@@ -113,13 +113,17 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
     /* Init SDL */
     if(bInitGraphics == false) {
-      if(SDL_Init(SDL_INIT_TIMER) < 0)
+      /* SDL_INIT_TIMER is not initialized while
+	 it's not required for SDL_Delay and SDL_GetTicks according to the
+	 code + it's not precised in the doc that it's required
+       */
+      if(SDL_Init(0) < 0)
         throw Exception("(1) SDL_Init : " + std::string(SDL_GetError()));
       
       /* No graphics mojo here, thank you */
       return;
     } else {
-      if(SDL_Init(SDL_INIT_VIDEO|SDL_INIT_TIMER) < 0)
+      if(SDL_Init(SDL_INIT_VIDEO) < 0)
         throw Exception("(2) SDL_Init : " + std::string(SDL_GetError()));
     }
     /* Set window title */
@@ -151,6 +155,7 @@ GameApp::~GameApp() {
 
   StateManager::cleanStates();
   delete m_userConfig;
+//  delete m_fileGhost;
 }
 
 GameApp::GameApp() {
@@ -188,6 +193,8 @@ GameApp::GameApp() {
   m_hasKeyboardFocus = true;
   m_isIconified      = false;
 
+  m_standAloneServer = NULL;
+
   m_userConfig = new UserConfig();
 }
    
@@ -489,23 +496,16 @@ void GameApp::displayCursor(bool display)
   void GameApp::initReplaysFromDir(xmDatabase* threadDb,
 				   XMotoLoadReplaysInterface* pLoadReplaysInterface) {
     std::vector<std::string> ReplayFiles;
+
     ReplayFiles = FS::findPhysFiles("Replays/*.rpl");
-    xmDatabase* pDb = NULL;
-
-    if(threadDb == NULL){
-      pDb = xmDatabase::instance("main");
-    } else {
-      pDb = threadDb;
-    }
-
-    pDb->replays_add_begin();
+    threadDb->replays_add_begin();
 
     for(unsigned int i=0; i<ReplayFiles.size(); i++) {
       try {
 	if(FS::getFileBaseName(ReplayFiles[i]) == "Latest") {
 	  continue;
 	}
-	addReplay(ReplayFiles[i], pDb, false);
+	addReplay(ReplayFiles[i], threadDb, false);
 	if(pLoadReplaysInterface != NULL){
 	  pLoadReplaysInterface->loadReplayHook(ReplayFiles[i], (int)((i*100)/((float)ReplayFiles.size())));
 	}
@@ -514,7 +514,7 @@ void GameApp::displayCursor(bool display)
 	// ok, forget this replay
       }
     }
-    pDb->replays_add_end();
+    threadDb->replays_add_end();
   }
 
   void GameApp::addReplay(const std::string& i_file, xmDatabase* pDb, bool sendMessage) {
@@ -592,7 +592,8 @@ void GameApp::addGhosts(Scene* i_motogame, Theme* i_theme) {
 
       if(v_replay_BESTOFROOM[i] != "" && v_exists == false) {
 	LogInfo("add ghost %s", v_replay_BESTOFROOM[i].c_str());
-	i_motogame->addGhostFromFile(v_replay_BESTOFROOM[i],
+
+        i_motogame->addGhostFromFile(v_replay_BESTOFROOM[i],
 				     xmDatabase::instance("main")->webrooms_getName(XMSession::instance()->idRoom(i)), i==0,
 				     Theme::instance(), Theme::instance()->getGhostTheme(),
 				     TColor(255,255,255,0),
@@ -600,7 +601,7 @@ void GameApp::addGhosts(Scene* i_motogame, Theme* i_theme) {
 					    GET_GREEN(i_theme->getGhostTheme()->getUglyRiderColor()),
 					    GET_BLUE(i_theme->getGhostTheme()->getUglyRiderColor()),
 					    0)
-				     );
+			   );
       }
     }
   }
@@ -835,3 +836,7 @@ void GameApp::drawFrame(void) {
   StateManager::instance()->update();
   StateManager::instance()->render(); 
 }
+
+NetServer* GameApp::standAloneServer() {
+  return m_standAloneServer;
+}
