@@ -48,6 +48,7 @@ class UITabView;
 class UIButton;
 class UIFrame;
 class UIStatic;
+class NetServer;
 
 /*===========================================================================
   Game application
@@ -122,8 +123,8 @@ public:
   void requestEnd();
   bool isRequestingEnd();
 
-  TColor getColorFromPlayerNumber(int i_player);
-  TColor getUglyColorFromPlayerNumber(int i_player);
+  static TColor getColorFromPlayerNumber(int i_player);
+  static TColor getUglyColorFromPlayerNumber(int i_player);
 
   bool getHighscoreInfos(unsigned int i_number,
 			 const std::string& i_id_level, std::string* io_id_profile, std::string* io_url, bool* o_isAccessible);
@@ -155,6 +156,12 @@ public:
 
   void addReplay(const std::string& i_file, xmDatabase* pDb, bool sendMessage = true);
 
+  NetServer* standAloneServer();
+
+  static void wait(int& io_lastFrameTimeStamp, int& io_frameLate, int i_maxFps);
+  
+ // inline FileGhost* getFileGhost() { return m_fileGhost; };
+
 protected:
   void createDefaultConfig();
 
@@ -162,7 +169,7 @@ private:
   void manageEvent(SDL_Event* Event);
   void playMusic(const std::string& i_music); // "" => no music
 
-  void initNetwork();
+  void initNetwork(bool i_forceNoServerStarted, bool i_forceNoClientStarted);
   void uninitNetwork();
 
   ReplayBiker* m_replayBiker; /* link to the replay biker in REPLAYING state */
@@ -241,6 +248,9 @@ private:
       
   DrawLib *drawLib;
 
+  // standalone server;
+  NetServer* m_standAloneServer;
+
   /* Run-time fun */
   bool m_bQuit;		/* Quit flag */
 
@@ -249,8 +259,7 @@ private:
   int m_frameLate;
 
   /* Helpers */
-  void _Wait();
-    
+
   void _UpdateLoadingScreen(const std::string &NextTask = "");
       
   void _UpdateWebLevels(bool bSilent, bool bEnableWeb = true);
