@@ -104,8 +104,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
       v_event = new MGE_MoveBlock(v_eventTime);
     } else if(MGE_SetBlockPos::SgetType() == v_eventType) {
       v_event = new MGE_SetBlockPos(v_eventTime);
-    } else if(MGE_SetPhysicsBlockPos::SgetType() == v_eventType) {
-      v_event = new MGE_SetPhysicsBlockPos(v_eventTime);
     } else if(MGE_SetGravity::SgetType() == v_eventType) {
       v_event = new MGE_SetGravity(v_eventTime);
     } else if(MGE_SetPlayersPosition::SgetType() == v_eventType) {
@@ -130,6 +128,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
       v_event = new MGE_SetDynamicBlockNone(v_eventTime);
     } else if(MGE_CameraMove::SgetType() == v_eventType) {
       v_event = new MGE_CameraMove(v_eventTime);
+    } else if(MGE_CameraSetPos::SgetType() == v_eventType) {
+      v_event = new MGE_CameraSetPos(v_eventTime);
     } else if(MGE_CameraZoom::SgetType() == v_eventType) {
       v_event = new MGE_CameraZoom(v_eventTime);
     } else if(MGE_PenalityTime::SgetType() == v_eventType) {
@@ -525,7 +525,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   }
   
   void MGE_EntityDestroyed::doAction(Scene *p_pScene) {
-    p_pScene->entityDestroyed(m_entityId);
+    p_pScene->entityDestroyed(m_entityId, m_eventTime);
   }
 
   void MGE_EntityDestroyed::serialize(DBuffer &Buffer) {
@@ -761,7 +761,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   } 
   
   void MGE_Message::doAction(Scene *p_pScene) {
-    p_pScene->gameMessage(m_message);
+    p_pScene->gameMessage(m_message, false, MOTOGAME_DEFAULT_GAME_MESSAGE_DURATION, scripted);
   }
 
   void MGE_Message::serialize(DBuffer &Buffer) {
@@ -883,55 +883,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     return "Block " + m_blockID + "'s position is changed";
   }
 
-  //////////////////////////////
-  MGE_SetPhysicsBlockPos::MGE_SetPhysicsBlockPos(int p_eventTime)
-  : SceneEvent(p_eventTime) {
-    m_blockID = "";
-    m_x = 0.0;
-    m_y = 0.0;
-  }
-
-  MGE_SetPhysicsBlockPos::MGE_SetPhysicsBlockPos(int p_eventTime,
-                                   std::string p_blockID,
-                                   float p_x, float p_y)
-  : SceneEvent(p_eventTime) {
-    m_blockID = p_blockID;
-    m_x = p_x;
-    m_y = p_y;
-  }
-
-  MGE_SetPhysicsBlockPos::~MGE_SetPhysicsBlockPos() {
-  }
-
-  void MGE_SetPhysicsBlockPos::doAction(Scene *p_pScene) {
-    p_pScene->SetPhysicsBlockPos(m_blockID, m_x, m_y);
-  }
-
-  void MGE_SetPhysicsBlockPos::serialize(DBuffer &Buffer) {
-    SceneEvent::serialize(Buffer);
-    Buffer << m_blockID;
-    Buffer << m_x;
-    Buffer << m_y;
-  }
-
-  void MGE_SetPhysicsBlockPos::unserialize(DBuffer &Buffer) {
-    Buffer >> m_blockID;
-    Buffer >> m_x;
-    Buffer >> m_y;
-  }
-
-  GameEventType MGE_SetPhysicsBlockPos::SgetType() {
-    return GAME_EVENT_SETPHYSICSBLOCKPOS;
-  }
-
-  GameEventType MGE_SetPhysicsBlockPos::getType() {
-    return SgetType();
-  }
-
-  std::string MGE_SetPhysicsBlockPos::toString() {
-    return "Block " + m_blockID + "'s position is changed";
-  }
-
   //////////////////////////////
   MGE_SetGravity::MGE_SetGravity(int p_eventTime) 
   : SceneEvent(p_eventTime) {
@@ -1637,6 +1588,52 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     return "Camera moves";
   }
 
+  //////////////////////////////
+  MGE_CameraSetPos::MGE_CameraSetPos(int p_eventTime) 
+  : SceneEvent(p_eventTime) {
+    m_X = 0.0;
+    m_Y = 0.0;
+  }
+
+  MGE_CameraSetPos::MGE_CameraSetPos(int p_eventTime, float p_X, float p_Y)
+  : SceneEvent(p_eventTime) {
+    m_X = p_X;
+    m_Y = p_Y;
+  }
+
+  MGE_CameraSetPos::~MGE_CameraSetPos() {
+  } 
+  
+  void MGE_CameraSetPos::doAction(Scene *p_pScene) {
+    for(unsigned int i=0; i<p_pScene->getNumberCameras(); i++) {
+    p_pScene->setCurrentCamera(i);
+      p_pScene->CameraSetPos(m_X, m_Y);
+    }
+  }
+
+  void MGE_CameraSetPos::serialize(DBuffer &Buffer) {
+    SceneEvent::serialize(Buffer);
+    Buffer << m_X;
+    Buffer << m_Y;
+  }
+  
+  void MGE_CameraSetPos::unserialize(DBuffer &Buffer) {
+    Buffer >> m_X;
+    Buffer >> m_Y;
+  }
+
+  GameEventType MGE_CameraSetPos::SgetType() {
+    return GAME_EVENT_CAMERASETPOS;
+  }
+
+  GameEventType MGE_CameraSetPos::getType() {
+    return SgetType();
+  }
+
+  std::string MGE_CameraSetPos::toString() {
+    return "Camera position is set";
+  }
+
   //////////////////////////////
   MGE_CameraZoom::MGE_CameraZoom(int p_eventTime) 
   : SceneEvent(p_eventTime) {
