@@ -22,8 +22,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *  Game application. (init-related stuff)
  */
  
-/* rneckelmann 2006-09-30: moved a lot of stuff from Game.cpp into here to 
-                           make it a tad smaller */ 
 #include "GameText.h"
 #include "Game.h"
 #include "VFileIO.h"
@@ -51,9 +49,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "states/StateReplaying.h"
 #include "states/StatePreplayingReplay.h"
 #include "states/StatePreplayingGame.h"
+#include "states/StateWaitServerInstructions.h"
 #include "states/StateMainMenu.h"
 #include "states/StateMessageBox.h"
 
+#include "thread/UpgradeLevelsThread.h"
+
 #include "UserConfig.h"
 #include "Renderer.h"
 #include "net/NetServer.h"
@@ -61,6 +62,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "net/NetActions.h"
 #include "include/xm_SDL_net.h"
 
+#if !defined(WIN32)
+#include <signal.h>
+#endif
+
 #define MOUSE_DBCLICK_TIME 0.250f
 
 #ifdef __amigaos4__
@@ -122,6 +127,17 @@ int main(int nNumArgs, char **ppcArgs) {
   return 0;
 }
 
+void xmexit_term(int i_signal) {
+  if(GameApp::instance()->standAloneServer() != NULL) {
+    if(Logger::isInitialized()) {
+      LogInfo("signal received.");
+    }
+    GameApp::instance()->standAloneServer()->stop();
+    GameApp::instance()->run_unload();
+  }
+  exit(0);
+}
+
 void GameApp::run(int nNumArgs, char** ppcArgs) {
   try {
     run_load(nNumArgs, ppcArgs);
@@ -137,6 +153,8 @@ void GameApp::run_load(int nNumArgs, char** ppcArgs) {
   XMArguments v_xmArgs;
   m_isODEInitialized = false;
   bool v_useGraphics = true;
+  bool v_missingFont = false;
+  std::string v_missingFontError;
 
   /* check args */
   try {
@@ -191,16 +209,14 @@ void GameApp::run_load(int nNumArgs, char** ppcArgs) {
   /* load config file, the session */
   XMSession::createDefaultConfig(m_userConfig);
   m_userConfig->loadFile();
-  
 
-  XMSession::instance("file")->load(m_userConfig); /* overload default session by userConfig */
-  (* XMSession::instance("live")) = (* XMSession::instance("file")) ; /* copying the resulting session in "live" instance */
-  (* XMSession::instance("temp")) = (* XMSession::instance("file")) ; /* copying the resulting session in a needed temporary instance */
-  XMSession::setDefaultInstance("live");
+  XMSession::setDefaultInstance("live");  
+  XMSession::instance()->load(m_userConfig); /* overload default session by userConfig */
 
   XMSession::instance()->load(&v_xmArgs); /* overload default session by xmargs     */
 
   Logger::setVerbose(XMSession::instance()->isVerbose()); /* apply verbose mode */
+  Logger::setActiv(XMSession::instance()->noLog() == false); /* apply log activ mode */
 
   LogInfo(std::string("X-Moto " + XMBuild::getVersionString(true)).c_str());
   LogInfo("compiled at "__DATE__" "__TIME__);
@@ -212,17 +228,75 @@ void GameApp::run_load(int nNumArgs, char** ppcArgs) {
   LogInfo("User directory: %s", FS::getUserDir().c_str());
   LogInfo("Data directory: %s", FS::getDataDir().c_str());
 
-  if(v_xmArgs.isOptListLevels() || v_xmArgs.isOptListReplays() || v_xmArgs.isOptReplayInfos()) {
+  if(v_xmArgs.isOptListLevels() || v_xmArgs.isOptListReplays() || v_xmArgs.isOptReplayInfos() || v_xmArgs.isOptServerOnly() || v_xmArgs.isOptUpdateLevelsOnly()) {
     v_useGraphics = false;
   }
 
+  // doesn't work on windows
+#if !defined(WIN32)
+  if(v_xmArgs.isOptServerOnly()) {
+    struct sigaction v_act;
+
+    v_act.sa_handler = xmexit_term;
+
+    if(sigaction(SIGTERM, &v_act, NULL) != 0) {
+      LogWarning("sigaction failed");
+    }
+
+    if(sigaction(SIGINT, &v_act, NULL) != 0) {
+      LogWarning("sigaction failed");
+    }
+  }
+#endif
+
   // init not so random numbers
   NotSoRandom::init();
 
-  _InitWin(v_useGraphics);
+  //gettext  requires database (pour la config de la langue)
+  //database requires drawlib  (pour visualiser les upgrades)
+  //drawlib  requires gettext  (pour choisir la fonte)
 
-  /* Init the window */
+  /* database */
+  /* thus, resolution/bpp/windowed parameters cannot be stored in the db (or some minor modifications are required) */
+  xmDatabase* pDb = xmDatabase::instance("main");
+  pDb->init(DATABASE_FILE,
+	    XMSession::instance()->profile() == "" ? std::string("") : XMSession::instance()->profile(),
+	    FS::getDataDir(), FS::getUserDir(), FS::binCheckSum(),
+	    v_xmArgs.isOptNoDBDirsCheck() == false,
+	    NULL); // v_useGraphics : NULL because drawlib is still not initialized
+  if(XMSession::instance()->sqlTrace()) {
+    pDb->setTrace(XMSession::instance()->sqlTrace());
+  }
+
+  XMSession::instance("file")->load(m_userConfig);  
+  XMSession::instance("file")->loadProfile(XMSession::instance("file")->profile(), pDb);
+  (* XMSession::instance()) = (* XMSession::instance("file"));
+
+  XMSession::instance()->load(&v_xmArgs); /* overload default session by xmargs */
+  // enable propagation only after overloading by command args
+  XMSession::enablePropagation("file");
+
+  LogInfo("SiteKey: %s", XMSession::instance()->sitekey().c_str());
+
+#ifdef USE_GETTEXT
+  std::string v_locale = Locales::init(XMSession::instance()->language());
+  LogInfo("Locales set to '%s' (directory '%s')", v_locale.c_str(), LOCALESDIR);
+
+  // some asian langages require ttf files ; change to us in case of problem
+  try {
+    DrawLib::checkFontPrerequites();
+  } catch(Exception &e) {
+    v_missingFont = true;
+    v_missingFontError = e.getMsg();
+    v_locale = Locales::init("en_US");
+    LogWarning("font prerequisites missing, switching to en_US: %s", e.getMsg().c_str());
+  }
+#endif
+
+  /* drawlib */
   if(v_useGraphics) {
+    _InitWin(v_useGraphics);
+
     /* init drawLib */
     drawLib = DrawLib::DrawLibFromName(XMSession::instance()->drawlib());
 
@@ -235,51 +309,23 @@ void GameApp::run_load(int nNumArgs, char** ppcArgs) {
     drawLib->setNoGraphics(v_useGraphics == false);
     drawLib->setDontUseGLExtensions(XMSession::instance()->glExts() == false);
 
+    LogInfo("Wanted resolution: %ix%i (%i bpp)",
+            XMSession::instance()->resolutionWidth(),
+	    XMSession::instance()->resolutionHeight(),
+	    XMSession::instance()->bpp());
     drawLib->init(XMSession::instance()->resolutionWidth(), XMSession::instance()->resolutionHeight(), XMSession::instance()->bpp(), XMSession::instance()->windowed());
     /* drawlib can change the final resolution if it fails, then, reinit session one's */
-    XMSession::instance("temp")->setResolutionWidth(drawLib->getDispWidth());
-    XMSession::instance("temp")->setResolutionHeight(drawLib->getDispHeight());
-    XMSession::instance("temp")->setBpp(drawLib->getDispBPP());
-    XMSession::instance("temp")->setWindowed(drawLib->getWindowed());
-    LogInfo("Resolution: %ix%i (%i bpp)", XMSession::instance("temp")->resolutionWidth(), XMSession::instance("temp")->resolutionHeight(), XMSession::instance("temp")->bpp());
+    XMSession::instance()->setResolutionWidth(drawLib->getDispWidth());
+    XMSession::instance()->setResolutionHeight(drawLib->getDispHeight());
+    XMSession::instance()->setBpp(drawLib->getDispBPP());
+    XMSession::instance()->setWindowed(drawLib->getWindowed());
+    LogInfo("Resolution: %ix%i (%i bpp)",
+            XMSession::instance()->resolutionWidth(),
+	    XMSession::instance()->resolutionHeight(),
+	    XMSession::instance()->bpp());
     /* */
-    
-    if(!drawLib->isNoGraphics()) {        
-      drawLib->setDrawDims(XMSession::instance()->resolutionWidth(), XMSession::instance()->resolutionHeight(),
-			   XMSession::instance()->resolutionWidth(), XMSession::instance()->resolutionHeight());
-    }
-  }
 
-  /* database -- require drawlib initialized */
-  /* thus, resolution/bpp/windowed parameters cannot be stored in the db (or some minor modifications are required) */
-  xmDatabase* pDb = xmDatabase::instance("main");
-  pDb->init(DATABASE_FILE,
-	    XMSession::instance()->profile() == "" ? std::string("") : XMSession::instance()->profile(),
-	    FS::getDataDir(), FS::getUserDir(), FS::binCheckSum(),
-	    v_xmArgs.isOptNoDBDirsCheck() == false,
-	    v_useGraphics ? this : NULL);
-  if(XMSession::instance()->sqlTrace()) {
-    pDb->setTrace(XMSession::instance()->sqlTrace());
   }
-  
-  XMSession::instance("file")->loadProfile(XMSession::instance("file")->profile(), pDb);
-  (* XMSession::instance("live")) = (* XMSession::instance("file")) ; /* copying the resulting session in "live" instance */
-  
-  /* Live instance should be altered by drawLib changes. Apply this alterations */
-  XMSession::instance()->setResolutionWidth(XMSession::instance("temp")->resolutionWidth());
-  XMSession::instance()->setResolutionHeight(XMSession::instance("temp")->resolutionHeight());
-  XMSession::instance()->setBpp(XMSession::instance("temp")->bpp());
-  XMSession::instance()->setWindowed(XMSession::instance("temp")->windowed());
-  XMSession::destroy("temp");
-  
-  XMSession::instance()->load(&v_xmArgs); /* overload default session by xmargs     */
-  LogInfo("SiteKey: %s", XMSession::instance()->sitekey().c_str());
-  XMSession::enablePropagation("file");
-
-#ifdef USE_GETTEXT
-  std::string v_locale = Locales::init(XMSession::instance()->language());
-  LogInfo("Locales set to '%s' (directory '%s')", v_locale.c_str(), LOCALESDIR);
-#endif
 
   // allocate the statemanager instance so that if it fails, it's not in a thread (serverThread for example)
   StateManager::instance();
@@ -290,8 +336,8 @@ void GameApp::run_load(int nNumArgs, char** ppcArgs) {
   }
 
   // no command line need the network for the moment
-  if(v_useGraphics) {
-    initNetwork();
+  if(v_useGraphics || v_xmArgs.isOptServerOnly()) {
+    initNetwork(v_xmArgs.isOptServerOnly(), v_xmArgs.isOptServerOnly());
   }
 
   /* Init renderer */
@@ -377,63 +423,119 @@ void GameApp::run_load(int nNumArgs, char** ppcArgs) {
     quit();
     return;
   }
-  
+
+  /* -updateLevels */
+  if(v_xmArgs.isOptUpdateLevelsOnly()) {
+    UpgradeLevelsThread* m_upgradeLevelsThread;
+    bool v_currentVerbosity = Logger::isVerbose();
+    int v_res;
+
+    m_upgradeLevelsThread = new UpgradeLevelsThread(XMSession::instance()->theme(), true);
+
+    // force verbosity while updating levels
+    Logger::setVerbose(true);
+    v_res = m_upgradeLevelsThread->runInMain();
+    if(v_res != 0 && v_res != 2 /* 2 for no level to update */) {
+      LogError("Not able to update levels");
+    }
+    Logger::setVerbose(v_currentVerbosity);
+
+    quit();
+    return;
+  }
+
   /* requires graphics now */
-  if(v_useGraphics == false) {
+  if(v_useGraphics == false && v_xmArgs.isOptServerOnly() == false) {
     quit();
     return;
   }
   
-  _UpdateLoadingScreen();
+  if(v_xmArgs.isOptServerOnly() == false) {
+    _UpdateLoadingScreen();
 
-  /* Find all files in the textures dir and load them */     
-  UITexture::setApp(this);
-  UIWindow::setDrawLib(getDrawLib());
+    /* Find all files in the textures dir and load them */     
+    UITexture::setApp(this);
+    UIWindow::setDrawLib(getDrawLib());
+  }
 
   // init physics
   // if(dInitODE2(0) == 0) { /* erreur */} ; // ode 0.10
   dInitODE();
   m_isODEInitialized = true;
 
-  /* Initialize renderer */
-  GameRenderer::instance()->init(drawLib);
-  
+  if(v_xmArgs.isOptServerOnly() == false) {
+    /* Initialize renderer */
+    GameRenderer::instance()->init(drawLib);
+  }  
+
   /* build handler */
   InputHandler::instance()->init(m_userConfig, pDb, XMSession::instance()->profile(), XMSession::instance()->enableJoysticks());
   Replay::enableCompression(XMSession::instance()->compressReplays());
   
   /* load packs */
   LevelsManager::checkPrerequires();
-  LevelsManager::instance()->makePacks(XMSession::instance()->profile(), XMSession::instance()->idRoom(0), XMSession::instance()->debug(), xmDatabase::instance("main"));
+  LevelsManager::instance()->makePacks(XMSession::instance()->profile(), XMSession::instance()->idRoom(0),
+				       XMSession::instance()->debug(), XMSession::instance()->adminMode(), xmDatabase::instance("main"));
 
   /* Update stats */
-  if(XMSession::instance()->profile() != "") {
-    pDb->stats_xmotoStarted(XMSession::instance()->sitekey(), XMSession::instance()->profile());
+  if(v_xmArgs.isOptServerOnly() == false) {
+    if(XMSession::instance()->profile() != "") {
+      pDb->stats_xmotoStarted(XMSession::instance()->sitekey(), XMSession::instance()->profile());
+    }
   }
 
-  /* try to not run sql at the same time you enter in the main menu (a thread to compute packs is run (concurrency)) */
-
-  /* What to do? */
-  if(m_PlaySpecificLevelFile != "") {
+  if(v_xmArgs.isOptServerOnly()) {
     try {
-      LevelsManager::instance()->addExternalLevel(m_PlaySpecificLevelFile, xmDatabase::instance("main"));
-      m_PlaySpecificLevelId = LevelsManager::instance()->LevelByFileName(m_PlaySpecificLevelFile, xmDatabase::instance("main"));
+      m_standAloneServer = NetServer::instance();
+      NetServer::instance()->start(false);
     } catch(Exception &e) {
-      m_PlaySpecificLevelId = m_PlaySpecificLevelFile;
+      LogError((std::string("Exception: ") + e.getMsg()).c_str());
     }
-  }
-  if((m_PlaySpecificLevelId != "")) {
-    /* ======= PLAY SPECIFIC LEVEL ======= */
-    StateManager::instance()->pushState(new StatePreplayingGame(m_PlaySpecificLevelId, false));
-    LogInfo("Playing as '%s'...", XMSession::instance()->profile().c_str());
-  }
-  else if(m_PlaySpecificReplay != "") {
-    /* ======= PLAY SPECIFIC REPLAY ======= */
-    StateManager::instance()->pushState(new StatePreplayingReplay(m_PlaySpecificReplay, false));
+
+    quit();
+    return;
+
+  } else {
+
+    /* try to not run sql at the same time you enter in the main menu (a thread to compute packs is run (concurrency)) */
+
+    /* What to do? */
+    if(m_PlaySpecificLevelFile != "") {
+      try {
+	LevelsManager::instance()->addExternalLevel(m_PlaySpecificLevelFile, xmDatabase::instance("main"));
+	m_PlaySpecificLevelId = LevelsManager::instance()->LevelByFileName(m_PlaySpecificLevelFile, xmDatabase::instance("main"));
+      } catch(Exception &e) {
+	m_PlaySpecificLevelId = m_PlaySpecificLevelFile;
+      }
+    }
+    if((m_PlaySpecificLevelId != "")) {
+      /* ======= PLAY SPECIFIC LEVEL ======= */
+
+      if(XMSession::instance()->clientGhostMode() == false && NetClient::instance()->isConnected()) {
+	  StateManager::instance()->pushState(new StateWaitServerInstructions(StateManager::instance()->getUniqueId()));
+      } else {
+	StateManager::instance()->pushState(new StatePreplayingGame(StateManager::instance()->getUniqueId(),
+								    m_PlaySpecificLevelId, false));
+      }
+      LogInfo("Playing as '%s'...", XMSession::instance()->profile().c_str());
+    }
+    else if(m_PlaySpecificReplay != "") {
+      /* ======= PLAY SPECIFIC REPLAY ======= */
+      StateManager::instance()->pushState(new StatePreplayingReplay(StateManager::instance()->getUniqueId(),
+								    m_PlaySpecificReplay, false));
+    }
+    else {
+      /* display what must be displayed */
+      StateManager::instance()->pushState(new StateMainMenu());
+      if(XMSession::instance()->clientGhostMode() == false && NetClient::instance()->isConnected()) {
+	  StateManager::instance()->pushState(new StateWaitServerInstructions(StateManager::instance()->getUniqueId()));
+      }
+    }
+
+    /* display error information to the player */
+    if(v_missingFont) {
+      SysMessage::instance()->displayError(GAMETEXT_TTF_MISSING + std::string("\n") + v_missingFontError);
     }
-  else {
-    /* display what must be displayed */
-    StateManager::instance()->pushState(new StateMainMenu());
   }
 
   LogInfo("UserInit ended at %.3f", GameApp::getXMTime());
@@ -560,9 +662,9 @@ void GameApp::run_loop() {
 
     /* Update user app */
     drawFrame();
-
+    
     if(XMSession::instance()->timedemo() == false) {
-      _Wait();
+      GameApp::wait(m_lastFrameTimeStamp, m_frameLate, StateManager::instance()->getMaxFps());
     }
   }
 }
@@ -638,18 +740,18 @@ void GameApp::run_unload() {
 }
 
 
-void GameApp::_Wait()
+ void GameApp::wait(int& io_lastFrameTimeStamp, int& io_frameLate, int i_maxFps)
 {
-  if(m_lastFrameTimeStamp < 0){
-    m_lastFrameTimeStamp = getXMTimeInt();
+  if(io_lastFrameTimeStamp < 0){
+    io_lastFrameTimeStamp = getXMTimeInt();
   }
 
   /* Does app want us to delay a bit after the frame? */
   int currentTimeStamp        = getXMTimeInt();
-  int currentFrameMinDuration = 1000/StateManager::instance()->getMaxFps();
-  int lastFrameDuration       = currentTimeStamp - m_lastFrameTimeStamp;
+  int currentFrameMinDuration = 1000/i_maxFps;
+  int lastFrameDuration       = currentTimeStamp - io_lastFrameTimeStamp;
   // late from the lasts frame is not forget
-  int delta = currentFrameMinDuration - (lastFrameDuration + m_frameLate);
+  int delta = currentFrameMinDuration - (lastFrameDuration + io_frameLate);
 
   // if we have toooo much late (1/10 second), let reset delta
   int maxDelta = -100;
@@ -668,17 +770,17 @@ void GameApp::_Wait()
     // now that we have sleep, see if we don't have too much sleep
     if(sleepTime >= delta){
       int tooMuchSleep = sleepTime - delta;
-      m_frameLate      = tooMuchSleep;
+      io_frameLate      = tooMuchSleep;
     }
   }
   else{
     // we're late
     // -> update late time
-    m_frameLate = (-delta);
+    io_frameLate = (-delta);
   }
 
   // the sleeping time is not included in the next frame time
-  m_lastFrameTimeStamp = getXMTimeInt();
+  io_lastFrameTimeStamp = getXMTimeInt();
 }
 
 
@@ -713,14 +815,45 @@ void GameApp::_Wait()
   }
 
 
-void GameApp::initNetwork() {
+  void GameApp::initNetwork(bool i_forceNoServerStarted, bool i_forceNoClientStarted) {
   if(SDLNet_Init()==-1) {
     throw Exception(SDLNet_GetError());
   }
 
-  // start server
-  if(XMSession::instance()->serverStartAtStartup()) {
-    NetServer::instance()->start();
+  // start server if gui
+  if(i_forceNoServerStarted == false) {
+    if(XMSession::instance()->serverStartAtStartup()) {
+      NetServer::instance()->start(true);
+    }
+  }
+
+  if(i_forceNoClientStarted == false) {
+    if(XMSession::instance()->clientConnectAtStartup()) {
+
+      /* special case : if xmoto is it's own server, you must wait that the server is started
+	 test ip is not a good solution, by the way, people starting the server
+	 should use it or lost less than 1 second at startup
+       */
+      if(XMSession::instance()->serverStartAtStartup()) {
+	// wait that server is started
+	while(NetServer::instance()->acceptConnections() == false) {
+	  LogInfo("Server still not accepting connections, wait");
+	  SDL_Delay(100);
+	}
+      }
+
+      try {
+	NetClient::instance()->connect(XMSession::instance()->clientServerName(),
+				       XMSession::instance()->clientServerPort());
+	// don't send in ghost mode to be compatible with old servers
+	if(XMSession::instance()->clientGhostMode() == false) {
+	  NetClient::instance()->changeMode(XMSession::instance()->clientGhostMode() ? NETCLIENT_GHOST_MODE : NETCLIENT_SLAVE_MODE);
+	}
+      } catch(Exception &e) {
+	SysMessage::instance()->displayError(GAMETEXT_UNABLETOCONNECTONTHESERVER);
+	LogError("Unable to connect to the server");
+      }
+    }
   }
 
 }
