@@ -57,6 +57,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_AUTOZOOM             _("Auto zoom")
 #define GAMETEXT_DB                   _("Database")
 #define GAMETEXT_CAMERAACTIVEZOOM     _("Camera Active Zoom")
+#define GAMETEXT_CAMERATRAILCAM       _("Use Trail Cam")
 #define GAMETEXT_BEATINGMODE          _("Beating mode")
 #define GAMETEXT_BESTTIMES            _("Best Times")
 #define GAMETEXT_BESTPLAYER           _("Best player")
@@ -103,6 +104,8 @@ Central place to keep many in-game text strings
 #define GAMETEXT_JOYSTICK_DIRECTION_DOWN  _("down")
 #define GAMETEXT_JOYSTICK_DIRECTION_NONE  _("none")
 #define GAMETEXT_JOYSTICK_BUTTON          _("button %i")
+#define GAMETEXT_OPTION_NEED_TO_RESTART _("You must restart so that this option takes effect")
+#define GAMETEXT_OPTION_NEED_TO_SERVERRECONNECT _("You must reconnect to the server so that this option takes effect")
 #define GAMETEXT_SCRIPTACTION             _("Script action")
 
 #define GAMETEXT_CREDITS                                                                     \
@@ -110,8 +113,10 @@ Central place to keep many in-game text strings
     ":Rasmus Neckelmann;"                                                                    \
     ":Nicolas Adenis-Lamarre;"                                                               \
     ":Emmanuel Gorse;"                                                                       \
+    ":Jens Erler;"                                                                           \
     ":;"                                                                                     \
     + std::string(_("Additional Programming")) +                                             \
+    ":Ville Lahdenvuo;"                                                                       \
     ":Richard Franks;"                                                                       \
     ":Kees Jongenburger;"                                                                    \
     ":Eric Piel;"                                                                            \
@@ -119,7 +124,6 @@ Central place to keep many in-game text strings
     ":Frederic Huard;"                                                                       \
     ":Brice Goglin;"                                                                         \
     ":Kristian Jagd;"                                                                        \
-    ":Jens Erler;"                                                                           \
     ":;"                                                                                     \
     + std::string(_("Graphics")) +                                                           \
     ":Rasmus Neckelmann;"                                                                    \
@@ -150,6 +154,9 @@ Central place to keep many in-game text strings
     ":Jānis Rūcis (" + std::string(_("Latvian")) + ");"                                      \
     ":Kristian Jagd (" + std::string(_("Danish")) + ");"                                     \
     ":Tadas Masiulionis (" + std::string(_("Lithuanian")) + ");"                                     \
+    ":Anil Ozbek (" + std::string(_("Turkish")) + ");"                                     \
+    ":Zoltán Balogh (" + std::string(_("Hungarian")) + ");"                                     \
+    ":Sérgio Marques (" + std::string(_("Portugese")) + ");"                                 \
     ":;"                                                                                     \
     + std::string(_("Main testers")) +                                                       \
     ":Jose Alberto Coelho;"                                                                  \
@@ -248,6 +255,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_GHOST_STRATEGY_MYBEST  _("The best of my replays (on this computer)")
 #define GAMETEXT_GHOST_STRATEGY_THEBEST _("The best of the replays (on this computer)")
 #define GAMETEXT_GHOSTOF              _("Ghost of %s")
+#define GAMETEXT_WAIT_XMSERVER        _("Please wait the next party\nOr press escape to disconnect")
 #define GAMETEXT_WEBGHOSTOF           _("Web ghost of %s")
 #define GAMETEXT_GHOSTTAB             _("Ghost")
 #define GAMETEXT_HELP                 _("Help")
@@ -263,17 +271,48 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 "  Esc - " + std::string(_("Pause")) + "\n" \
 "  Return - " + std::string(_("Restart the level")) + "\n" \
 "  PageDown/PageUp - " + std::string(_("Previous/Next level")) + "\n" \
-"  ctrl+M - " + std::string(_("change mirror mode")) + "\n"\
+"  " + "\n"\
 "  F8 - " + std::string(_("Enable/disable web")) + "\n" \
 "  F5 - " + std::string(_("Reload levels, themes and replays from directories")) + "\n" \
 "  F12 - " + std::string(_("Take a screenshot")) + "\n" \
-"\n" \
+"  " + "\n" \
+ + std::string(_("Use Quick Play button to immediately start a game with a random level,\nor use Levels button to select from level packs.")) + "\n" \
+"  " + "\n" \
  + std::string(_("Find all the strawberries and touch the flower to finish\nthe level.")) + "\n" \
- + std::string(_("Read the README file or check out the website at\nhttp://xmoto.tuxfamily.org for more information."))
+ + std::string(_("Read the README file or check out the website at\nhttp://xmoto.tuxfamily.org\nfor more information."))
+
+#define GAMETEXT_HELPTEXT_PLAYINGLEVEL(accelerate_KEY, brake_KEY, rotate_counter_clockwise_KEY, rotate_clockwise_KEY, change_direction_KEY) \
+std::string(_("You control your bike using the keyboard")) + ":\n" \
+"  " + accelerate_KEY + " - " + _("Accelerates") + "\n" \
+"  " + brake_KEY + " - " + std::string(_("Brakes")) + "\n" \
+"  " + rotate_counter_clockwise_KEY + " - " + std::string(_("Rotates it counter-clockwise")) + "\n" \
+"  " + rotate_clockwise_KEY + " - " + std::string(_("Rotates it clockwise")) + "\n" \
+"  " + change_direction_KEY + " - " + std::string(_("Turns around and drives in the other direction")) + "\n" \
+"  " + "\n" \
+"  Esc - " + std::string(_("Pause")) + "\n" \
+"  Return - " + std::string(_("Restart the level")) + "\n" \
+"  PageDown/PageUp - " + std::string(_("Previous/Next level")) + "\n" \
+"  ctrl+M - " + std::string(_("change mirror mode")) + "\n"\
+"  ctrl+B - " + std::string(_("Toggle blacklist")) + "\n"\
+"  ctrl+S - " + std::string(_("Enable/disable audio")) +"\n"\
+"  ctrl+O - " + std::string(_("Open options menu"))  + "\n"\
+"  ctrl+G - " + std::string(_("Toggle Ghost Trail Rendering")) + "\n"\
+"  ctrl+T - " + std::string(_("Toggle Trail Cam")) + "\n"\
+"  F1 - " + std::string(_("Show this help")) + "\n"\
+"  F2 - " + std::string(_("Show the ghost if possible in the game")) + "\n"\
+"  F3 - " + std::string(_("Toggle favorite")) + "\n"\
+"  F4 - " + std::string(_("Toggle Ghost Trail Tracking Shot")) +"\n"\
+"  F7 - " + std::string(_("Enable/disable FPS display")) + "\n"\
+"  F8 - " + std::string(_("Enable/disable web")) + "\n" \
+"  F9 - " + std::string(_("Enable/disable ugly mode")) + "\n"\
+"  F10- " + std::string(_("Enable/disable theme mode")) + "\n"\
+"  F11- " + std::string(_("Enable/disable ugly over mode")) + "\n"\
+"  F12- " + std::string(_("Take a screenshot")) + "\n" \
 
 #define GAMETEXT_HIDEGHOSTS           _("Hide ghosts")
 #define GAMETEXT_HIGH                 _("High")
 #define GAMETEXT_HIGHSCOREOFTHEROOM   _("Highscore of the room")
+#define GAMETEXT_HIGHSCORE_STOLEN     _("%s: %s beat your highscore for level '%s'")
 #define GAMETEXT_LOAD_LEVEL_HOOK      _("Levels are being added into the database. Please wait.")
 #define GAMETEXT_INETCONF             _("Internet Configuration")
 #define GAMETEXT_INITZOOM             _("View Level Initially")
@@ -311,6 +350,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_MAIN                 _("Main")
 #define GAMETEXT_MOUSE                _("Mouse")
 #define GAMETEXT_THEME                _("Theme")
+#define GAMETEXT_TTF_MISSING          "You must install the font file for your langage:" // not translated because always displayed in english
 #define GAMETEXT_MEDIUM               _("Medium")
 #define GAMETEXT_MENUGFX              _("Menu Graphics")
 #define CONTEXTHELP_MINISTATTIMEFORPACKLEVEL _("Total time you scored / total highscore time for levels you finished")
@@ -384,14 +424,16 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_RELOADINGREPLAYS     _("Reloading replays...")
 #define GAMETEXT_RELOADINGTHEMES      _("Reloading themes...")
 #define GAMETEXT_REPLAY               _("Replay")
-#define GAMETEXT_REPLAYHELPTEXT(current_speed) _("Stop[esc] ||[space]  << >>[left/right keys]  < >[up/down keys]   Speed:") + current_speed + "x"
-#define GAMETEXT_REPLAYHELPTEXTNOREWIND(current_speed) _("Stop[esc] ||[space] >>[right key] < >[up/down keys]   Speed:") + current_speed + "x"
-  // + "a" + "X"
+#define GAMETEXT_REPLAYHELPTEXTNOREWIND_L _("  Stop:\n    >>\n   < >\n Speed:" )
+#define GAMETEXT_REPLAYHELPTEXTNOREWIND_R(current_speed) _("[esc] , [space]\n[right key]\n[up/down keys]\n") + current_speed + "x"
+#define GAMETEXT_REPLAYHELPTEXT_L    _("  Stop:\n<< >>\n   < >\n Speed:" )
+#define GAMETEXT_REPLAYHELPTEXT_R(current_speed) _("[esc] , [space]\n[left/right keys]\n[up/down keys]\n") + current_speed + "x"
 #define GAMETEXT_REPLAYNOTFOUND       _("The replay can't be played!")
 #define GAMETEXT_REPLAYOF             _("Replay of %s")
 #define GAMETEXT_REPLAYS              _("Replays")
 #define GAMETEXT_RESETTODEFAULTS      _("Are you sure you want to reset config to defaults ?")
 #define GAMETEXT_RESTART              _("Restart This Level")
+#define GAMETEXT_RESTARTLEVEL         _("Restart level")
 #define GAMETEXT_RESUME               _("Resume Playing")
 #define GAMETEXT_ROOM                 _("Room")
 #define GAMETEXT_RUNWINDOWED          _("Run Windowed")
@@ -400,12 +442,14 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_SAVEREPLAY           _("Save Replay")
 #define GAMETEXT_SCREENRES            _("Screen Resolution")
 #define GAMETEXT_SHOW                 _("Show")
+#define GAMETEXT_SHOWCONSOLE          _("Show console")
 #define GAMETEXT_SHOWENGINECOUNTER    _("Speedometer")
 #define GAMETEXT_SHOWINFO             _("Info...")
 #define GAMETEXT_SHOWMINIMAP          _("Show Mini Map")
 #define GAMETEXT_STARTLEVEL           _("Play!")
 #define GAMETEXT_STATISTICS           _("Statistics")
 #define GAMETEXT_STATS                _("STATS")
+#define GAMETEXT_STATUS_DECONNECTED   _("You are currently disconnected")
 #define GAMETEXT_STEREO               _("Stereo")
 #define GAMETEXT_SYNC_DOWN            _("Synchronisation down")
 #define GAMETEXT_SYNC_UP              _("Synchronisation up")
@@ -484,6 +528,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_DEFAULT_PORT _("Default port")
 #define GAMETEXT_CUSTOM_PORT _("Custom port")
 #define GAMETEXT_NETWORK _("Network")
+#define GAMETEXT_CLIENTGHOSTMODE _("Simple ghost mode")
 #define GAMETEXT_CLIENTSTATUSON _("You're currently connected")
 #define GAMETEXT_CLIENTSTATUSOFF _("You're currently disconnected")
 #define GAMETEXT_CLIENTCONNECT _("Connect")
@@ -617,6 +662,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_DEATHANIM _("Enable animation of bike falling apart when dead")
 #define CONTEXTHELP_INITZOOM _("Automatically scroll over the level before starting playing it")
 #define CONTEXTHELP_CAMERAACTIVEZOOM _("Run a dynamic zoom while playing")
+#define CONTEXTHELP_CAMERATRAILCAM _("Use a camera that directs to the shortest path through the level")
 #define CONTEXTHELP_CREDITS _("View the X-Moto credits")
 #define CONTEXTHELP_REPLAYCOL _("Name of replay")
 #define CONTEXTHELP_REPLAYLEVELCOL _("Level played in replay")
@@ -632,6 +678,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_PROXYLOGIN    _("Your proxy login")
 #define CONTEXTHELP_PROXYPASSWORD _("Your password associated with your login")
 #define CONTEXTHELP_REPLAYS_FILTER _("Enter text to filter the replay list")
+#define CONTEXTHELP_ROOMS_FILTER _("Enter text to filter the rooms list")
 #define CONTEXTHELP_QUICKSTART _("Press to play X-Moto immediately")
 #define CONTEXTHELP_QUICKSTART_QUALITY    _("Increase or decrease the quality of the levels selected")
 #define CONTEXTHELP_QUICKSTART_DIFFICULTY _("Increase or decrease the difficulty of the levels selected")
@@ -664,6 +711,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_EXPERT       _("Expert")
 #define GAMETEXT_MASTER       _("Master")
 #define GAMETEXT_GOD          _("God")
+#define GAMETEXT_GO           _("Go !")
 #define GAMETEXT_NOTNICEATALL _("Not nice at all")
 #define GAMETEXT_NOTNICE      _("Not nice")
 #define GAMETEXT_NICE         _("Nice")
@@ -692,6 +740,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_SERVER _("Server on which you want to connect")
 #define CONTEXTHELP_CLIENTCONNECTDISCONNECT _("Connect/disconnect the client to the server")
 #define CONTEXTHELP_MUSICONALLLEVELS _("Enables background music for levels that do not have their own music track")
+#define CONTEXTHELP_CLIENTGHOSTMODE _("Network playing mode : just see other players as ghosts")
 
 #define VPACKAGENAME_LEVELS_WITH_NO_HIGHSCORE   _("Levels with no highscore")
 #define VPACKAGENAME_INCOMPLETED_LEVELS         _("Levels you have not completed")
@@ -725,6 +774,8 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define VPACKAGENAME_MEDIUM_LEVELS              _("Medium levels")
 #define VPACKAGENAME_LONG_LEVELS                _("Long levels")
 #define VPACKAGENAME_VERY_LONG_LEVELS           _("Very long levels")
+#define VPACKAGENAME_LEVELS_STOLEN              _("Stolen highscores")
+#define VPACKAGENAME_VOTE_NOT_LOCKED_LEVELS     _("Vote unlocked levels")
 
 #define VPACKAGENAME_DESC_LEVELS_WITH_NO_HIGHSCORE   _("Levels with no highscore in your room")
 #define VPACKAGENAME_DESC_INCOMPLETED_LEVELS         _("Levels you have not completed")
@@ -759,6 +810,8 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define VPACKAGENAME_DESC_MEDIUM_LEVELS          _("The medium levels (25 seconds to 60)")
 #define VPACKAGENAME_DESC_LONG_LEVELS            _("The long levels (1 minute to 2 minutes)")
 #define VPACKAGENAME_DESC_VERY_LONG_LEVELS       _("The longest levels (more than 2 minutes)")
+#define VPACKAGENAME_DESC_LEVELS_STOLEN          _("Levels for which you owned the highscore")
+#define VPACKAGENAME_DESC_VOTE_NOT_LOCKED_LEVELS _("Levels having votes unlocked")
 
 #define SYS_MSG_UGLY_MODE_ENABLED      	_("Ugly mode enabled")
 #define SYS_MSG_UGLY_MODE_DISABLED     	_("Ugly mode disabled")
@@ -774,10 +827,17 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define SYS_MSG_FPS_DISABLED            _("Fps disabled")
 #define SYS_MSG_AUDIO_ENABLED           _("Audio enabled")
 #define SYS_MSG_AUDIO_DISABLED          _("Audio disabled")
+#define SYS_MSG_TRAILCAM_NA             _("Trail Cam not available")
+#define SYS_MSG_TRAILCAM_ACTIVATED      _("Trail Cam activated")
+#define SYS_MSG_TRAILCAM_DEACTIVATED    _("Trail Cam deactivated")
+#define SYS_MSG_TRAIL_NA                _("Ghost Trail is not available")
+#define SYS_MSG_TRAIL_VISIBLE           _("Ghost Trail Rendering activated")
+#define SYS_MSG_TRAIL_INVISIBLE         _("Ghost Trail Rendering deactivated")
 
 #define SYS_MSG_TRAIN_NO_RESTORE_AVAIL  _("No training positions stored")
 #define SYS_MSG_TRAIN_RESTORING         _("Training position %i/%i restored")
 #define SYS_MSG_TRAIN_STORED            _("Stored as training position %i")
+#define SYS_MSG_UNSAVABLE_LEVEL         _("This level is not recordable (feature still not implemented).\nSorry.")
 
 #define SYS_MSG_NO_NEXT_HIGHSCORE(A)    ngettext("Can't find a highscore in the next %i level", "Can't find a highscore in the next %i levels", A)
 
