@@ -27,8 +27,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "helpers/Log.h"
 #include "xmscene/Level.h"
 #include "xmscene/Block.h"
+#include "xmscene/ScriptTimer.h"
 #include <sstream>
 
+#define STIMER_DELAY_DEFAULT 100
+#define STIMER_LOOPS_DEFAULT 0
+
 luaL_reg LuaLibGame::m_gameFuncs[] = {
   {"GetTime",                      LuaLibGame::L_Game_GetTime},
   {"Message",                      LuaLibGame::L_Game_Message},
@@ -36,7 +40,7 @@ luaL_reg LuaLibGame::m_gameFuncs[] = {
   {"MoveBlock",                    LuaLibGame::L_Game_MoveBlock},
   {"GetBlockPos",                  LuaLibGame::L_Game_GetBlockPos},
   {"SetBlockPos",                  LuaLibGame::L_Game_SetBlockPos},
-  {"SetPhysicsBlockPos",           LuaLibGame::L_Game_SetPhysicsBlockPos},
+  {"SetPhysicsBlockPos",           LuaLibGame::L_Game_SetBlockPos},
   {"PlaceInGameArrow",             LuaLibGame::L_Game_PlaceInGameArrow},
   {"PlaceScreenArrow",             LuaLibGame::L_Game_PlaceScreenArrow},
   {"HideArrow",                    LuaLibGame::L_Game_HideArrow},
@@ -86,7 +90,11 @@ luaL_reg LuaLibGame::m_gameFuncs[] = {
   {"StopMusic",                    LuaLibGame::L_Game_StopMusic},
   {"GetPlayerVelocity",            LuaLibGame::L_Game_GetPlayerVelocity},
   {"GetPlayerSpeed",               LuaLibGame::L_Game_GetPlayerSpeed},
-  {"GetPlayerAngle",               LuaLibGame::L_Game_GetPlayerAngle},   
+  {"GetPlayerAngle",               LuaLibGame::L_Game_GetPlayerAngle}, 
+  {"StartTimer",               LuaLibGame::L_Game_StartTimer},   
+  {"SetTimerDelay",               LuaLibGame::L_Game_SetTimerDelay}, 
+  {"StopTimer",               LuaLibGame::L_Game_StopTimer}, 
+	{"SetCameraPosition",               LuaLibGame::L_Game_SetCameraPosition}, 
   {NULL, NULL}
 };
 Scene*     LuaLibGame::m_exec_world              = NULL;
@@ -134,14 +142,14 @@ bool LuaLibGame::scriptCallBool(const std::string& FuncName,bool bDefault) {
   
   bool bRet = bDefault;
   
-    /* Fetch global function */
+  /* Fetch global function */
   lua_getglobal(m_pL,FuncName.c_str());
   
   /* Is it really a function and not just a pile of ****? */
   if(lua_isfunction(m_pL,-1)) {
     /* Call! */
     if(lua_pcall(m_pL,0,1,0) != 0) {
-        throw Exception("failed to invoke (bool) " + FuncName + std::string("(): ") + std::string(lua_tostring(m_pL,-1)));
+      throw Exception("failed to invoke (bool) " + FuncName + std::string("(): ") + std::string(lua_tostring(m_pL,-1)));
     }
     
     /* Retrieve return value */
@@ -360,13 +368,20 @@ int LuaLibGame::L_Game_Message(lua_State *pL) {
 int LuaLibGame::L_Game_IsPlayerInZone(lua_State *pL) {
   /* no event for this */
   bool res = false;
-  Zone* v_zone = m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1));
+  Zone* v_zone;
 
-  for(unsigned int i=0; i<m_exec_world->Players().size(); i++) {
-    if(m_exec_world->Players()[i]->isTouching(v_zone)) {
-      res = true;
+  try {
+    v_zone = m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1));
+
+    for(unsigned int i=0; i<m_exec_world->Players().size(); i++) {
+      if(m_exec_world->Players()[i]->isTouching(v_zone)) {
+	res = true;
+      }
     }
+  } catch(Exception &e) {
+    /* res will be false */
   }
+
   lua_pushboolean(pL, res?1:0);
   return 1;
 }
@@ -380,24 +395,22 @@ int LuaLibGame::L_Game_MoveBlock(lua_State *pL) {
 						 X_luaL_check_number(pL,3)));
   return 0;
 }
-
-int LuaLibGame::L_Game_SetPhysicsBlockPos(lua_State *pL) {
-  /* event for this */
-
-  m_exec_world->createGameEvent(new MGE_SetPhysicsBlockPos(m_exec_world->getTime(),
-						 luaL_checkstring(pL,1),
-						 X_luaL_check_number(pL,2),
-						 X_luaL_check_number(pL,3)));
-  return 0;
-}
   
 int LuaLibGame::L_Game_GetBlockPos(lua_State *pL) {
   /* no event for this */
 
   /* Find the specified block and return its position */
-  Block* pBlock = m_exec_world->getLevelSrc()->getBlockById(luaL_checkstring(pL,1));
-  lua_pushnumber(pL,pBlock->DynamicPosition().x);
-  lua_pushnumber(pL,pBlock->DynamicPosition().y);
+  Block* pBlock;
+
+  try {
+    pBlock = m_exec_world->getLevelSrc()->getBlockById(luaL_checkstring(pL,1));
+    lua_pushnumber(pL,pBlock->DynamicPosition().x);
+    lua_pushnumber(pL,pBlock->DynamicPosition().y);
+  } catch(Exception &e) {
+    lua_pushnumber(pL, 0);
+    lua_pushnumber(pL, 0);
+  }
+
   return 2;
 }
   
@@ -461,7 +474,14 @@ int LuaLibGame::L_Game_GetEntityPos(lua_State *pL) {
   /* no event for this */
 
   /* Find the specified entity and return its position */
-  Entity *p = m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1));
+  Entity *p;
+
+  try {
+    p = m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1));
+  } catch(Exception &e) {
+    p = NULL;
+  }
+
   if(p != NULL) {
     lua_pushnumber(pL,p->DynamicPosition().x);
     lua_pushnumber(pL,p->DynamicPosition().y);
@@ -476,7 +496,11 @@ int LuaLibGame::L_Game_GetEntityPos(lua_State *pL) {
   
 int LuaLibGame::L_Game_GetEntityRadius(lua_State *pL) {
   /* no event for this */
-  lua_pushnumber(pL, m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1))->Size());
+  try {
+    lua_pushnumber(pL, m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1))->Size());
+  } catch(Exception &e) {
+    lua_pushnumber(pL, 0);
+  }
   return 1;
 }
 
@@ -485,7 +509,11 @@ int LuaLibGame::L_Game_IsEntityTouched(lua_State *pL) {
 
   bool v_touch = false;
   if(m_exec_world->Players().size() > 0) {
-    v_touch = m_exec_world->Players()[0]->isTouching(m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1)));
+    try {
+      v_touch = m_exec_world->Players()[0]->isTouching(m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1)));
+    } catch(Exception &e) {
+      /* v_touch will be false */
+    }
   }
 
   lua_pushnumber(pL, v_touch? 1:0);
@@ -508,8 +536,8 @@ int LuaLibGame::L_Game_SetKeyHook(lua_State *pL) {
   if(m_exec_activeInputHandler != NULL) {
     try {
       m_exec_activeInputHandler->addScriptKeyHook(m_exec_world, luaL_checkstring(pL,1), luaL_checkstring(pL,2));
-    } catch(Exception &e) {
-      m_exec_world->gameMessage("** Warning ** : addScriptKeyHook failed", true);      
+    } catch(Exception &e) {  
+			luaL_error (pL, "AddScriptKeyHook failed");    
     }
   }
   return 0;
@@ -662,6 +690,14 @@ int LuaLibGame::L_Game_CameraMove(lua_State *pL) {
   return 0;
 }
 
+int LuaLibGame::L_Game_SetCameraPosition(lua_State *pL) {
+  /* event for this */
+  m_exec_world->createGameEvent(new MGE_CameraSetPos(m_exec_world->getTime(),
+						  X_luaL_check_number(pL,1),
+						  X_luaL_check_number(pL,2)));
+  return 0;
+}
+
 int LuaLibGame::L_Game_KillPlayer(lua_State *pL) {
   m_exec_world->createGameEvent(new MGE_PlayersDie(m_exec_world->getTime(), false));
   return 0;
@@ -694,16 +730,22 @@ int LuaLibGame::L_Game_PenaltyTime(lua_State *pL) {
 
 int LuaLibGame::L_Game_IsAPlayerInZone(lua_State *pL) {
   /* no event for this */
-  Zone* v_zone = m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1));
-  int v_player = (int)X_luaL_check_number(pL, 2);
+  Zone* v_zone;
+  int v_player;
 
+  try {
+    v_zone = m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1));
+    v_player = (int)X_luaL_check_number(pL, 2);
+    
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    std::ostringstream v_txt_player;
-    v_txt_player << v_player;
-    throw Exception("Invalid player " + v_txt_player.str());
+    luaL_error (pL, "Invalid player number");
+  }
+
+    lua_pushboolean(pL, m_exec_world->Players()[v_player]->isTouching(v_zone)?1:0);
+  } catch(Exception &e) {
+    lua_pushboolean(pL, 0);
   }
 
-  lua_pushboolean(pL, m_exec_world->Players()[v_player]->isTouching(v_zone)?1:0);
   return 1;
 }
 
@@ -713,10 +755,7 @@ int LuaLibGame::L_Game_SetAPlayerPosition(lua_State *pL) {
   int v_player = (int)X_luaL_check_number(pL,4);
 
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    std::ostringstream v_txt_player;
-    v_txt_player << v_player;
-    printf("player is %i\n", v_player);
-    //throw Exception("Invalid player " + v_txt_player.str());
+		luaL_error (pL, "Invalid player number");
   }
 
   m_exec_world->createGameEvent(new MGE_SetPlayerPosition(m_exec_world->getTime(),
@@ -735,9 +774,7 @@ int LuaLibGame::L_Game_GetAPlayerPosition(lua_State *pL) {
   int v_player = (int)X_luaL_check_number(pL,1);
 
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    std::ostringstream v_txt_player;
-    v_txt_player << v_player;
-    throw Exception("Invalid player " + v_txt_player.str());
+		luaL_error (pL, "Invalid player number");
   }
 
   x = m_exec_world->Players()[v_player]->getState()->CenterP.x;
@@ -755,9 +792,7 @@ int LuaLibGame::L_Game_KillAPlayer(lua_State *pL) {
   int v_player = (int)X_luaL_check_number(pL,1);
 
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    std::ostringstream v_txt_player;
-    v_txt_player << v_player;
-    throw Exception("Invalid player " + v_txt_player.str());
+		luaL_error (pL, "Invalid player number");
   }
 
   m_exec_world->createGameEvent(new MGE_PlayerDies(m_exec_world->getTime(), false, v_player));
@@ -768,9 +803,7 @@ int LuaLibGame::L_Game_WinAPlayer(lua_State *pL) {
   int v_player = (int)X_luaL_check_number(pL,1);
 
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    std::ostringstream v_txt_player;
-    v_txt_player << v_player;
-    throw Exception("Invalid player " + v_txt_player.str());
+		luaL_error (pL, "Invalid player number");
   }
 
   m_exec_world->makePlayerWin(v_player);
@@ -830,42 +863,109 @@ int LuaLibGame::L_Game_StopMusic(lua_State *pL) {
   return 0;
 }
 
+/* by Tuhoojabotti */
 int LuaLibGame::L_Game_GetPlayerVelocity(lua_State *pL) {
   /* no event for this */
   int v_player = (int)X_luaL_check_number(pL,1);
 
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    throw Exception("Invalid player");
+		luaL_error (pL, "Invalid player number");
   }
   lua_pushnumber(pL, m_exec_world->Players()[v_player]->getBikeLinearVel());
 
   return 1;
 }
-
+/* by Tuhoojabotti */
 int LuaLibGame::L_Game_GetPlayerSpeed(lua_State *pL) {
   /* no event for this */
   int v_player = (int)X_luaL_check_number(pL,1);
   
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    throw Exception("Invalid player");
+		luaL_error (pL, "Invalid player number");
   }
   lua_pushnumber(pL, m_exec_world->Players()[v_player]->getBikeEngineSpeed());
 
   return 1;
 }
-
+/* by Tuhoojabotti */
 int LuaLibGame::L_Game_GetPlayerAngle(lua_State *pL) {
   /* no event for this */
   int v_player = (int)X_luaL_check_number(pL,1);
   
   if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
-    throw Exception("Invalid player");
+		luaL_error (pL, "Invalid player number");
   }
   lua_pushnumber(pL, m_exec_world->Players()[v_player]->getAngle());
 
   return 1; //return 1 value
 }
 
+/*=====================================================
+        Script Timer Functions! by tuhoojabotti
+=====================================================*/
+//START
+int LuaLibGame::L_Game_StartTimer(lua_State *pL) {
+	args_CheckNumberOfArguments(pL, 1, 3); //we need 1 or 3 args
+	//set the defaults
+  int v_numargs=args_numberOfArguments(pL); 
+  std::string v_name="";
+	int v_delay = STIMER_DELAY_DEFAULT;
+	int v_loops=STIMER_LOOPS_DEFAULT;
+	ScriptTimer* v_timer=NULL;
+  //get parameters
+	v_name=(std::string)luaL_checkstring(pL,1);
+	v_timer=m_exec_world->getScriptTimerByName(v_name);
+	//check the optional args
+	if(v_numargs>1){
+		v_delay=(int)luaL_checknumber(pL,2);
+		if(v_delay<1){luaL_error (pL, "StartTimer: delay can't be smaller than 1.");}
+	}
+	if(v_numargs>2){
+		v_loops=(int)luaL_checknumber(pL,3);
+		if(v_loops<0){luaL_error (pL, "StartTimer: loops can't be smaller than 0.");}
+	}
+	//if timer is not found
+	if(v_timer==NULL){
+		m_exec_world->createScriptTimer(v_name,v_delay,v_loops); //create timer
+	}else{
+		if(v_numargs == 1){ //only name given
+			v_timer->StartTimer(); //start the timer
+		}else{ //numarg is not 1 so it can only be 2 or 3 which is okay
+			v_timer->ResetTimer(v_delay,v_loops,m_exec_world->getTime());
+			/* For example: if only delay is given then the loops=0 (default) */
+		}
+	}
+  return 0; //return no values to the script
+}
+//SET DELAY
+int LuaLibGame::L_Game_SetTimerDelay(lua_State *pL) {
+	args_CheckNumberOfArguments(pL, 2, 2); //exactly 2 args needed
+  std::string v_name=(std::string)luaL_checkstring(pL,1);
+	int v_delay=(int)luaL_checknumber(pL,2);
+	ScriptTimer* v_timer=m_exec_world->getScriptTimerByName(v_name);
+	if(v_timer!=NULL){
+		v_timer->SetTimerDelay(v_delay);
+	}else{
+		luaL_error (pL, "An error occured, timer doesn't exist!");   
+	}
+	return 0; //return no values to the script
+}
+//STOP
+int LuaLibGame::L_Game_StopTimer(lua_State *pL) {
+	args_CheckNumberOfArguments(pL, 1, 1); //exactly 1 arg needed
+  std::string v_name = (std::string)luaL_checkstring(pL,1); //get name
+  ScriptTimer* v_timer=m_exec_world->getScriptTimerByName(v_name);
+  if(v_timer!=NULL){ //timer is found
+		v_timer->PauseTimer(); //pause it
+  }else{
+		luaL_error (pL, "An error occured, timer doesn't exist!"); 
+	}
+  return 0; //return no values to the script
+}
+/*=====================================================
+            Script Helpers
+=====================================================*/
+
 int LuaLibGame::args_numberOfArguments(lua_State *pL) {
   return lua_gettop(pL);
 }
@@ -875,11 +975,11 @@ void LuaLibGame::args_CheckNumberOfArguments(lua_State *pL, int i_from, int i_to
 
   if(i_to == -1) {
     if(n != i_from) {
-      throw Exception("Invalid number of arguments");
+      luaL_error (pL, "Invalid number of arguments");  
     }
   } else {
     if(n < i_from || n > i_to) {
-      throw Exception("Invalid number of arguments");
+      luaL_error (pL, "Invalid number of arguments");  
     }
   }
 }
