@@ -64,7 +64,6 @@ private:
   static int L_Game_MoveBlock(lua_State *pL);
   static int L_Game_GetBlockPos(lua_State *pL);
   static int L_Game_SetBlockPos(lua_State *pL);
-  static int L_Game_SetPhysicsBlockPos(lua_State *pL);
   static int L_Game_PlaceInGameArrow(lua_State *pL);
   static int L_Game_PlaceScreenArrow(lua_State *pL);
   static int L_Game_HideArrow(lua_State *pL);
@@ -115,6 +114,12 @@ private:
   static int L_Game_GetPlayerVelocity(lua_State *pL);
   static int L_Game_GetPlayerSpeed(lua_State *pL);
   static int L_Game_GetPlayerAngle(lua_State *pL);
+	static int L_Game_SetCameraPosition(lua_State *pL);
+  /* Script Timer Functions*/
+  static int L_Game_StartTimer(lua_State *pL);  
+	static int L_Game_SetTimerDelay(lua_State *pL);  
+  static int L_Game_StopTimer(lua_State *pL);
+	
 
   /* get the number of arguments */
   static int args_numberOfArguments(lua_State *pL);
