@@ -34,6 +34,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "helpers/Log.h"
 #include "helpers/SwapEndian.h"
+#include "helpers/FileCompression.h"
 #include "GameEvents.h"
 #include "Game.h"
 #include "xmscene/Bike.h"
@@ -78,10 +79,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     }
   }
   
-  void Replay::finishReplay(bool bFinished, int finishTime) {
+  void Replay::finishReplay(bool bFinished, int finishTime, int i_format) {
     m_finishTime = finishTime;
     m_bFinished = bFinished;
-    saveReplay();
+    saveReplay(i_format);
   }
   
   void Replay::createReplay(const std::string &FileName, const std::string &LevelID,
@@ -95,13 +96,83 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     initOutput(1024);
   }
   
-  void Replay::saveReplay(void) {
-    /* Save it */
+  void Replay::saveReplay(int i_format) {
+
     FileHandle *pfh = FS::openOFile(std::string("Replays/") + m_FileName);
     if(pfh == NULL) {
       LogWarning("Failed to open replay file for output: %s",(std::string("Replays/") + m_FileName).c_str());
       return;
     }        
+
+    switch(i_format) {
+
+      // case 0: do not use format 0 anymore, it's the same as 1 + events
+    case 1:
+      saveReplay_1(pfh);
+      break;
+
+    case 2:
+      saveReplay_2(pfh);
+      break;
+
+    default:
+      FS::closeFile(pfh);
+      throw Exception("Invalid replay format");
+    }
+
+    FS::closeFile(pfh);
+  }
+
+  void Replay::saveReplay_2(FileHandle *pfh) {
+    const char *pcData;
+    int nDataSize;
+    char *pcCompressedData;
+    int nCompressedDataSize;
+
+    DBuffer v_replay;
+
+    /* keep header uncompressed to be faster to read just it */
+
+    /* Header */
+    FS::writeByte(pfh,2); /* Version: 2 */
+    FS::writeString(pfh,m_LevelID);
+    FS::writeString(pfh,m_PlayerName);
+    FS::writeBool(pfh,m_bFinished);
+    FS::writeFloat_LE(pfh, GameApp::timeToFloat(m_finishTime));
+    FS::writeFloat_LE(pfh,m_fFrameRate);
+    FS::writeInt_LE(pfh,m_nStateSize);
+
+    /* ***** ***** ***** ***** ***** **/
+    /* compress all except the header */
+    /* ***** ***** ***** ***** ***** **/
+
+    v_replay.initOutput(32);
+
+    /* Events */
+    pcData    = convertOutputToInput();
+    nDataSize = numRemainingBytes();
+
+    v_replay << nDataSize;
+    v_replay.writeBuf(pcData, nDataSize);
+    
+    /* Chunks */
+    v_replay << m_Chunks.size();
+    for(unsigned int i=0;i<m_Chunks.size();i++) {
+      v_replay << m_Chunks[i]->nNumStates;
+      v_replay.writeBuf(m_Chunks[i]->pcChunkData, m_nStateSize * m_Chunks[i]->nNumStates);
+    }
+
+    /* zip and write into the file */
+    pcData    = v_replay.convertOutputToInput();
+    nDataSize = v_replay.numRemainingBytes();
+    pcCompressedData = FileCompression::zcompress(pcData, nDataSize, nCompressedDataSize);
+    FS::writeInt_LE(pfh, nDataSize);
+    FS::writeInt_LE(pfh, nCompressedDataSize);
+    FS::writeBuf(pfh, (char *)pcCompressedData, nCompressedDataSize); 
+    free(pcCompressedData);
+  }
+
+  void Replay::saveReplay_1(FileHandle *pfh) {
     
     /* Write header */
     FS::writeByte(pfh,1); /* Version: 1 */
@@ -174,11 +245,258 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 	FS::writeBuf(pfh,m_Chunks[i]->pcChunkData,m_nStateSize * m_Chunks[i]->nNumStates);
       }
     }
-    
-    /* Clean up */
-    FS::closeFile(pfh);
   }
   
+void Replay::openReplay_2(FileHandle *pfh, bool bDisplayInformation) {
+  DBuffer v_replay;
+  int v_nDataSize;
+  char *v_pcData;
+  int v_nCompressedDataSize;
+  char *v_pcCompressedData;
+
+  /* Header */
+  m_LevelID = FS::readString(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %s\n", "Level Id", m_LevelID.c_str());
+  }
+
+  m_PlayerName = FS::readString(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %s\n", "Player", m_PlayerName.c_str());
+  }      
+      
+  m_bFinished = FS::readBool(pfh);
+  m_finishTime = GameApp::floatToTime(FS::readFloat_LE(pfh));
+  if(bDisplayInformation) {
+    if(m_bFinished) {
+      printf("%-30s: %.2f (%f)\n", "Finish time", m_finishTime / 100.0, m_finishTime / 100.0);
+    } else {
+      printf("%-30s: %s\n", "Finish time", "unfinished");
+    }
+  }
+
+  m_fFrameRate = FS::readFloat_LE(pfh);
+
+  m_nStateSize = FS::readInt_LE(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %i\n", "State size", m_nStateSize);
+  } 
+
+  /* zuncompressed */
+  v_nDataSize           = FS::readInt_LE(pfh);
+  v_nCompressedDataSize = FS::readInt_LE(pfh);
+
+  v_pcData = (char*) malloc(v_nDataSize);
+  if(v_pcData == NULL) {
+    throw Exception("Unable to malloc for decompression");
+  }
+  v_pcCompressedData = (char*) malloc(v_nCompressedDataSize);
+  if(v_pcCompressedData == NULL) {
+    free(v_pcData);
+    throw Exception("Unable to malloc for decompression");
+  }
+  FS::readBuf(pfh, v_pcCompressedData, v_nCompressedDataSize);
+  try {
+    FileCompression::zuncompress(v_pcCompressedData, v_nCompressedDataSize, v_pcData, v_nDataSize);
+  } catch(Exception &e) {
+    free(v_pcData);
+    free(v_pcCompressedData);
+    throw e;
+  }
+  free(v_pcCompressedData);
+  v_replay.initInput(v_pcData , v_nDataSize);
+
+  /* Events */
+  v_replay >> m_nInputEventsDataSize;
+  if(bDisplayInformation) {
+    printf("%-30s: %i\n", "Events data size", m_nInputEventsDataSize);
+  } 
+  m_pcInputEventsData = new char [m_nInputEventsDataSize];
+  v_replay.readBuf(m_pcInputEventsData, m_nInputEventsDataSize);
+  initInput(m_pcInputEventsData, m_nInputEventsDataSize);        
+
+  /* Chunks */
+  unsigned int nNumChunks;
+  v_replay >> nNumChunks;
+  if(bDisplayInformation) {
+    printf("%-30s: %i\n", "Number of chunks", nNumChunks);
+  }
+  if(nNumChunks == 0) {
+    _FreeReplay();
+    LogWarning("try to open a replay with no chunk");
+    throw Exception("Replay with no chunk !");
+  }
+
+  for(unsigned int i=0;i<nNumChunks;i++) {
+    if(bDisplayInformation) {
+      printf("Chunk %02i\n", i);
+    }  
+  
+    ReplayStateChunk* Chunk = new ReplayStateChunk();
+    v_replay >> Chunk->nNumStates;
+
+    if(bDisplayInformation) {
+      printf("   %-27s: %i\n", "Number of states", Chunk->nNumStates);
+    } 
+    
+    Chunk->pcChunkData = new char [Chunk->nNumStates * m_nStateSize];
+
+    v_replay.readBuf(Chunk->pcChunkData, m_nStateSize*Chunk->nNumStates);
+    m_Chunks.push_back(Chunk);
+  }
+}
+
+void Replay::openReplay_1(FileHandle *pfh, bool bDisplayInformation, int nVersion) {
+  /* Little/big endian safety check */
+  if(FS::readInt_LE(pfh) != 0x12345678) {
+    LogWarning("Sorry, the replay you're trying to open are not endian-compatible with your computer!");
+    throw Exception("Unable to open the replay");        
+  }
+  
+  /* Read level ID */
+  m_LevelID = FS::readString(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %s\n", "Level Id", m_LevelID.c_str());
+  }
+
+  /* Read player name */
+  m_PlayerName = FS::readString(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %s\n", "Player", m_PlayerName.c_str());
+  }      
+
+  /* Read replay frame rate */
+  m_fFrameRate = FS::readFloat_LE(pfh);
+
+  /* Read state size */
+  m_nStateSize = FS::readInt_LE(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %i\n", "State size", m_nStateSize);
+  } 
+      
+  /* Read finish time if any */
+  m_bFinished = FS::readBool(pfh);
+  m_finishTime = GameApp::floatToTime(FS::readFloat_LE(pfh));
+  if(bDisplayInformation) {
+    if(m_bFinished) {
+      printf("%-30s: %.2f (%f)\n", "Finish time", m_finishTime / 100.0, m_finishTime / 100.0);
+    } else {
+      printf("%-30s: %s\n", "Finish time", "unfinished");
+    }
+  }
+
+  /* Version 1 includes event data */
+  if(nVersion == 1) {
+    /* Read uncompressed size */
+    m_nInputEventsDataSize = FS::readInt_LE(pfh);
+    if(bDisplayInformation) {
+      printf("%-30s: %i\n", "Events data size", m_nInputEventsDataSize);
+    } 
+    m_pcInputEventsData = new char [m_nInputEventsDataSize];
+        
+    /* Compressed? */
+    if(FS::readBool(pfh)) {
+      /* Compressed */          
+      int nCompressedEventsSize = FS::readInt_LE(pfh);
+      if(bDisplayInformation) {
+	printf("%-30s: %i\n", "Compressed events data size", nCompressedEventsSize);
+      } 
+          
+      char *pcCompressedEvents = new char [nCompressedEventsSize];
+      FS::readBuf(pfh,pcCompressedEvents,nCompressedEventsSize);
+          
+      /* Unpack */
+      uLongf nDestLen = m_nInputEventsDataSize;
+      uLongf nSrcLen = nCompressedEventsSize;
+      int nZRet = uncompress((Bytef *)m_pcInputEventsData,&nDestLen,(Bytef *)pcCompressedEvents,nSrcLen);
+      if(nZRet != Z_OK || nDestLen != m_nInputEventsDataSize) {
+	delete [] pcCompressedEvents;
+	delete [] m_pcInputEventsData; m_pcInputEventsData = NULL;
+	_FreeReplay();
+	LogWarning("Failed to uncompress events in replay");
+	throw Exception("Unable to open the replay");
+      }
+      
+      /* Clean up */
+      delete [] pcCompressedEvents;
+    }
+    else {
+      /* Not compressed */
+      FS::readBuf(pfh,m_pcInputEventsData,m_nInputEventsDataSize);
+    }
+    
+    /* Set up input stream */
+    initInput(m_pcInputEventsData,m_nInputEventsDataSize);        
+  }
+  
+  /* Read chunks */
+  unsigned int nNumChunks = FS::readInt_LE(pfh);
+  if(bDisplayInformation) {
+    printf("%-30s: %i\n", "Number of chunks", nNumChunks);
+  }
+  if(nNumChunks == 0) {
+    _FreeReplay();
+    LogWarning("try to open a replay with no chunk");
+    throw Exception("Replay with no chunk !");
+  }
+
+  for(unsigned int i=0;i<nNumChunks;i++) {
+    if(bDisplayInformation) {
+      printf("Chunk %02i\n", i);
+    }  
+  
+    ReplayStateChunk* Chunk = new ReplayStateChunk();
+    Chunk->nNumStates = FS::readInt_LE(pfh);
+
+    if(bDisplayInformation) {
+      printf("   %-27s: %i\n", "Number of states", Chunk->nNumStates);
+    } 
+    
+    Chunk->pcChunkData = new char [Chunk->nNumStates * m_nStateSize];
+        
+    /* Compressed or not compressed? */
+    if(FS::readBool(pfh)) {
+      if(bDisplayInformation) {
+	printf("   %-27s: %s\n", "Compressed data", "true");
+      } 
+
+      /* Compressed! - read compressed size */
+      int nCompressedSize = FS::readInt_LE(pfh);
+      if(bDisplayInformation) {
+	printf("   %-27s: %i\n", "Compressed states size", nCompressedSize);
+      }
+
+      /* Read compressed data */
+      unsigned char *pcCompressed = new unsigned char [nCompressedSize];
+      FS::readBuf(pfh,(char *)pcCompressed,nCompressedSize);
+         
+      /* Uncompress it */           
+      uLongf nDestLen = Chunk->nNumStates * m_nStateSize;
+      uLongf nSrcLen = nCompressedSize;
+      int nZRet = uncompress((Bytef *)Chunk->pcChunkData,&nDestLen,(Bytef *)pcCompressed,nSrcLen);
+      if(nZRet != Z_OK || nDestLen != Chunk->nNumStates * m_nStateSize) {
+	LogWarning("Failed to uncompress chunk %d in replay");
+	delete [] pcCompressed;
+	Chunk->pcChunkData = NULL;
+	_FreeReplay();
+	throw Exception("Unable to open the replay");
+      }
+
+      /* Clean up */
+      delete [] pcCompressed;
+    } else {
+      if(bDisplayInformation) {
+	printf("   %-27s: %s\n", "Compressed data", "false");
+      } 
+      
+      /* Not compressed! */
+      FS::readBuf(pfh,Chunk->pcChunkData,m_nStateSize*Chunk->nNumStates);
+    }
+        
+    m_Chunks.push_back(Chunk);
+  }
+}
+
   std::string Replay::openReplay(const std::string &FileName, std::string &Player, bool bDisplayInformation) {
     /* Try opening as if it is a full path */
     FileHandle *pfh = FS::openIFile(FileName, true);
@@ -198,179 +516,50 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     /* Read header */
     int nVersion = FS::readByte(pfh); 
     if(bDisplayInformation) {
-      LogInfo("%-30s: %i\n", "Replay file version", nVersion);
+      printf("%-30s: %i\n", "Replay file version", nVersion);
     }
        
     /* Supported version? */
-    if(nVersion != 0 && nVersion != 1) {
+    switch(nVersion) {
+
+    case 0:
+    case 1:
+      try {
+	openReplay_1(pfh, bDisplayInformation, nVersion);
+      } catch(Exception &e) {
+	FS::closeFile(pfh);
+	throw e;
+      }
+      break;
+
+    case 2:
+      try {
+	openReplay_2(pfh, bDisplayInformation);
+      } catch(Exception &e) {
+	FS::closeFile(pfh);
+	throw e;
+      }
+      break;
+
+    default:
       FS::closeFile(pfh);
       LogWarning("Unsupported replay file version (%d): %s",nVersion,(std::string("Replays/") + FileName).c_str());
       throw Exception("Unable to open the replay (unsupported version)");
-    } else {
-      /* Little/big endian safety check */
-      if(FS::readInt_LE(pfh) != 0x12345678) {
-        FS::closeFile(pfh);
-        LogWarning("Sorry, the replay you're trying to open are not endian-compatible with your computer!");
-        throw Exception("Unable to open the replay");        
-      }
-  
-      /* Read level ID */
-      m_LevelID = FS::readString(pfh);
-      if(bDisplayInformation) {
-	LogInfo("%-30s: %s\n", "Level Id", m_LevelID.c_str());
-      }
 
-      /* Read player name */
-      Player = m_PlayerName = FS::readString(pfh);
-      if(bDisplayInformation) {
-	LogInfo("%-30s: %s\n", "Player", Player.c_str());
-      }      
-
-      /* Read replay frame rate */
-      m_fFrameRate = FS::readFloat_LE(pfh);
-
-      /* Read state size */
-      m_nStateSize = FS::readInt_LE(pfh);
-      if(bDisplayInformation) {
-	LogInfo("%-30s: %i\n", "State size", m_nStateSize);
-      } 
-      
-      /* Read finish time if any */
-      m_bFinished = FS::readBool(pfh);
-      m_finishTime = GameApp::floatToTime(FS::readFloat_LE(pfh));
-      if(bDisplayInformation) {
-	if(m_bFinished) {
-	  LogInfo("%-30s: %.2f (%f)\n", "Finish time", m_finishTime / 100.0, m_finishTime / 100.0);
-	} else {
-	  LogInfo("%-30s: %s\n", "Finish time", "unfinished");
-	}
-      }
-
-      /* Version 1 includes event data */
-      if(nVersion == 1) {
-        /* Read uncompressed size */
-        m_nInputEventsDataSize = FS::readInt_LE(pfh);
-	if(bDisplayInformation) {
-	  LogInfo("%-30s: %i\n", "Events data size", m_nInputEventsDataSize);
-	} 
-        m_pcInputEventsData = new char [m_nInputEventsDataSize];
-        
-        /* Compressed? */
-        if(FS::readBool(pfh)) {
-          /* Compressed */          
-          int nCompressedEventsSize = FS::readInt_LE(pfh);
-	  if(bDisplayInformation) {
-	    LogInfo("%-30s: %i\n", "Compressed events data size", nCompressedEventsSize);
-	  } 
-          
-          char *pcCompressedEvents = new char [nCompressedEventsSize];
-          FS::readBuf(pfh,pcCompressedEvents,nCompressedEventsSize);
-          
-          /* Unpack */
-          uLongf nDestLen = m_nInputEventsDataSize;
-          uLongf nSrcLen = nCompressedEventsSize;
-          int nZRet = uncompress((Bytef *)m_pcInputEventsData,&nDestLen,(Bytef *)pcCompressedEvents,nSrcLen);
-          if(nZRet != Z_OK || nDestLen != m_nInputEventsDataSize) {
-            delete [] pcCompressedEvents;
-            delete [] m_pcInputEventsData; m_pcInputEventsData = NULL;
-            FS::closeFile(pfh);
-            _FreeReplay();
-            LogWarning("Failed to uncompress events in replay: %s",FileName.c_str());
-            throw Exception("Unable to open the replay");
-          }
-          
-          /* Clean up */
-          delete [] pcCompressedEvents;
-        }
-        else {
-          /* Not compressed */
-          FS::readBuf(pfh,m_pcInputEventsData,m_nInputEventsDataSize);
-        }
-
-        /* Set up input stream */
-        initInput(m_pcInputEventsData,m_nInputEventsDataSize);        
-      }
-      
-      /* Read chunks */
-      unsigned int nNumChunks = FS::readInt_LE(pfh);
-      if(bDisplayInformation) {
-	LogInfo("%-30s: %i\n", "Number of chunks", nNumChunks);
-      }
-      if(nNumChunks == 0) {
-	FS::closeFile(pfh);
-	_FreeReplay();
-	LogWarning("try to open a replay with no chunk");
-	throw Exception("Replay with no chunk !");
-      }
-
-      for(unsigned int i=0;i<nNumChunks;i++) {
-	if(bDisplayInformation) {
-	  LogInfo("Chunk %02i\n", i);
-	}  
-  
-        ReplayStateChunk* Chunk = new ReplayStateChunk();
-        Chunk->nNumStates = FS::readInt_LE(pfh);
-
-	if(bDisplayInformation) {
-	  LogInfo("   %-27s: %i\n", "Number of states", Chunk->nNumStates);
-	} 
-
-        Chunk->pcChunkData = new char [Chunk->nNumStates * m_nStateSize];
-        
-        /* Compressed or not compressed? */
-        if(FS::readBool(pfh)) {
-	  if(bDisplayInformation) {
-	    LogInfo("   %-27s: %s\n", "Compressed data", "true");
-	  } 
-
-          /* Compressed! - read compressed size */
-          int nCompressedSize = FS::readInt_LE(pfh);
-	  if(bDisplayInformation) {
-	    LogInfo("   %-27s: %i\n", "Compressed states size", nCompressedSize);
-	  }
-
-          /* Read compressed data */
-          unsigned char *pcCompressed = new unsigned char [nCompressedSize];
-          FS::readBuf(pfh,(char *)pcCompressed,nCompressedSize);
-         
-          /* Uncompress it */           
-          uLongf nDestLen = Chunk->nNumStates * m_nStateSize;
-          uLongf nSrcLen = nCompressedSize;
-          int nZRet = uncompress((Bytef *)Chunk->pcChunkData,&nDestLen,(Bytef *)pcCompressed,nSrcLen);
-          if(nZRet != Z_OK || nDestLen != Chunk->nNumStates * m_nStateSize) {
-            LogWarning("Failed to uncompress chunk %d in replay: %s",i,FileName.c_str());
-            delete [] pcCompressed;
-            Chunk->pcChunkData = NULL;
-            FS::closeFile(pfh);
-            _FreeReplay();
-            throw Exception("Unable to open the replay");
-          }
-
-          /* Clean up */
-          delete [] pcCompressed;
-        }
-        else {
-	  if(bDisplayInformation) {
-	    LogInfo("   %-27s: %s\n", "Compressed data", "false");
-	  } 
-
-          /* Not compressed! */
-          FS::readBuf(pfh,Chunk->pcChunkData,m_nStateSize*Chunk->nNumStates);
-        }
-        
-        m_Chunks.push_back(Chunk);
-      }
+      break;
     }
-    
+
     /* Clean up */
     FS::closeFile(pfh);
     
+    Player = m_PlayerName;
+
     m_nCurChunk = 0;
     m_nCurState = 0.0;
     
     /* Reconstruct game events that are going to happen during the replay */
     if(bDisplayInformation) {
-      LogInfo("%-30s:\n", "Game Events");
+      printf("%-30s:\n", "Game Events");
     }
 
     /* unserialize events */
@@ -546,38 +735,54 @@ bool Replay::nextState(int p_frames) {
       }
       
       int nVersion = FS::readByte(pfh);
-      if(nVersion != 0 && nVersion != 1) {
+      if(nVersion != 0 && nVersion != 1 && nVersion != 2) {
 	FS::closeFile(pfh);
 	return NULL;
       }
       
-      if(FS::readInt_LE(pfh) != 0x12345678) {   
-	FS::closeFile(pfh);
-	return NULL;
-      }
-  
-      std::string LevelID = FS::readString(pfh);
-      std::string Player  = FS::readString(pfh);
-      /*float fFrameRate    = */ FS::readFloat_LE(pfh);
-      /*int nStateSize      = */ FS::readInt_LE(pfh);
-      bool bFinished      = FS::readBool(pfh);
-      int finishTime   = GameApp::floatToTime(FS::readFloat_LE(pfh));
-                
-      ReplayInfo *pRpl     = new ReplayInfo;
+      ReplayInfo *pRpl = new ReplayInfo;
+      std::string LevelID;
+      std::string Player;
+      bool bFinished = true;
+      int finishTime = 0;
 
+      switch(nVersion) {
+      case 0:
+      case 1:
+	if(FS::readInt_LE(pfh) != 0x12345678) {   
+	  FS::closeFile(pfh);
+	  return NULL;
+	}
+	
+	LevelID       =    FS::readString(pfh);
+	Player        =    FS::readString(pfh);
+	/* fFrameRate = */ FS::readFloat_LE(pfh);
+	/* nStateSize = */ FS::readInt_LE(pfh);
+	bFinished     =    FS::readBool(pfh);
+	finishTime    = GameApp::floatToTime(FS::readFloat_LE(pfh));
+	break;
+
+      case 2:
+	LevelID       =    FS::readString(pfh);
+	Player        =    FS::readString(pfh);
+	bFinished     =    FS::readBool(pfh);
+	finishTime    = GameApp::floatToTime(FS::readFloat_LE(pfh));
+	break;
+      }
+	
       /* Set members */
       pRpl->Level = LevelID;
       pRpl->Name = p_ReplayName;
       pRpl->Player = Player;
       pRpl->IsFinished = bFinished;
-
+      
       if(bFinished) {
 	pRpl->finishTime = finishTime;
       } else {
 	pRpl->finishTime = -1;                
       }
-          
-      FS::closeFile(pfh);
+
+      FS::closeFile(pfh); 
       return pRpl;
   }
 
