@@ -23,6 +23,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "XMSession.h"
 #include "helpers/Log.h"
 #include "helpers/VExcept.h"
+#include "include/xm_SDL.h"
 
 /*===========================================================================
   Globals
@@ -47,7 +48,7 @@ void Sound::init(XMSession* i_session) {
     m_nSampleRate = n;
     break;
   default:
-    Logger::Log("** Warning ** : invalid audio sample rate, falling back to 22050");
+    LogWarning("invalid audio sample rate, falling back to 22050");
     m_nSampleRate = 22050;
     break;
   }      
@@ -58,7 +59,7 @@ void Sound::init(XMSession* i_session) {
     m_nSampleBits = n;
     break;
   default:
-	Logger::Log("** Warning ** : invalid audio sample bits, falling back to 16");
+	LogWarning("invalid audio sample bits, falling back to 16");
 	m_nSampleRate = 16;
 	break;
   }      
@@ -67,7 +68,7 @@ void Sound::init(XMSession* i_session) {
   
   /* Init SDL stuff */
   if(SDL_InitSubSystem(SDL_INIT_AUDIO) < 0) {
-    Logger::Log("** Warning ** : failed to initialize SDL audio (%s)",SDL_GetError());
+    LogWarning("failed to initialize SDL audio (%s)",SDL_GetError());
     return;
   }
  
@@ -76,7 +77,7 @@ void Sound::init(XMSession* i_session) {
   else nFormat = AUDIO_S16;
   
   if(Mix_OpenAudio(m_nSampleRate,nFormat,m_nChannels,2048) < 0) {
-    Logger::Log("** Warning ** : failed to open mixer device (%s)",Mix_GetError());
+    LogWarning("failed to open mixer device (%s)",Mix_GetError());
     SDL_QuitSubSystem(SDL_INIT_AUDIO);
     return;
   }
@@ -196,7 +197,8 @@ SoundSample *Sound::findSample(const std::string &File) {
     if(m_Samples[i]->Name == File)
       return m_Samples[i];
   }
-  return NULL;
+
+  return loadSample(File);
 }
 
 void Sound::playSampleByName(const std::string &Name,float fVolume) {
@@ -252,7 +254,7 @@ void Sound::playMusic(std::string i_musicPath) {
   }
   
   /* No music available, try loading */
-#if defined(WIN32) /* this works around a bug in SDL_mixer 1.2.7 on Windows */
+#if defined(WIN32) || defined(__amigaos4__)  /* this works around a bug in SDL_mixer 1.2.7 on Windows */
   SDL_RWops *rwfp;
   rwfp = SDL_RWFromFile(i_musicPath.c_str(), "rb");
   if(rwfp != NULL) {
@@ -271,6 +273,14 @@ void Sound::playMusic(std::string i_musicPath) {
   }
 }
 
+void Sound::togglePauseMusic() {
+    if(m_pMenuMusic != NULL && Mix_PlayingMusic() && Mix_PausedMusic() == false) {
+	Mix_PauseMusic();
+    } else if(m_pMenuMusic != NULL && Mix_PlayingMusic() && Mix_PausedMusic()) {
+        Mix_ResumeMusic();
+    }
+}
+
 void Sound::stopMusic() {
   if(m_pMenuMusic != NULL && Mix_PlayingMusic()) {
     Mix_HaltMusic();
