@@ -85,6 +85,11 @@ void Universe::removeAllWorlds() {
   m_scenes.clear();
 }
 
+void Universe::initPlayServer() {
+  // just one scene for all players
+  addScene();
+}
+
 void Universe::initPlay(int i_nbPlayer, bool i_multiScenes) {
   if(i_multiScenes) {
     for(int i=0; i<i_nbPlayer; i++) {
@@ -102,6 +107,7 @@ void Universe::initCameras(int nbPlayer) {
   int width  = GameApp::instance()->getDrawLib()->getDispWidth();
   int height = GameApp::instance()->getDrawLib()->getDispHeight();
   bool v_useActiveZoom = XMSession::instance()->enableActiveZoom();
+  bool v_useTrailCam = XMSession::instance()->enableTrailCam();
   
   if(m_scenes.size() <= 0) {
     return;
@@ -111,41 +117,41 @@ void Universe::initCameras(int nbPlayer) {
   default:
   case 1:
     m_scenes[0]->addCamera(Vector2i(0,0),
-			   Vector2i(width, height), v_useActiveZoom);
+			   Vector2i(width, height), v_useActiveZoom, v_useTrailCam);
     break;
   case 2:
     m_scenes[0]->addCamera(Vector2i(0,height/2),
-			   Vector2i(width, height), v_useActiveZoom);
+			   Vector2i(width, height), v_useActiveZoom, v_useTrailCam);
     if(m_scenes.size() == 1) {
       m_scenes[0]->addCamera(Vector2i(0,0),
-			     Vector2i(width, height/2), v_useActiveZoom);
+			     Vector2i(width, height/2), v_useActiveZoom, v_useTrailCam);
     } else {
       m_scenes[1]->addCamera(Vector2i(0,0),
-			     Vector2i(width, height/2), v_useActiveZoom);
+			     Vector2i(width, height/2), v_useActiveZoom, v_useTrailCam);
     }
     break;
   case 3:
   case 4:
     if(m_scenes.size() == 1) {
       m_scenes[0]->addCamera(Vector2i(0,height/2),
-			     Vector2i(width/2, height), v_useActiveZoom);
+			     Vector2i(width/2, height), v_useActiveZoom, v_useTrailCam);
       m_scenes[0]->addCamera(Vector2i(width/2,height/2),
-			     Vector2i(width, height), v_useActiveZoom);
+			     Vector2i(width, height), v_useActiveZoom, v_useTrailCam);
       m_scenes[0]->addCamera(Vector2i(0,0),
-			     Vector2i(width/2, height/2), v_useActiveZoom);
+			     Vector2i(width/2, height/2), v_useActiveZoom, v_useTrailCam);
       m_scenes[0]->addCamera(Vector2i(width/2,0),
-			     Vector2i(width, height/2), v_useActiveZoom);
+			     Vector2i(width, height/2), v_useActiveZoom, v_useTrailCam);
     } else {
       m_scenes[0]->addCamera(Vector2i(0,height/2),
-			     Vector2i(width/2, height), v_useActiveZoom);
+			     Vector2i(width/2, height), v_useActiveZoom, v_useTrailCam);
       m_scenes[1]->addCamera(Vector2i(width/2,height/2),
-			     Vector2i(width, height), v_useActiveZoom);
+			     Vector2i(width, height), v_useActiveZoom, v_useTrailCam);
       m_scenes[2]->addCamera(Vector2i(0,0),
-			     Vector2i(width/2, height/2), v_useActiveZoom);
+			     Vector2i(width/2, height/2), v_useActiveZoom, v_useTrailCam);
 
       if(nbPlayer == 4) {
 	m_scenes[3]->addCamera(Vector2i(width/2,0),
-			       Vector2i(width, height/2), v_useActiveZoom);
+			       Vector2i(width, height/2), v_useActiveZoom, v_useTrailCam);
       }
     }
     break;
@@ -154,7 +160,7 @@ void Universe::initCameras(int nbPlayer) {
   // the autozoom camera is a special one in multi player
   if(nbPlayer > 1){
     m_scenes[0]->addCamera(Vector2i(0,0),
-			   Vector2i(width, height), v_useActiveZoom);
+			   Vector2i(width, height), v_useActiveZoom, v_useTrailCam);
   }
   // current cam is autozoom one
   for(unsigned int i=0; i<m_scenes.size(); i++) {
@@ -185,14 +191,13 @@ void Universe::switchFollowCamera() {
   }
 }
 
-void Universe::isTheCurrentPlayAHighscore(bool& o_personal, bool& o_room) {
+void Universe::isTheCurrentPlayAHighscore(xmDatabase *pDb, bool& o_personal, bool& o_room) {
   int v_best_personal_time;
   int v_current_time;
   int v_best_room_time;
   char **v_result;
   unsigned int nrow;
   char *v_res;
-  xmDatabase *pDb = xmDatabase::instance("main");
 
   o_personal = o_room = false;
 
@@ -237,6 +242,17 @@ bool Universe::isAReplayToSave() const {
   return m_pJustPlayReplay != NULL;
 }
 
+bool Universe::isAnErrorOnSaving() const {
+
+  // fake an error on physics level
+  for(unsigned int i=0; i<m_scenes.size(); i++) {
+    if(m_scenes[i]->getLevelSrc()->isPhysics()) {
+      return true;
+    }
+  }
+  return false;
+}
+
 void Universe::finalizeReplay(bool i_finished) {
   if(m_scenes.size() != 1) {
     return;
@@ -250,7 +266,14 @@ void Universe::finalizeReplay(bool i_finished) {
   SerializedBikeState BikeState;
   Scene::getSerializedBikeState(m_scenes[0]->Players()[0]->getState(), m_scenes[0]->getTime(), &BikeState, m_scenes[0]->getPhysicsSettings());
   m_pJustPlayReplay->storeState(BikeState);
-  m_pJustPlayReplay->finishReplay(i_finished, i_finished ? m_scenes[0]->Players()[0]->finishTime() : 0);
+  m_pJustPlayReplay->finishReplay(i_finished, i_finished ? m_scenes[0]->Players()[0]->finishTime() : 0,
+				  1); // still always use the format 1
+				  /*
+				    use old format if level is not physics to allow people having an old version to read replays
+				    in the future (today is 28/06/2009), once everybody can read 2 version, use always 2 version
+				    
+				    m_scenes[0]->getLevelSrc()->isPhysics() ? 2 : 1);
+				  */
 }
 
 Replay* Universe::getCurrentReplay() {
@@ -276,13 +299,12 @@ void Universe::initReplay() {
   }
 }
 
-void Universe::saveReplay(const std::string &Name) {
+void Universe::saveReplay(xmDatabase *pDb, const std::string &Name) {
   /* This is simply a job of copying the Replays/Latest.rpl file into 
      Replays/Name.rpl */
 
   /* Try saving */
   std::string v_outputfile;
-  xmDatabase *pDb = xmDatabase::instance("main");
 
   if(!FS::copyFile("Replays/Latest.rpl",
 		   std::string("Replays/") + Name + std::string(".rpl"),
