@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -24,7 +23,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "VCommon.h"
 
-namespace vapp {
 
 	/*===========================================================================
 	User variable
@@ -76,6 +74,4 @@ namespace vapp {
 	    UserConfigVar *_FindVarByName(std::string Name);
 	};
 
-}
-
 #endif
