@@ -454,6 +454,9 @@ CURLcode FSWeb::performPostCurl(CURL *p_curl,
 void FSWeb::sendVote(const std::string& p_id_level,
 		     const std::string& p_difficulty_value,
 		     const std::string& p_quality_value,
+		     bool p_adminMode,
+		     const std::string& p_id_profile,
+		     const std::string& p_password,
 		     const std::string& p_url_to_transfert,
 		     WWWAppInterface *p_WebApp,
 		     const ProxySettings *p_proxy_settings,
@@ -494,6 +497,14 @@ void FSWeb::sendVote(const std::string& p_id_level,
   curl_formadd(&v_post, &v_last, CURLFORM_COPYNAME, "quality",
          CURLFORM_PTRCONTENTS, p_quality_value.c_str(), CURLFORM_END);
 
+  if(p_adminMode) {
+    curl_formadd(&v_post, &v_last, CURLFORM_COPYNAME, "login",
+		 CURLFORM_PTRCONTENTS, p_id_profile.c_str(), CURLFORM_END);
+    
+    curl_formadd(&v_post, &v_last, CURLFORM_COPYNAME, "password",
+		 CURLFORM_PTRCONTENTS, p_password.c_str(), CURLFORM_END);
+  }
+
   v_res = performPostCurl(v_curl, v_post, p_url_to_transfert, v_destinationFile, p_WebApp, p_proxy_settings);
 
   fclose(v_destinationFile);
@@ -1036,7 +1047,15 @@ void WebThemes::updateTheme(xmDatabase* i_pDb, const std::string& i_id_theme, WW
 	/* if v_md5Dist == "", don't download ; it's a manually adding */
 	if(FS::fileExists((*v_required_files)[i].filepath) == false || (v_md5Local != v_md5Dist && v_md5Dist != "")) {
 	  v_data.v_nb_files_performed = v_nb_files_performed;
-	  
+
+	  if(FS::fileExists((*v_required_files)[i].filepath) == false) {
+	    LogInfo("The file %s must be downloaded because it is missing on the system", (*v_required_files)[i].filepath.c_str());
+	  } else {
+	    if(v_md5Local != v_md5Dist && v_md5Dist != "") {
+	      LogInfo("The file %s must be downloaded because local md5sum=%s and distant md5sum=%s", (*v_required_files)[i].filepath.c_str(), v_md5Local.c_str(), v_md5Dist.c_str());
+	    }
+	  }
+
 	  float v_percentage = (((float)v_nb_files_performed) * 100.0) / ((float)v_nb_files_to_download);
 	  if(i_WebLevelApp != NULL) {
 	    i_WebLevelApp->setTaskProgress(v_percentage);
