@@ -151,6 +151,9 @@ class FSWeb {
   static void sendVote(const std::string& p_id_level,
 		       const std::string& p_difficulty_value,
 		       const std::string& p_quality_value,
+		       bool p_adminMode,
+		       const std::string& p_id_profile,
+		       const std::string& p_password,
 		       const std::string& p_url_to_transfert,
 		       WWWAppInterface *p_WebApp,
 		       const ProxySettings *p_proxy_settings,
