@@ -24,6 +24,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VFileIO.h"
 #include <sstream>
 #include <stdlib.h>
+#include <cstdio>
 
 XMArguments::XMArguments() {
   m_opt_pack   	       = false;
@@ -39,6 +40,7 @@ XMArguments::XMArguments() {
   m_opt_noexts         = false;
   m_opt_drawlib        = false;
   m_opt_ugly           = false;
+  m_opt_noLog          = false;
   m_opt_nowww          = false;
   m_opt_help           = false;
   m_opt_verbose        = false;
@@ -68,7 +70,11 @@ XMArguments::XMArguments() {
   m_opt_hidePlayingInformation  = false;
   m_opt_forceChildrenCompliant  = false;
   m_opt_default_theme           = false;
-  m_opt_noDBDirsCheck = false;
+  m_opt_noDBDirsCheck 	      	= false;
+  m_opt_serverOnly    	      	= false;
+  m_opt_updateLevelsOnly        = false;
+  m_opt_clientConnectAtStartup  = false;
+  m_opt_adminMode               = false;
 }
 
 void XMArguments::parse(int i_argc, char **i_argv) {
@@ -199,6 +205,8 @@ void XMArguments::parse(int i_argc, char **i_argv) {
       m_opt_benchmark = true;
     } else if(v_opt == "--cleancache") {
       m_opt_cleanCache = true;
+    } else if(v_opt == "--noLog") {
+      m_opt_noLog = true;
     } else if(v_opt == "--cleanNoWWWLevels") {
       m_opt_cleanNoWWWLevels = true;
     } else if(v_opt == "-ri" || v_opt == "--replayInfos") {
@@ -257,6 +265,12 @@ void XMArguments::parse(int i_argc, char **i_argv) {
       m_opt_hidePlayingInformation = true;
     } else if(v_opt == "--noDBDirsCheck") {
       m_opt_noDBDirsCheck = true;
+    } else if(v_opt == "--server") {
+      m_opt_serverOnly = true;
+    } else if(v_opt == "--updateLevelsOnly") {
+      m_opt_updateLevelsOnly = true;
+    } else if(v_opt == "--connectAtStartup") {
+      m_opt_clientConnectAtStartup = true;
     } else if(v_opt == "--defaultTheme") {
       m_opt_default_theme = true;
       if(i+1 >= i_argc) {
@@ -264,6 +278,8 @@ void XMArguments::parse(int i_argc, char **i_argv) {
       }
       m_opt_default_theme_value = i_argv[i+1];
       i++;
+    } else if(v_opt == "--admin") { // hidden option to control website from the game ; keep undocumented
+      m_opt_adminMode = true;
     } else {
       /* check if the parameter is a file */
       v_arg = i_argv[i];
@@ -462,6 +478,10 @@ bool XMArguments::isOptUgly() const {
   return m_opt_ugly;
 }
 
+bool XMArguments::isOptNoLog() const {
+  return m_opt_noLog;
+}
+
 bool XMArguments::isOptTestTheme() const {
   return m_opt_testTheme;
 }
@@ -554,6 +574,22 @@ bool XMArguments::isOptNoDBDirsCheck() const {
   return m_opt_noDBDirsCheck;
 }
 
+bool XMArguments::isOptServerOnly() const {
+  return m_opt_serverOnly;
+}
+
+bool XMArguments::isOptClientConnectAtStartup() const {
+  return m_opt_clientConnectAtStartup;
+}
+
+bool XMArguments::isOptUpdateLevelsOnly() const {
+  return m_opt_updateLevelsOnly;
+}
+
+bool XMArguments::isOptAdminMode() const {
+  return m_opt_adminMode;
+}
+
 void XMArguments::help(const std::string& i_cmd) {
   printf("X-Moto %s\n", XMBuild::getVersionString().c_str());
   printf("usage:  %s [options]\n"
@@ -589,6 +625,7 @@ void XMArguments::help(const std::string& i_cmd) {
   printf("\t\tperformance.\n");
   printf("\t--cleancache\n\t\tDeletes the content of the level cache.\n");
   printf("\t--cleanNoWWWLevels\n\t\tCheck web levels list and remove levels which are not available on the web.\n");
+  printf("\t--noLog\n\t\tDon't log information into the xmoto.log file\n");
   printf("\t--videoRecording\n\t\tEnable video recording.\n");
   printf("\t--videoRecordingSizeDivision DIVISION\n\t\tChange video size (1=full, 2=50%%, 4=25%%).\n");
   printf("\t--videoRecordingFramerate FRAMERATE\n\t\tChange video framerate.\n");
@@ -598,6 +635,9 @@ void XMArguments::help(const std::string& i_cmd) {
   printf("\t--drawlib DRAWLIB\n\t\tChoose the render to use (default one is OPENGL if available).\n");
   printf("\t--defaultTheme THEME\n\t\tDefault theme for new profiles created.\n");
   printf("\t--noDBDirsCheck\n\t\tDon't check that system and user dirs changed at startup.\n");
+  printf("\t--server\n\t\tRun X-Moto as a server only (no gui).\n");
+  printf("\t--updateServerOnly\n\t\tOnly update levels (no gui).\n");
+  printf("\t--connectAtStartup\n\t\tConnect the client to the server at startup.\n");
   printf("\t-h, -?, -help, --help\n\t\tDisplay this message.\n");
   printf("\t--pack [BIN] [DIR]\n\t\tBuild the BIN package from directory DIR.\n");
   printf("\t--unpack [BIN] [DIR] [no_list]\n\t\tUnpack the BIN package into the dir DIR.\n");
