@@ -66,6 +66,7 @@ class XMArguments {
   bool isOptTimedemo() const;
   bool isOptFps() const;
   bool isOptUgly() const;
+  bool isOptNoLog() const;
   bool isOptTestTheme() const;
   bool isOptBenchmark() const;
   bool isOptCleanCache() const;
@@ -90,6 +91,10 @@ class XMArguments {
   bool isOptHidePlayingInformation() const;
   bool isOptForceChildrenCompliant() const;
   bool isOptNoDBDirsCheck() const;
+  bool isOptServerOnly() const;
+  bool isOptUpdateLevelsOnly() const;
+  bool isOptClientConnectAtStartup() const;
+  bool isOptAdminMode() const;
 
   private:
   /* pack options */
@@ -114,6 +119,7 @@ class XMArguments {
   std::string m_drawlib_lib;
   bool m_opt_ugly;
   bool m_opt_nosound;
+  bool m_opt_noLog;
 
   /* config */
   bool m_opt_configpath;
@@ -170,6 +176,15 @@ class XMArguments {
   int m_opt_videoRecordingEndTime_value;
   bool m_opt_hidePlayingInformation;
 
+  /* update levels only */
+  bool m_opt_updateLevelsOnly;
+
+  /* server */
+  bool m_opt_serverOnly;
+
+  /* net */
+  bool m_opt_clientConnectAtStartup;
+
   /* specific */
   bool m_opt_noDBDirsCheck;
   
@@ -179,6 +194,9 @@ class XMArguments {
 
   /* at command line, you can pass [0-9]* for level of id _iLXX_ */
   static std::string levelArg2levelId(std::string i_arg);
+
+  /* admin */
+  bool m_opt_adminMode;
 };
 
 #endif
