@@ -63,6 +63,7 @@ void XMSession::setToDefault() {
   m_ugly      	     	          = DEFAULT_UGLY;
   m_uglyOver         	          = DEFAULT_UGLYOVER;
   m_testTheme 	     	          = DEFAULT_TESTTHEME;
+  m_noLog                         = DEFAULT_NOLOG;
   m_ghostStrategy_MYBEST          = DEFAULT_GHOST_MYBEST;
   m_ghostStrategy_THEBEST         = DEFAULT_GHOST_THEBEST;
   m_ghostStrategy_BESTOFREFROOM   = DEFAULT_GHOSTBESTREFROOM;
@@ -127,14 +128,20 @@ void XMSession::setToDefault() {
   m_hidePlayingInformation        = DEFAULT_HIDEPLAYINGINFORMATION;
   m_enableInitZoom                = DEFAULT_ENABLEINITZOOM;
   m_enableActiveZoom              = DEFAULT_ENABLEACTIVEZOOM;
+  m_enableTrailCam                = DEFAULT_ENABLETRAILCAM;
+  m_renderGhostTrail              = DEFAULT_GHOSTTRAILRENDERING;
+  m_renderGhostTrailTS            = DEFAULT_GHOSTTRAILRENDERING_TS;
   m_dbsynchronizeOnQuit           = DEFAULT_DBSYNCHRONIZEONQUIT;
   m_enableJoysticks               = DEFAULT_ENABLEJOYSTICKS;
+  m_adminMode                     = DEFAULT_ADMINMODE;
   m_beatingMode                   = DEFAULT_BEATINGMODE;
   m_webForms                      = DEFAULT_WEBFORMS;
   m_serverStartAtStartup          = DEFAULT_SERVERSTARTATSTARTUP;
+  m_clientConnectAtStartup        = DEFAULT_CLIENTCONNECTATSTARTUP;
   m_serverPort                    = DEFAULT_SERVERPORT;
   m_serverMaxClients              = DEFAULT_SERVERMAXCLIENTS;
   m_clientServerName              = DEFAULT_CLIENTSERVERNAME;
+  m_clientGhostMode               = DEFAULT_CLIENTGHOSTMODE;
   m_clientServerPort              = DEFAULT_CLIENTSERVERPORT;
   m_clientFramerateUpload         = DEFAULT_CLIENTFRAMERATEUPLOAD;
   m_musicOnAllLevels              = DEFAULT_MUSICONALLLEVELS;
@@ -207,6 +214,10 @@ void XMSession::load(const XMArguments* i_xmargs) {
     m_ugly = true;
   }
 
+  if(i_xmargs->isOptNoLog()) {
+    m_noLog = true;
+  }
+
   if(i_xmargs->isOptTestTheme()) {
     m_testTheme = true;
   }
@@ -247,6 +258,14 @@ void XMSession::load(const XMArguments* i_xmargs) {
   if(i_xmargs->isOptForceChildrenCompliant()) {
     m_forceChildrenCompliant = true;
   }
+
+  if(i_xmargs->isOptClientConnectAtStartup()) {
+    m_clientConnectAtStartup = true;
+  }
+
+  if(i_xmargs->isOptAdminMode()) {
+    m_adminMode = true;
+  }
 }
 
 void XMSession::load(UserConfig* m_Config) {
@@ -296,6 +315,7 @@ void XMSession::loadProfile(const std::string& i_id_profile, xmDatabase* pDb) {
   m_enableGameMusic                = pDb->config_getBool   (i_id_profile, "GameMusic"                     , m_enableGameMusic  );
   m_enableInitZoom           	   = pDb->config_getBool   (i_id_profile, "InitZoom"                      , m_enableInitZoom   );
   m_enableActiveZoom         	   = pDb->config_getBool   (i_id_profile, "CameraActiveZoom"              , m_enableActiveZoom );
+  m_enableTrailCam                 = pDb->config_getBool   (i_id_profile, "CameraTrailCam"                , m_enableTrailCam   );
   m_enableDeadAnimation      	   = pDb->config_getBool   (i_id_profile, "DeathAnim"                     , m_enableDeadAnimation);
   m_checkNewLevelsAtStartup        = pDb->config_getBool   (i_id_profile, "CheckNewLevelsAtStartup"       , m_checkNewLevelsAtStartup);
   m_checkNewHighscoresAtStartup    = pDb->config_getBool   (i_id_profile, "CheckHighscoresAtStartup"  , m_checkNewHighscoresAtStartup);
@@ -320,12 +340,14 @@ void XMSession::loadProfile(const std::string& i_id_profile, xmDatabase* pDb) {
   m_webForms                       = pDb->config_getBool   (i_id_profile, "WebForms"                   , m_webForms);
 
   m_serverStartAtStartup  = pDb->config_getBool   (i_id_profile, "ServerStartAtStartup" , m_serverStartAtStartup);
+  m_clientConnectAtStartup = pDb->config_getBool  (i_id_profile, "ClientConnectAtStartup" , m_clientConnectAtStartup);
   m_serverPort            = pDb->config_getInteger(i_id_profile, "ServerPort"           , m_serverPort);
   m_serverMaxClients      = pDb->config_getInteger(i_id_profile, "ServerMaxClients"     , m_serverMaxClients);
   m_clientServerName      = pDb->config_getString (i_id_profile, "ClientServerName"     , m_clientServerName);
   m_clientServerPort      = pDb->config_getInteger(i_id_profile, "ClientServerPort"     , m_clientServerPort);
   m_clientFramerateUpload = pDb->config_getInteger(i_id_profile, "ClientFramerateUpload", m_clientFramerateUpload);
   m_musicOnAllLevels      = pDb->config_getBool   (i_id_profile, "MusicOnAllLevels"     , m_musicOnAllLevels);
+  m_clientGhostMode       = pDb->config_getBool   (i_id_profile, "ClientGhostMode"      , m_clientGhostMode);
 
   m_nbRoomsEnabled                 = pDb->config_getInteger(i_id_profile, "WebHighscoresNbRooms"          , m_nbRoomsEnabled);
   if(m_nbRoomsEnabled < 1) { m_nbRoomsEnabled = 1; }
@@ -428,6 +450,7 @@ void XMSession::saveProfile(xmDatabase* pDb) {
 	pDb->config_setBool   (m_profile, "GameMusic"                     , m_enableGameMusic);
 	pDb->config_setBool   (m_profile, "InitZoom"                      , m_enableInitZoom);
 	pDb->config_setBool   (m_profile, "CameraActiveZoom"              , m_enableActiveZoom);
+	pDb->config_setBool   (m_profile, "CameraTrailCam"                , m_enableTrailCam);
 	pDb->config_setBool   (m_profile, "DeathAnim"                     , m_enableDeadAnimation);
 	pDb->config_setBool   (m_profile, "CheckNewLevelsAtStartup"       , m_checkNewLevelsAtStartup);
 	pDb->config_setBool   (m_profile, "CheckHighscoresAtStartup"      , m_checkNewHighscoresAtStartup);
@@ -452,12 +475,14 @@ void XMSession::saveProfile(xmDatabase* pDb) {
 	pDb->config_setBool   (m_profile, "WebForms"                      , m_webForms);
 
 	pDb->config_setBool   (m_profile, "ServerStartAtStartup" , m_serverStartAtStartup);
+	pDb->config_setBool   (m_profile, "ClientConnectAtStartup" , m_clientConnectAtStartup);
 	pDb->config_setInteger(m_profile, "ServerPort"           , m_serverPort);
 	pDb->config_setInteger(m_profile, "ServerMaxClients"           , m_serverMaxClients);
 	pDb->config_setString (m_profile, "ClientServerName"     , m_clientServerName);
 	pDb->config_setInteger(m_profile, "ClientServerPort"     , m_clientServerPort);
 	pDb->config_setInteger(m_profile, "ClientFramerateUpload", m_clientFramerateUpload);
 	pDb->config_setBool   (m_profile, "MusicOnAllLevels"     , m_musicOnAllLevels);
+	pDb->config_setBool   (m_profile, "ClientGhostMode"      , m_clientGhostMode);
 
 	pDb->config_setString (m_profile, "MenuGraphics", m_menuGraphics == GFX_LOW ? "Low" : m_menuGraphics == GFX_MEDIUM ? "Medium":"High");
 	pDb->config_setString (m_profile, "GameGraphics", m_gameGraphics == GFX_LOW ? "Low" : m_gameGraphics == GFX_MEDIUM ? "Medium":"High");
@@ -605,6 +630,10 @@ bool XMSession::uglyOver() const {
   return m_uglyOver;
 }
 
+bool XMSession::noLog() const {
+  return m_noLog;
+}
+
 bool XMSession::testTheme() const {
   return m_testTheme;
 }
@@ -778,6 +807,33 @@ bool XMSession::enableActiveZoom() const {
   return m_enableActiveZoom;
 }
 
+void XMSession::setEnableTrailCam(bool i_value) {
+  PROPAGATE(XMSession,setEnableTrailCam,i_value,bool);
+  m_enableTrailCam = i_value;
+}
+
+bool XMSession::enableTrailCam() const {
+  return m_enableTrailCam;
+}
+
+void XMSession::setRenderGhostTrail(bool i_value) {
+  PROPAGATE(XMSession,setRenderGhostTrail,i_value,bool);
+  m_renderGhostTrail = i_value;
+}
+
+bool XMSession::renderGhostTrail() const {
+  return m_renderGhostTrail;
+}
+
+void XMSession::setRenderGhostTrailTS(bool i_value) {
+  PROPAGATE(XMSession,setRenderGhostTrailTS,i_value,bool);
+  m_renderGhostTrailTS = i_value;
+}
+
+bool XMSession::renderGhostTrailTS() const {
+  return m_renderGhostTrailTS;
+}
+
 void XMSession::setEnableDeadAnimation(bool i_value) {
   PROPAGATE(XMSession,setEnableDeadAnimation,i_value,bool);
   m_enableDeadAnimation = i_value;
@@ -1133,6 +1189,14 @@ bool XMSession::forceChildrenCompliant() const {
   return m_forceChildrenCompliant;
 }
 
+bool XMSession::adminMode() const {
+  return m_adminMode;
+}
+
+void XMSession::setAdminMode(bool i_value) {
+  m_adminMode = i_value;
+}
+
 bool XMSession::enableJoysticks() const {
   return m_enableJoysticks;
 }
@@ -1169,6 +1233,15 @@ void XMSession::setServerStartAtStartup(bool i_value) {
   m_serverStartAtStartup = i_value;
 }
 
+bool XMSession::clientConnectAtStartup() const {
+  return m_clientConnectAtStartup;
+}
+
+void XMSession::setClientConnectAtStartup(bool i_value) {
+  PROPAGATE(XMSession,setClientConnectAtStartup,i_value,bool);
+  m_clientConnectAtStartup = i_value;
+}
+
 int XMSession::serverPort() const {
   return m_serverPort;
 }
@@ -1178,12 +1251,12 @@ void XMSession::setServerPort(int i_value) {
   m_serverPort = i_value;
 }
 
-int XMSession::serverMaxClients() const {
+unsigned int XMSession::serverMaxClients() const {
   return m_serverMaxClients;
 }
 
-void XMSession::setServerMaxClients(int i_value) {
-  PROPAGATE(XMSession,setServerMaxClients,i_value,int);
+void XMSession::setServerMaxClients(unsigned int i_value) {
+  PROPAGATE(XMSession,setServerMaxClients,i_value, unsigned int);
   m_serverMaxClients = i_value;
 }
 
@@ -1196,6 +1269,15 @@ void XMSession::setClientServerName(const std::string& i_value) {
   m_clientServerName = i_value;
 }
 
+bool XMSession::clientGhostMode() const {
+  return m_clientGhostMode;
+}
+
+void XMSession::setClientGhostMode(bool i_value) {
+  PROPAGATE(XMSession,setClientGhostMode,i_value,bool);
+  m_clientGhostMode = i_value;
+}
+
 int XMSession::clientServerPort() const {
   return m_clientServerPort;
 }
@@ -1227,10 +1309,27 @@ ProxySettings* XMSession::proxySettings() {
   return &m_proxySettings;
 }
 
+void XMSession::setProxySettings(const ProxySettings& i_value) {
+  m_proxySettings = i_value;
+}
+
+void XMSession::markProxyUpdated() {
+  PROPAGATE_REF(XMSession, setProxySettings, m_proxySettings, ProxySettings);
+}
+
 ProxySettings::ProxySettings() {
   setDefault();
 }
 
+void ProxySettings::operator=(const ProxySettings& i_copy) {
+  m_useProxy     = i_copy.m_useProxy;
+  m_server       = i_copy.m_server;
+  m_port         = i_copy.m_port;
+  m_type         = i_copy.m_type;
+  m_authUser     = i_copy.m_authUser;
+  m_authPassword = i_copy.m_authPassword;
+}
+
 void ProxySettings::setServer(std::string p_server) {
   m_server = p_server;
 }
