@@ -51,6 +51,8 @@ class xmDatabase;
 class ProxySettings {
  public:
   ProxySettings();
+  void operator=(const ProxySettings& i_copy);
+
   void setServer(std::string p_server);
   void setPort(long p_port);
   void setType(const std::string& p_type); /* CURLPROXY_HTTP OR CURLPROXY_SOCKS5 */
@@ -132,6 +134,7 @@ public:
   void setUgly(bool i_value);
   bool uglyOver() const;
   void setUglyOver(bool i_value);
+  bool noLog() const;
   bool testTheme() const;
   void setTestTheme(bool i_value);
   bool ghostStrategy_MYBEST() const;
@@ -162,6 +165,12 @@ public:
   bool enableInitZoom() const;
   void setEnableActiveZoom(bool i_value);
   bool enableActiveZoom() const;
+  void setEnableTrailCam(bool i_value);
+  bool enableTrailCam() const;
+  void setRenderGhostTrail(bool i_value);
+  bool renderGhostTrail() const;
+  void setRenderGhostTrailTS(bool i_value);
+  bool renderGhostTrailTS() const;
   void setEnableDeadAnimation(bool i_value);
   bool enableDeadAnimation() const;
   void setMenuGraphics(GraphicsLevel i_value);
@@ -219,6 +228,8 @@ public:
   std::string webThemesURLBase() const;
   std::string webRoomsURL() const;
   ProxySettings* proxySettings();
+  void setProxySettings(const ProxySettings& i_value);
+  void markProxyUpdated();
   void setWebConfAtInit(bool i_value);
   bool webConfAtInit() const;
   bool storeReplays() const;
@@ -236,6 +247,8 @@ public:
   bool mirrorMode() const;
   void setMirrorMode(bool i_value);
   bool enableJoysticks() const;
+  bool adminMode() const;
+  void setAdminMode(bool i_value);
   void setEnableJoysticks(bool i_value);
   bool useCrappyPack() const;
   void setUseCrappyPack(bool i_value);
@@ -257,12 +270,16 @@ public:
   bool webForms() const;
   bool serverStartAtStartup() const;
   void setServerStartAtStartup(bool i_value);
+  bool clientConnectAtStartup() const;
+  void setClientConnectAtStartup(bool i_value);
   int serverPort() const;
   void setServerPort(int i_value);
-  int serverMaxClients() const;
-  void setServerMaxClients(int i_value);
+  unsigned int serverMaxClients() const;
+  void setServerMaxClients(unsigned int i_value);
   std::string clientServerName() const;
   void setClientServerName(const std::string& i_value);
+  bool clientGhostMode() const;
+  void setClientGhostMode(bool i_value);
   int clientServerPort() const;
   void setClientServerPort(int i_value);
   int clientFramerateUpload() const;
@@ -325,6 +342,9 @@ public:
   bool m_enableGameMusic;
   bool m_enableInitZoom; /* true: Perform initial level scroll/zoom */
   bool m_enableActiveZoom;
+  bool m_enableTrailCam;
+  bool m_renderGhostTrail;
+  bool m_renderGhostTrailTS;
   bool m_enableDeadAnimation;
   GraphicsLevel m_menuGraphics;
   GraphicsLevel m_gameGraphics;
@@ -382,12 +402,16 @@ public:
   bool m_beatingMode;
   bool m_webForms;
   bool m_serverStartAtStartup;
+  bool m_clientConnectAtStartup;
   int m_serverPort;
-  int m_serverMaxClients;
+  unsigned int m_serverMaxClients;
   std::string m_clientServerName;
   int m_clientServerPort;
   int m_clientFramerateUpload;
+  bool m_clientGhostMode;
   bool m_musicOnAllLevels;
+  bool m_noLog;
+  bool m_adminMode;
 };
 
 #endif
