@@ -28,7 +28,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../VFileIO.h"
 #include <sstream>
 
-#define XMDB_VERSION         28
+#define XMDB_VERSION         34
 #define DB_MAX_SQL_RUNTIME 0.25
 #define DB_BUSY_TIMEOUT   60000 // 60 seconds
 
@@ -665,6 +665,60 @@ void xmDatabase::upgradeXmDbToVersion(int i_fromVersion,
       throw Exception("Unable to update xmDb from 27: " + e.getMsg());
     }
 
+  case 28:
+    try {
+      simpleSql("ALTER TABLE levels ADD COLUMN loadingCacheFormatVersion DEFAULT NULL;");
+      simpleSql("ALTER TABLE levels ADD COLUMN loaded DEFAULT NULL;");
+      simpleSql("CREATE INDEX levels_checkSum_idx1 ON levels(checkSum);");
+      updateXmDbVersion(29);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 28: " + e.getMsg());
+    }
+
+  case 29:
+    try {
+      simpleSql("CREATE TABLE levels_mywebhighscores(id_profile, id_room, id_level, PRIMARY KEY(id_profile, id_room, id_level));");
+      updateXmDbVersion(30);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 29: " + e.getMsg());
+    }
+
+  case 30:
+    try {
+      simpleSql("ALTER TABLE levels_mywebhighscores ADD COLUMN known_stolen DEFAULT 0;");
+      simpleSql("ALTER TABLE levels_mywebhighscores ADD COLUMN known_stolen_date;");
+      simpleSql("CREATE INDEX levels_mywebhighscores_idx1 ON levels_mywebhighscores(known_stolen);");
+      simpleSql("CREATE INDEX levels_mywebhighscores_idx2 ON levels_mywebhighscores(known_stolen_date);");
+      updateXmDbVersion(31);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 30: " + e.getMsg());
+    }
+
+  case 31:
+    try {
+      simpleSql("CREATE TABLE srv_admins(id INTEGER PRIMARY KEY AUTOINCREMENT, id_profile UNIQUE, password);");
+      updateXmDbVersion(32);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 31: " + e.getMsg());
+    }
+
+  case 32:
+    try {
+      simpleSql("CREATE TABLE srv_bans(id INTEGER PRIMARY KEY AUTOINCREMENT, id_profile, ip, from_date, nb_days);");
+      updateXmDbVersion(33);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 32: " + e.getMsg());
+    }
+
+  case 33:
+    try {
+      simpleSql("ALTER TABLE weblevels ADD COLUMN vote_locked DEFAULT 0;");
+      simpleSql("CREATE INDEX weblevels_vote_locked_idx1 ON weblevels(vote_locked);");
+      updateXmDbVersion(34);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 33: " + e.getMsg());
+    }
+
     // next
   }
 }
