@@ -91,8 +91,11 @@ public:
   void levels_delToBlacklist(const std::string& i_profile, const std::string& i_id_level);
   void levels_cleanNew();
   void levels_addToNew(const std::string& i_id_level, bool i_isAnUpdate);
+  void levels_addToNew_begin();
+  void levels_addToNew_end();
 
   void levels_add_begin(bool i_isToReload);
+  bool levels_add_fast(const std::string& i_filepath, std::string& o_levelName, bool i_isToReload);
   void levels_add(const std::string& i_id_level,
 		  const std::string& i_filepath, const std::string& i_name,
 		  const std::string& i_checkSum,
@@ -153,6 +156,10 @@ public:
 				const std::string& i_id_level); /* or a negativ value if not */
   void webLoadDataFirstTime();
   bool isOnTheWeb(const std::string& i_id_level);
+  bool isWebVoteLocked(const std::string& i_id_level);
+  void updateMyHighscoresFromHighscores(const std::string& i_id_profile);
+  void updateMyHighscoresKnownStolenBack(const std::string& i_id_profile);
+  bool markMyHighscoresKnownStolen(const std::string& i_id_profile, std::string& o_stolen_msg);
 
   /* configuration */
 	/* if you save several values, use begin and end to make it faster */
@@ -181,6 +188,16 @@ public:
   void markAsVoted(const std::string& i_profile, const std::string& i_id_level);
   bool isVoted(const std::string& i_profile, const std::string& i_id_level);
 
+  /* server cmd */
+  bool srv_isAdmin(const std::string& i_profile, const std::string& i_password);
+  void srv_addAdmin(const std::string& i_profile, const std::string& i_password);
+  void srv_removeAdmin(int id);
+  void srv_addBan(const std::string& i_profile, const std::string& i_ip, unsigned int i_nbDays);
+  void srv_removeBan(int id);
+  bool srv_isBanned(const std::string& i_profile, const std::string& i_ip);
+  void srv_cleanBans();
+  void srv_changePassword(const std::string& i_profile, const std::string& i_password);
+
   /* data fixes */
   void fixStatsProfilesLevelsNbCompleted();
 
