@@ -22,8 +22,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../helpers/VExcept.h"
 #include "../VXml.h"
 #include "../GameText.h"
-#include "Game.h"
+#include "../Game.h"
+#include <sstream>
 
+/*
+  IMPORTANT NOTE: this update is used ONLY when sitekey didn't exits !! 
+  you must change the query to take case of it if you want to reuse it
+*/
 void xmDatabase::updateDB_stats(XmDatabaseUpdateInterface *i_interface) {
   XMLDocument XML;
   const char *tag, *tagv;
@@ -142,13 +147,14 @@ void xmDatabase::updateDB_stats(XmDatabaseUpdateInterface *i_interface) {
   }
 }
 
-void xmDatabase::stats_createProfile(const std::string& i_profile) {
-  simpleSql("INSERT INTO stats_profiles(id_profile, nbStarts, since) "
-	    "VALUES(\"" + protectString(i_profile) + "\", 0, \"" + 
+void xmDatabase::stats_createProfile(const std::string& i_sitekey, const std::string& i_profile) {
+  simpleSql("INSERT INTO stats_profiles(sitekey, id_profile, nbStarts, since) "
+	    "VALUES(\"" + protectString(i_sitekey) + "\", \"" + protectString(i_profile) + "\", 0, \"" + 
 	    GameApp::getTimeStamp() + "\");");
 }
 
 void xmDatabase::stats_destroyProfile(const std::string& i_profile) {
+  /* delete with all sitekeys */
   try {
     simpleSql("BEGIN TRANSACTION;");
     simpleSql("DELETE FROM stats_profiles          WHERE id_profile=\""+ protectString(i_profile) + "\";");
@@ -162,115 +168,133 @@ void xmDatabase::stats_destroyProfile(const std::string& i_profile) {
   }
 }
 
-bool xmDatabase::stats_checkKeyExists_stats_profiles(const std::string& i_profile) {
+bool xmDatabase::stats_checkKeyExists_stats_profiles(const std::string& i_sitekey, const std::string& i_profile) {
   return checkKey("SELECT count(1) FROM stats_profiles "
-		  "WHERE id_profile=\"" + i_profile + "\";");
+		  "WHERE sitekey=\""    + protectString(i_sitekey) + "\" "
+		  "AND   id_profile=\"" + protectString(i_profile) + "\";");
 }
 
-bool xmDatabase::stats_checkKeyExists_stats_profiles_levels(const std::string& i_profile,
+bool xmDatabase::stats_checkKeyExists_stats_profiles_levels(const std::string& i_sitekey,
+							    const std::string& i_profile,
 							    const std::string& i_level) {
   return checkKey("SELECT count(1) FROM stats_profiles_levels "
-		  "WHERE id_profile=\"" + i_profile + "\" " +
-		  "AND id_level=\""     + i_level   + "\";");
+		  "WHERE sitekey=\""      + protectString(i_sitekey) + "\" "
+		  "AND   id_profile=\""   + protectString(i_profile) + "\" "
+		  "AND   id_level=\""     + protectString(i_level)   + "\";");
 }
 
-void xmDatabase::stats_levelCompleted(const std::string &PlayerName,
+void xmDatabase::stats_levelCompleted(const std::string& i_sitekey,
+				      const std::string &PlayerName,
 				      const std::string &LevelID,
 				      int i_playTime) {
   //printf("stats: level completed\n");
   std::ostringstream v_playTime;
   v_playTime << i_playTime;
 
-  if(stats_checkKeyExists_stats_profiles_levels(PlayerName, LevelID)) {
+  if(stats_checkKeyExists_stats_profiles_levels(i_sitekey, PlayerName, LevelID)) {
     simpleSql("UPDATE stats_profiles_levels SET "
 	      "nbCompleted=nbCompleted+1,"
 	      "nbPlayed=nbPlayed+1,"
 	      "playedTime=playedTime+" + v_playTime.str() + ","   +
-	      "last_play_date=datetime('now', 'localtime') "         +
-	      "WHERE id_profile=\""    + PlayerName       + "\" " +
-	      "AND id_level=\""        + LevelID          + "\";");
+	      "last_play_date=datetime('now', 'localtime'), "
+	      "synchronized = 0 "
+	      "WHERE sitekey=\""    + protectString(i_sitekey)        + "\" "
+	      "AND id_profile=\""   + protectString(PlayerName)       + "\" "
+	      "AND id_level=\""     + protectString(LevelID)          + "\";");
   } else {
     simpleSql("INSERT INTO stats_profiles_levels("
-	      "id_profile, id_level,"
-	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date) "
-	      "VALUES (\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) + "\", 1, 0, 1, 0, \"" +
-	      v_playTime.str() + "\", datetime('now', 'localtime'));");
+	      "sitekey, id_profile, id_level,"
+	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date, synchronized) "
+	      "VALUES (\"" + protectString(i_sitekey) + "\",\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) +
+	      "\", 1, 0, 1, 0, \"" + v_playTime.str() + "\", datetime('now', 'localtime'), 0);");
   }
 }
 
-void xmDatabase::stats_died(const std::string &PlayerName,
+void xmDatabase::stats_died(const std::string& i_sitekey,
+			    const std::string &PlayerName,
 			    const std::string &LevelID,
 			    int i_playTime) {
   //printf("stats: level dead\n");
   std::ostringstream v_playTime;
   v_playTime << i_playTime;
 
-  if(stats_checkKeyExists_stats_profiles_levels(PlayerName, LevelID)) {
+  if(stats_checkKeyExists_stats_profiles_levels(i_sitekey, PlayerName, LevelID)) {
     simpleSql("UPDATE stats_profiles_levels SET "
 	      "nbDied=nbDied+1,"
 	      "nbPlayed=nbPlayed+1,"
 	      "playedTime=playedTime+" + v_playTime.str() + ","   +
-	      "last_play_date=datetime('now', 'localtime') "
-	      "WHERE id_profile=\""    + PlayerName       + "\" " +
-	      "AND id_level=\""        + LevelID          + "\";");
+	      "last_play_date=datetime('now', 'localtime'), "
+	      "synchronized = 0 "
+	      "WHERE sitekey=\""    + protectString(i_sitekey)        + "\" "
+	      "AND id_profile=\""   + protectString(PlayerName)       + "\" "
+	      "AND id_level=\""        + protectString(LevelID)          + "\";");
   } else {
     simpleSql("INSERT INTO stats_profiles_levels("
-	      "id_profile, id_level,"
-	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date) "
-	      "VALUES (\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) + "\", 1, 1, 0, 0, \"" +
-	      v_playTime.str() + "\", datetime('now', 'localtime'));");
+	      "sitekey, id_profile, id_level,"
+	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date, synchronized) "
+	      "VALUES (\"" + protectString(i_sitekey) + "\",\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) +
+	      "\", 1, 1, 0, 0, \"" +
+	      v_playTime.str() + "\", datetime('now', 'localtime'), 0);");
   }
 }
 
-void xmDatabase::stats_abortedLevel(const std::string &PlayerName,
+void xmDatabase::stats_abortedLevel(const std::string& i_sitekey,
+				    const std::string &PlayerName,
 				    const std::string &LevelID,
 				    int i_playTime) {
   //printf("stats: level aborted\n");
   std::ostringstream v_playTime;
   v_playTime << i_playTime;
   
-  if(stats_checkKeyExists_stats_profiles_levels(PlayerName, LevelID)) {
+  if(stats_checkKeyExists_stats_profiles_levels(i_sitekey, PlayerName, LevelID)) {
     simpleSql("UPDATE stats_profiles_levels SET "
 	      "nbPlayed=nbPlayed+1,"
 	      "playedTime=playedTime+" + v_playTime.str() + ","   +
-	      "last_play_date=datetime('now', 'localtime') "
-	      "WHERE id_profile=\""    + PlayerName       + "\" " +
-	      "AND id_level=\""        + LevelID          + "\";");
+	      "last_play_date=datetime('now', 'localtime'), "
+	      "synchronized = 0 "
+	      "WHERE sitekey=\""    + protectString(i_sitekey)        + "\" "
+	      "AND id_profile=\""   + protectString(PlayerName)       + "\" "
+	      "AND id_level=\""        + protectString(LevelID)          + "\";");
   } else {
     simpleSql("INSERT INTO stats_profiles_levels("
-	      "id_profile, id_level,"
-	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date) "
-	      "VALUES (\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) + "\", 1, 0, 0, 0, \"" +
-	      v_playTime.str() + "\", datetime('now', 'localtime'));");
+	      "sitekey, id_profile, id_level,"
+	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date, synchronized) "
+	      "VALUES (\"" + protectString(i_sitekey) + "\",\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) +
+	      "\", 1, 0, 0, 0, \"" +
+	      v_playTime.str() + "\", datetime('now', 'localtime'), 0);");
   }
 }
 
-void xmDatabase::stats_levelRestarted(const std::string &PlayerName,
+void xmDatabase::stats_levelRestarted(const std::string& i_sitekey,
+				      const std::string &PlayerName,
 				      const std::string &LevelID,
 				      int i_playTime) {
   //printf("stats: level restarted\n");
   std::ostringstream v_playTime;
   v_playTime << i_playTime;
 
-  if(stats_checkKeyExists_stats_profiles_levels(PlayerName, LevelID)) {
+  if(stats_checkKeyExists_stats_profiles_levels(i_sitekey, PlayerName, LevelID)) {
     simpleSql("UPDATE stats_profiles_levels SET "
 	      "nbRestarted=nbRestarted+1,"
 	      "nbPlayed=nbPlayed+1,"
 	      "playedTime=playedTime+" + v_playTime.str() + ","   +
-	      "last_play_date=datetime('now', 'localtime') "
-	      "WHERE id_profile=\""    + PlayerName       + "\" " +
-	      "AND id_level=\""        + LevelID          + "\";");
+	      "last_play_date=datetime('now', 'localtime'), "
+	      "synchronized = 0 "
+	      "WHERE sitekey=\""    + protectString(i_sitekey)        + "\" "
+	      "AND id_profile=\""   + protectString(PlayerName)       + "\" "
+	      "AND id_level=\""        + protectString(LevelID)          + "\";");
   } else {
     simpleSql("INSERT INTO stats_profiles_levels("
-	      "id_profile, id_level,"
-	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date) "
-	      "VALUES (\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) + "\", 1, 0, 0, 1, \"" +
-	      v_playTime.str() + "\", datetime('now', 'localtime'));");
+	      "sitekey, id_profile, id_level,"
+	      "nbPlayed, nbDied, nbCompleted, nbRestarted, playedTime, last_play_date, synchronized) "
+	      "VALUES (\"" + protectString(i_sitekey) + "\",\"" + protectString(PlayerName) + "\", \"" + protectString(LevelID) +
+	      "\", 1, 0, 0, 1, \"" +
+	      v_playTime.str() + "\", datetime('now', 'localtime'), 0);");
   }
 }
 
-void xmDatabase::stats_xmotoStarted(const std::string &PlayerName) {
+void xmDatabase::stats_xmotoStarted(const std::string& i_sitekey, const std::string &PlayerName) {
   simpleSql("UPDATE stats_profiles SET "
 	    "nbStarts=nbStarts+1 "
-	    "WHERE id_profile=\"" + PlayerName + "\";");
+	    "WHERE sitekey=\"" + i_sitekey + "\" AND id_profile=\"" + protectString(PlayerName) + "\";");
 }
