@@ -19,12 +19,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
 #include "xmDatabase.h"
+#include "../GameText.h"
 #include "../VXml.h"
 #include "../helpers/VExcept.h"
 #include "../helpers/Log.h"
 #include "../WWW.h"
 #include <sstream>
 
+#define XM_NB_THIEFS_MAX 3
+
 bool xmDatabase::webrooms_checkKeyExists_id_room(const std::string& i_id_room) {
   return checkKey("SELECT count(1) FROM webrooms "
 		  "WHERE id_room=" + i_id_room + ";");
@@ -199,6 +202,10 @@ bool xmDatabase::isOnTheWeb(const std::string& i_id_level) {
   return checkKey("SELECT count(1) FROM weblevels WHERE id_level=\"" + protectString(i_id_level) + "\";");
 }
 
+bool xmDatabase::isWebVoteLocked(const std::string& i_id_level) {
+  return checkKey("SELECT count(1) FROM weblevels WHERE id_level=\"" + protectString(i_id_level) + "\" AND vote_locked=1;");
+}
+
 void xmDatabase::weblevels_updateDB(const std::string& i_weblevelsFile) {
   XMLDocument v_webLXml;
   TiXmlDocument *v_webLXmlData;
@@ -206,7 +213,7 @@ void xmDatabase::weblevels_updateDB(const std::string& i_weblevelsFile) {
   const char *pc;
   std::string v_levelId, v_levelName, v_url, v_MD5sum_web;
   std::string v_difficulty, v_quality, v_creationDate;
-  std::string v_crappy, v_children_compliant;
+  std::string v_crappy, v_children_compliant, v_vote_locked;
 
   try {
     simpleSql("BEGIN TRANSACTION;");
@@ -286,9 +293,16 @@ void xmDatabase::weblevels_updateDB(const std::string& i_weblevelsFile) {
 	v_children_compliant = std::string(pc) == "true" ? "1" : "0";
       }
 
+      pc = pVarElem->Attribute("vote_locked");
+      if(pc == NULL) {
+	v_vote_locked = "0";
+      } else {
+	v_vote_locked = std::string(pc) == "true" ? "1" : "0";
+      }
+
       // add the level
       simpleSql("INSERT INTO weblevels(id_level, name, fileUrl, "
-		"checkSum, difficulty, quality, creationDate, crappy, children_compliant) VALUES (\"" +
+		"checkSum, difficulty, quality, creationDate, crappy, children_compliant, vote_locked) VALUES (\"" +
 		protectString(v_levelId)    + "\", \"" +
 		protectString(v_levelName)  + "\", \"" +
 		protectString(v_url)        + "\", \"" +
@@ -297,7 +311,8 @@ void xmDatabase::weblevels_updateDB(const std::string& i_weblevelsFile) {
 		v_quality      + ", \"" +
 		v_creationDate + "\", " +
 		v_crappy       + ", "   +
-		v_children_compliant + ");");
+		v_children_compliant + ", " +
+		v_vote_locked + ");");
 
       pVarElem = pVarElem->NextSiblingElement("level");
     }
@@ -420,7 +435,6 @@ void xmDatabase::webthemes_addTheme(const std::string& i_id_theme, const std::st
 void xmDatabase::webLoadDataFirstTime() {
   char **v_result;
   unsigned int nrow;
-  std::string v_res;
   bool v_update = false;
 
   /* updating weblevels table with defaults */
@@ -459,3 +473,147 @@ void xmDatabase::webLoadDataFirstTime() {
     LogWarning("Loading delivered webhighscores.xml failed");
   }
 }
+
+void xmDatabase::updateMyHighscoresFromHighscores(const std::string& i_id_profile) {
+  char **v_result;
+  unsigned int nrow;
+
+  /* get my highscores which are in webhighscores but not in levels_mywebhighscores */
+  try {
+    v_result = readDB("SELECT a.id_profile, a.id_room, a.id_level "
+                      "FROM webhighscores AS a "
+		      "LEFT OUTER JOIN levels_mywebhighscores AS b ON (a.id_room    = b.id_room     "
+		                                                  "AND a.id_level   = b.id_level    "
+		                                                  "AND a.id_profile = b.id_profile) "
+		      "WHERE a.id_profile = \"" + protectString(i_id_profile) + "\" "
+		      "AND   b.id_profile IS NULL;",
+		      nrow);
+
+    if(nrow > 0) {
+      try {
+	simpleSql("BEGIN TRANSACTION;");
+	for(unsigned int i=0; i<nrow; i++) {
+	  simpleSql("INSERT INTO levels_mywebhighscores("
+		    "id_profile, id_room, id_level) "
+		    "VALUES(\"" + protectString(getResult(v_result, 3, i, 0)) + "\", " +
+		    getResult(v_result, 3, i, 1)                              + ", " +
+		    "\""        + protectString(getResult(v_result, 3, i, 2)) + "\");");
+	}
+	simpleSql("COMMIT;");
+      } catch(Exception &e) {
+	simpleSql("ROLLBACK;");
+      }
+    }
+
+    read_DB_free(v_result);
+  } catch(Exception &e) {
+    /* ok, no pb */
+    LogWarning("Unable to update my highscores");
+  }
+
+  /* reset levels i get back */
+  updateMyHighscoresKnownStolenBack(i_id_profile);
+}
+
+void xmDatabase::updateMyHighscoresKnownStolenBack(const std::string& i_id_profile) {
+  char **v_result;
+  unsigned int nrow;
+
+  /* reset to known_stolen=0 levels where known_stolen = 1 but highscore owner = i_id_profile */
+  try {
+    v_result = readDB("SELECT a.id_profile, a.id_room, a.id_level "
+                      "FROM webhighscores AS a "
+		      "INNER JOIN levels_mywebhighscores AS b ON (a.id_room    = b.id_room     "
+                                           		     "AND a.id_level   = b.id_level    "
+		                                             "AND a.id_profile = b.id_profile) "
+		      "WHERE a.id_profile = \"" + protectString(i_id_profile) + "\" "
+		      "AND   b.known_stolen = 1;",
+		      nrow);
+
+    if(nrow > 0) {
+      try {
+	simpleSql("BEGIN TRANSACTION;");
+	for(unsigned int i=0; i<nrow; i++) {
+	  simpleSql("UPDATE levels_mywebhighscores "
+		    "SET known_stolen=0 "
+		    "WHERE id_profile=\"" + protectString(getResult(v_result, 3, i, 0)) + "\" "
+		    "AND   id_room="      + getResult(v_result, 3, i, 1) + " "
+		    "AND   id_level=\""   + protectString(getResult(v_result, 3, i, 2)) + "\";");
+	}
+	simpleSql("COMMIT;");
+      } catch(Exception &e) {
+	simpleSql("ROLLBACK;");
+      }
+    }
+
+    read_DB_free(v_result);
+  } catch(Exception &e) {
+    /* ok, no pb */
+    LogWarning("Unable to update known stolen on my highscores");
+  }
+}
+
+bool xmDatabase::markMyHighscoresKnownStolen(const std::string& i_id_profile, std::string& o_stolen_msg) {
+  char **v_result;
+  unsigned int nrow;
+  bool v_res;
+  char v_line_info[256];
+  
+  v_res = false;
+  o_stolen_msg = "";
+
+  try {
+    v_result = readDB("SELECT a.id_room, a.id_level, c.name, a.id_profile, d.name "
+                      "FROM webhighscores AS a "
+		      "INNER JOIN levels_mywebhighscores AS b ON (a.id_room    = b.id_room     "
+                                           		     "AND a.id_level   = b.id_level    "
+		                                             "AND b.id_profile = \"" + protectString(i_id_profile) + "\") "
+                      "INNER JOIN levels AS c ON a.id_level = c.id_level "
+                      "INNER JOIN webrooms AS d ON a.id_room=d.id_room "
+		      "WHERE a.id_profile <> \"" + protectString(i_id_profile) + "\" "
+		      "AND   b.known_stolen = 0 "
+		      "ORDER BY a.date DESC;",
+		      nrow);
+
+    if(nrow > 0) {
+      v_res = true;
+
+      try {
+	simpleSql("BEGIN TRANSACTION;");
+	for(unsigned int i=0; i<nrow; i++) {
+	  
+	  if(i<XM_NB_THIEFS_MAX) {
+	    if(o_stolen_msg != "") {
+	      o_stolen_msg += "\n";
+	    }
+
+	    snprintf(v_line_info, 256, GAMETEXT_HIGHSCORE_STOLEN,
+		     getResult(v_result, 5, i, 4),
+		     getResult(v_result, 5, i, 3),
+		     getResult(v_result, 5, i, 2));
+	    o_stolen_msg += v_line_info;
+
+	  } else if(i == XM_NB_THIEFS_MAX) {
+	    o_stolen_msg += "\n...";
+	  }
+
+	  simpleSql("UPDATE levels_mywebhighscores "
+		    "SET known_stolen=1, known_stolen_date=datetime('now', 'localtime') "
+		    "WHERE id_profile=\"" + protectString(i_id_profile) + "\" "
+		    "AND   id_room="      + getResult(v_result, 5, i, 0) + " "
+		    "AND   id_level=\""   + protectString(getResult(v_result, 5, i, 1)) + "\";");
+	}
+	simpleSql("COMMIT;");
+      } catch(Exception &e) {
+	simpleSql("ROLLBACK;");
+      }
+    }
+
+    read_DB_free(v_result);
+  } catch(Exception &e) {
+    /* ok, no pb */
+    LogWarning("Unable to update known stolen on my highscores");
+  }
+
+  return v_res;
+}
