@@ -191,6 +191,9 @@ class DrawLib {
    **/
   virtual void flushGraphics() = 0;
 
+  /* For Ghost Trail */
+	void DrawFilledCircle(unsigned int nSteps,Color CircleColor,const Vector2f &C,float fRadius);
+	void DrawLine(Vector2f& i_p1, Vector2f& i_p2,const Color& i_color, float i_thickness1, float i_thickness2, bool i_rounded);
   /* Methods - primitives */
   virtual void drawCircle(const Vector2f & Center, float fRadius,
 			  float fBorder = 1.0f, Color Back =
@@ -210,7 +213,6 @@ class DrawLib {
   /*
    * set the reference drawing size
    **/
-  void setDrawDims(unsigned int nActualW, unsigned int nActualH, unsigned int w, unsigned int h);
   bool useVBOs();
   bool useFBOs();
   bool useShaders();
@@ -223,12 +225,11 @@ class DrawLib {
   FontManager* getFontMedium();
   FontManager* getFontBig();
   virtual FontManager* getFontManager(const std::string &i_fontFile, unsigned int i_fontSize);
+  static void checkFontPrerequites();
 
   Camera* getMenuCamera();
 
  protected:    
-  unsigned int m_nDrawWidth, m_nDrawHeight;
-  unsigned int m_nActualWidth, m_nActualHeight;
   unsigned int m_nDispWidth, m_nDispHeight, m_nDispBPP;	/* Screen stuff */
   unsigned int m_nLScissorX, m_nLScissorY, m_nLScissorW, m_nLScissorH;
 
