@@ -159,7 +159,7 @@ DrawLibOpenGL::DrawLibOpenGL() : DrawLib(){
   Transform an OpenGL vertex to pure 2D 
   ===========================================================================*/
 void DrawLibOpenGL::glVertexSP(float x,float y) { 	 
-  glVertex2f(x, m_nActualHeight - y); 	 
+  glVertex2f(x, m_nDispHeight - y); 	 
 } 	 
 
 void DrawLibOpenGL::glVertex(float x,float y) { 	 
@@ -171,7 +171,7 @@ void DrawLibOpenGL::glTexCoord(float x,float y){
 }
 
 void DrawLibOpenGL::screenProjVertex(float *x, float *y) {
-  *y = m_nActualHeight - (*y);
+  *y = m_nDispHeight - (*y);
 }
 
 void DrawLibOpenGL::setClipRect(int x, int y, unsigned int w, unsigned int h){
@@ -272,19 +272,10 @@ void DrawLibOpenGL::init(unsigned int nDispWidth, unsigned int nDispHeight, unsi
                     
   m_nDispBPP = pVidInfo->vfmt->BitsPerPixel;
 
-  /* Did we get a z-buffer? */        
-  int nDepthBits;
-  SDL_GL_GetAttribute(SDL_GL_DEPTH_SIZE, &nDepthBits);
-  if(nDepthBits == 0)
-    throw Exception("no depth buffer");  
-  
   m_menuCamera = new Camera(Vector2i(0, 0),
 			    Vector2i(m_nDispWidth, m_nDispHeight));
   m_menuCamera->setCamera2d();
 
-  glClearDepth(1);
-  glDepthFunc(GL_LEQUAL);
-
   /* Output some general info */
   LogInfo("GL: %s (%s)", glGetString(GL_RENDERER), glGetString(GL_VENDOR));
   if(glGetString(GL_RENDERER) == NULL
@@ -405,11 +396,11 @@ void DrawLibOpenGL::init(unsigned int nDispWidth, unsigned int nDispHeight, unsi
   }
   else
     LogInfo("GL: not using ARB_fragment_shader/ARB_vertex_shader/ARB_shader_objects");
-    
+ 
   /* Set background color to black */
   glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
   glClear(GL_COLOR_BUFFER_BIT);
-  SDL_GL_SwapBuffers();  
+  SDL_GL_SwapBuffers();
 }
 
 void DrawLibOpenGL::unInit()
@@ -611,10 +602,9 @@ int ScrapTextures::allocateAndLoadTexture(unsigned int width,
 					  float* vx, float* vy,
 					  SDL_Surface* data)
 {
-  unsigned int x, y, firstAvailable, scrap;
+  unsigned int x = 0, y = 0, firstAvailable = 0, scrap = 0;
   bool useScrap = false;
 
-  scrap = 0;
   while(scrap < MAX_SCRAPS && useScrap == false) {
     for(unsigned int i=0; i<BLOCK_WIDTH-width && useScrap == false; i++){
       firstAvailable= 0;
