@@ -30,6 +30,9 @@ class Sprite;
 class GameApp;
 
 #include "../../Theme.h"
+#include "../../include/xm_SDL.h"
+
+#define GUI_JOYSTICK_MINIMUM_DETECTION 3000
 
 
 /*===========================================================================
@@ -144,10 +147,14 @@ protected:
     m_bActiveMsgBox = false;
     setPrimaryChild(NULL);
     setOpacity(100);
+    m_canGetFocus = true;
   }
       
 public:
-  UIWindow() {m_curFont = NULL;}
+  UIWindow() {
+      m_curFont = NULL;
+      m_canGetFocus = true;
+  }
   UIWindow(UIWindow *pParent,int x=0,int y=0,std::string Caption="",int nWidth=0,int nHeight=0) {
     initW(pParent,x,y,Caption,nWidth,nHeight);
   }
@@ -167,18 +174,21 @@ public:
   virtual void mouseRDown(int x,int y) {}
   virtual void mouseRUp(int x,int y) {}
   virtual void mouseHover(int x,int y) {}
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar) {return false;}
-  virtual bool keyUp(int nKey, SDLMod mod) {return false;}
+  virtual void mouseOut(int x,int y) {}
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char) {return false;}
+  virtual bool keyUp(int nKey, SDLMod mod, const std::string& i_utf8Char) {return false;}
+  virtual bool joystickAxisMotion(Uint8 i_joyNum, Uint8 i_joyAxis, Sint16 i_joyAxisValue) {return false;}
+  virtual bool joystickButtonDown(Uint8 i_joyNum, Uint8 i_joyButton) {return false;}
   virtual bool offerActivation(void) {return false;}
   virtual bool offerMouseEvent(void) {return true;}
   virtual std::string subContextHelp(int x,int y) {return "";}
 
   /* Painting */
   void putText(int x,int y, std::string Text,
-	       float i_xper = 0.0, float i_yper = 0.0);
+	       float i_xper = 0.0, float i_yper = 0.0, float i_perCentered = -1.0);
   void putTextS(int x,int y, std::string Text,
 		int& o_width, int &o_height,
-		float i_xper = 0.0, float i_yper = 0.0);
+		float i_xper = 0.0, float i_yper = 0.0, float i_perCentered = -1.0);
   void putImage(int x,int y,int nWidth,int nHeight,Texture *pImage);
   void putElem(int x,int y,int nWidth,int nHeight,UIElem Elem,bool bDisabled,bool bActive=false);
   void putRect(int x,int y,int nWidth,int nHeight,Color c);
@@ -198,7 +208,7 @@ public:
   UIRoot *getRoot(void);
       
   /* Generic message boxing */
-  UIMsgBox *msgBox(std::string Text,UIMsgBoxButton Buttons,bool bTextInput=false,bool bQuery=false);
+  UIMsgBox *msgBox(std::string Text,UIMsgBoxButton Buttons,bool bTextInput=false,bool bQuery=false,bool i_verticallyLarge=false);
     
   /* Data interface */
   UIWindow *getPrimaryChild(void) {return m_pPrimaryChild;}
@@ -213,7 +223,7 @@ public:
   UIRect &getPosition(void) {return m_Pos;}
   void setPosition(int x,int y,int nWidth,int nHeight) {m_Pos.nX=x; m_Pos.nY=y; m_Pos.nWidth=nWidth; m_Pos.nHeight=nHeight;}
   std::string getCaption(void) {return m_Caption;}
-  virtual void setCaption(std::string Caption) {m_Caption=Caption;}
+  virtual void setCaption(const std::string& Caption) {m_Caption=Caption;}
   UITextStyle &getTextStyle(void) {return m_TextStyle;}
   void setTextSolidColor(Color c) {m_TextStyle.c0=m_TextStyle.c1=m_TextStyle.c2=m_TextStyle.c3=c;}
   void setTextGradientColors(Color a,Color b) {m_TextStyle.c0=m_TextStyle.c1=a; m_TextStyle.c2=m_TextStyle.c3=b;}
@@ -224,6 +234,8 @@ public:
   bool isBranchHidden(void);
   bool isDisabled(void); // recursive to parents
   bool isVisible(); // recursive to parents
+  bool canGetFocus(void) {return m_canGetFocus && isHidden() == false;}
+  void setCanGetFocus(bool b) {m_canGetFocus = b;}
   void showWindow(bool b);      
   void enableWindow(bool b) {m_bDisable=!b;}
   bool isActive(void);
@@ -267,6 +279,7 @@ private:
   bool m_bActive;                           /* Only one window should be active at a time */
   int m_nGroup;                             /* In window group */    
   bool m_bActiveMsgBox;                     /* Message box active */
+  bool m_canGetFocus;                       /* UI element can be focused with keyboard */
 };  
 
 /*===========================================================================
@@ -284,19 +297,23 @@ public:
     
   /* Methods */
   virtual void paint(void);
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar);
-      
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char);
+  virtual bool joystickAxisMotion(Uint8 i_joyNum, Uint8 i_joyAxis, Sint16 i_joyAxisValue);
+  virtual bool joystickButtonDown(Uint8 i_joyNum, Uint8 i_joyButton);
+
   virtual bool offerActivation(void) {return true;}
   void hideText(bool bHideText) {m_hideText=bHideText;} 
 
-  void setCaption(std::string Caption);
+  void setCaption(const std::string& Caption);
 
   void setHasChanged(bool b_value);
   bool hasChanged();
 
 private:
+  void setCaptionResetCursor(const std::string& Caption, bool i_value = true);
+
   /* Data */
-  int m_nCursorPos;
+  unsigned int m_nCursorPos;
   bool m_hideText;    
   bool m_hasChanged;
 };
@@ -322,7 +339,8 @@ public:
   virtual void paint(void);
   virtual void mouseLDown(int x,int y);
   virtual void mouseHover(int x,int y);
-      
+  virtual void mouseOut(int x,int y);
+
   void makeMinimizable(int nMinX,int nMinY);
   void setMinimized(bool b);
       
@@ -394,9 +412,9 @@ public:
     
   /* Virtual methods */
   virtual void paint(void);      
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar);
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char);
   virtual bool offerActivation(void) {if(m_bTextInput) return true; return false;}
-    
+
   /* Methods */
   bool setClicked(std::string Text);
   UIMsgBoxButton getClicked(void);
@@ -440,7 +458,7 @@ public:
   }      
 
   /* Virtual methods */
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar);
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char);
 };
 
 /*===========================================================================
@@ -463,6 +481,7 @@ public:
   void setBackgroundShade(bool b) {m_bBackgroundShade=b;}
   void setBackground(Texture *p) {m_pCustomBackgroundTexture = p;}
   void setAllowContextHelp(bool i_value);
+  void setNormalColor(Color c);
 
 private:
   /* Data */
@@ -473,6 +492,7 @@ private:
   Texture *m_pCustomBackgroundTexture;
 
   bool m_allowContextHelp;
+  Color m_normalColor;
 };
 
 class UIProgressBar : public UIWindow {
@@ -524,10 +544,12 @@ public:
   virtual void mouseLUp(int x,int y);
   virtual void mouseRDown(int x,int y);
   virtual void mouseRUp(int x,int y);
-  virtual void mouseHover(int x,int y);      
+  virtual void mouseHover(int x,int y);
+  virtual void mouseOut(int x,int y);
   virtual bool offerActivation(void);
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar);
-      
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char);
+  virtual bool joystickButtonDown(Uint8 i_joyNum, Uint8 i_joyButton);
+
   /* Data interface */
   UIButtonState getState(void) {return m_State;}
   void setState(UIButtonState State) {m_State = State;}
@@ -548,6 +570,9 @@ protected:
       
   /* Helper methods */
   void _UncheckGroup(int nGroup);
+
+ private:
+  void actionnate();
 };
 
 class UIButtonDrawn : public UIButton {
@@ -563,6 +588,7 @@ public:
 
   virtual void paint();
   void setBorder(int i_border);
+  virtual void mouseOut(int x,int y);
 
 private:
   int m_border;
@@ -604,10 +630,11 @@ public:
   virtual void mouseWheelDown(int x,int y);
   virtual void mouseHover(int x,int y);      
   virtual bool offerActivation(void);
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar);
-
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char);
+  virtual bool joystickAxisMotion(Uint8 i_joyNum, Uint8 i_joyAxis, Sint16 i_joyAxisValue);
+  virtual bool joystickButtonDown(Uint8 i_joyNum, Uint8 i_joyButton);
   virtual std::string subContextHelp(int x,int y);
-      
+
   /* if position != -1, force the entry to this position */
   UIListEntry *addEntry(std::string Text,void *pvUser=NULL, int i_position = -1);
   virtual void clear();
@@ -697,6 +724,13 @@ private:
   float ScrollNbVisibleItems();
   bool isScrollBarRequired();
 
+  // keyboard/joystick/... events reaction
+  void eventGo();
+  void eventDown();
+  void eventUp();
+  void eventLeft();
+  void eventRight();
+
   int m_headerHeight;
   int m_headerSubBorderHeight;
   int m_rowHeight;
@@ -723,6 +757,7 @@ public:
         
     m_nSelected = 0;
     m_bChanged = false;
+    m_hideDisabledTabs = false;
   }      
 
   /* Methods */
@@ -752,11 +787,15 @@ public:
   void selectChildren(unsigned int i);
   void selectChildrenById(const std::string& i_id);
 
+  void setHideDisabledTabs(bool i_value) { m_hideDisabledTabs = i_value; }
+  bool hideDisabledTabs() const { return m_hideDisabledTabs; }
+
 private:
   /* Data */
   bool m_bChanged;
   unsigned int m_nSelected;
   std::vector<std::string> m_TabContextHelp;
+  bool m_hideDisabledTabs;
 };
 
 /*===========================================================================
@@ -780,7 +819,7 @@ enum UIRootKeyEvent {
   
 struct UIRootActCandidate {
   UIWindow *pWindow;
-  int x,y;
+  int x,y,nWidth,nHeight;
 };
   
 class UIRoot : public UIWindow {
@@ -797,9 +836,11 @@ public:
   virtual void mouseHover(int x,int y);
   virtual void mouseWheelUp(int x,int y);
   virtual void mouseWheelDown(int x,int y);
-  virtual bool keyDown(int nKey, SDLMod mod,int nChar);      
-  virtual bool keyUp(int nKey, SDLMod mod);  
-      
+  virtual bool keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char);      
+  virtual bool keyUp(int nKey, SDLMod mod, const std::string& i_utf8Char);  
+  virtual bool joystickAxisMotion(Uint8 i_joyNum, Uint8 i_joyAxis, Sint16 i_joyAxisValue);
+  virtual bool joystickButtonDown(Uint8 i_joyNum, Uint8 i_joyButton);
+
   void deactivate(UIWindow *pWindow);
 
   void enableContextMenuDrawing(bool b) {m_bShowContextMenu=b;}
@@ -809,6 +850,8 @@ public:
   void activateDown(void);
   void activateLeft(void);
   void activateRight(void);
+  void activateNext(void);
+  void activatePrevious(void);
             
   void setApp(GameApp *pApp) {}
   virtual GameApp *getApp(void) {return m_pApp;}
@@ -821,13 +864,20 @@ private:
   GameApp *m_pApp; /* Application */      
 
   /* Helpers */      
-  bool _RootKeyEvent(UIWindow *pWindow,UIRootKeyEvent Event,int nKey, SDLMod mod,int nChar);
+  bool _RootKeyEvent(UIWindow *pWindow,UIRootKeyEvent Event,int nKey, SDLMod mod, const std::string& i_utf8Char);
+
+  bool _RootJoystickAxisMotionEvent(UIWindow *pWindow, Uint8 i_joyNum, Uint8 i_joyAxis, Sint16 i_joyAxisValue);
+  bool _RootJoystickButtonDownEvent(UIWindow *pWindow, Uint8 i_joyNum, Uint8 i_joyButton);
+
   bool _RootMouseEvent(UIWindow *pWindow,UIRootMouseEvent Event,int x,int y);
   void _RootPaint(int x,int y,UIWindow *pWindow,UIRect *pRect);
   void _ClipRect(UIRect *pRect,UIRect *pClipWith);
   unsigned int _UpdateActivationMap(UIWindow *pWindow, UIRootActCandidate *pMap, unsigned int nNum, unsigned int nMax);
   void _ActivateByVector(int dx,int dy);
+  void _ActivateByStep(int step);
   int _GetActiveIdx(UIRootActCandidate *pMap, unsigned int nNum);
+
+  UIWindow* m_lastHover;
 };
 
 #endif
