@@ -22,11 +22,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *  GUI: list control
  */
 #include "GUI.h"
-#include "drawlib/DrawLib.h"
-#include "Game.h"
-#include "Sound.h"
+#include "../../drawlib/DrawLib.h"
+#include "../../Game.h"
+#include "../../Sound.h"
+#include <sstream>
 
-#define GUILIST_SCROLL_SIZE 4
+#define GUILIST_SCROLL_SIZE 10
 
   int UIList::HeaderHeight() {
     return m_headerHeight;
@@ -531,12 +532,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   ===========================================================================*/
   void UIList::mouseWheelDown(int x,int y) {
     /* Scroll down! */
-    _Scroll(-16);
+    _Scroll(-16*GUILIST_SCROLL_SIZE);
   }
   
   void UIList::mouseWheelUp(int x,int y) {
     /* Scroll up! */
-    _Scroll(16);
+    _Scroll(16*GUILIST_SCROLL_SIZE);
   }
   
   void UIList::mouseLDoubleClick(int x,int y) {
@@ -719,14 +720,18 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     m_nScroll   = 0;
   }
 
+  /* Implements Knuth shuffle
+   * http://en.wikipedia.org/wiki/Knuth_shuffle
+   * */
   void UIList::randomize() {
     UIListEntry *v_tmp;
     int r;
-
-    for(unsigned int i = 0; i<m_Entries.size(); i++) {
-      r = randomIntNum(0, m_Entries.size() -1);
-      v_tmp = m_Entries[i];
-      m_Entries[i] = m_Entries[r];
+    int n = m_Entries.size();
+    while (n > 1) {
+      r = randomIntNum(0, n);
+      n--;
+      v_tmp = m_Entries[n];
+      m_Entries[n] = m_Entries[r];
       m_Entries[r] = v_tmp;
     }
   }
@@ -748,42 +753,61 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     return true;    
   }
 
+void UIList::eventGo() {
+  /* Uhh... send this to the default button, if any. And if anything is selected */
+  if(m_nVisibleSelected>=0
+     && m_nVisibleSelected < (int)(m_Entries.size()-m_filteredItems)
+     && m_pEnterButton != NULL) {
+    m_pEnterButton->setClicked(true);       
+    m_bChanged = true;
+    
+    try {
+      Sound::playSampleByName(Theme::instance()->getSound("Button3")->FilePath());
+    } catch(Exception &e) {
+    }
+  }
+  
+  /* Under all circumstances set the activation flag */
+  m_bItemActivated = true;
+}
+
+void UIList::eventDown() {
+  if(m_nVisibleSelected >= (int)(m_Entries.size() - m_filteredItems - 1)) {
+    getRoot()->activateDown();
+  } else {
+    setVisibleSelected(m_nVisibleSelected + 1);
+  }         
+}
+
+void UIList::eventUp() {
+  if(m_nVisibleSelected <= 0) {
+    getRoot()->activateUp();
+  } else {
+    setVisibleSelected(m_nVisibleSelected - 1);
+  }
+}
+
+void UIList::eventLeft() {
+  getRoot()->activateLeft();
+}
+
+void UIList::eventRight() {
+  getRoot()->activateRight();
+}
+
   /*===========================================================================
   Up/down keys select elements
   ===========================================================================*/
-  bool UIList::keyDown(int nKey, SDLMod mod,int nChar) {
+  bool UIList::keyDown(int nKey, SDLMod mod, const std::string& i_utf8Char) {
     switch(nKey) {
-      case SDLK_RETURN: 
-        /* Uhh... send this to the default button, if any. And if anything is selected */
-        if(m_nVisibleSelected>=0
-	   && m_nVisibleSelected < (int)(m_Entries.size()-m_filteredItems)
-	   && m_pEnterButton != NULL) {
-          m_pEnterButton->setClicked(true);       
-	  m_bChanged = true;
-          
-	  try {
-	    Sound::playSampleByName(Theme::instance()->getSound("Button3")->FilePath());
-	  } catch(Exception &e) {
-	  }
-        }
-        
-        /* Under all circumstances set the activation flag */
-        m_bItemActivated = true;
-        return true;
-    
+    case SDLK_RETURN:
+	eventGo();
+        return true; 
       case SDLK_UP:
-        if(m_nVisibleSelected <= 0)
-          getRoot()->activateUp();
-        else {
-          setVisibleSelected(m_nVisibleSelected - 1);
-        }
+	eventUp();
         return true;
       case SDLK_DOWN:
-        if(m_nVisibleSelected >= (int)(m_Entries.size() - m_filteredItems - 1))
-          getRoot()->activateDown();
-        else {
-          setVisibleSelected(m_nVisibleSelected + 1);
-        }          
+	eventDown();
         return true;
       case SDLK_PAGEUP:
         for(int i=0;i<10;i++) {
@@ -806,47 +830,74 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
       
       /* Left and right always selects another window */
       case SDLK_LEFT:
-        getRoot()->activateLeft();
+	eventLeft();
         return true;
       case SDLK_RIGHT:
-        getRoot()->activateRight();
+	eventRight();
         return true;
     }
-    
-    /* Maybe it's a character? If so, try jumping to a suitable place in the list */
-    if(nChar != 0) {
-      bool bContinue;
-      unsigned int nPos = 0;
-      
-      do {
-        bContinue = false;
-        
-        /* Look at character number 'nPos' in all entries */
-        for(unsigned int i=0; i<m_Entries.size(); i++) {
-	  if(m_Entries[i]->bFiltered == false) {
-	    int nEntryIdx = i + m_nRealSelected + 1; /* always start looking at the next */
-	    nEntryIdx %= m_Entries.size();
-        
-	    if(m_Entries[nEntryIdx]->Text[0].length() > nPos) {
-	      if(tolower(m_Entries[nEntryIdx]->Text[0].at(nPos)) == tolower(nChar)) {
-		/* Nice, select this one */
-		setVisibleSelected(nEntryIdx);
-		bContinue = false;
-		return true;
-	      }
-            
-	      bContinue = true;
-	    }
-	  }
-        }
-        
-        nPos++;
-      } while(bContinue);
-    }
+
+// this must be adapted to utf8
+//    /* Maybe it's a character? If so, try jumping to a suitable place in the list */
+//    if(utf8::utf8_length(i_utf8Char) == 1) {
+//      bool bContinue;
+//      unsigned int nPos = 0;
+//      
+//      do {
+//        bContinue = false;
+//        
+//        /* Look at character number 'nPos' in all entries */
+//        for(unsigned int i=0; i<m_Entries.size(); i++) {
+//	  if(m_Entries[i]->bFiltered == false) {
+//	    int nEntryIdx = i + m_nRealSelected + 1; /* always start looking at the next */
+//	    nEntryIdx %= m_Entries.size();
+//        
+//	    if(m_Entries[nEntryIdx]->Text[0].length() > nPos) {
+//	      if(tolower(m_Entries[nEntryIdx]->Text[0].at(nPos)) == tolower(nChar)) {
+//		/* Nice, select this one */
+//		setVisibleSelected(nEntryIdx);
+//		bContinue = false;
+//		return true;
+//	      }
+//            
+//	      bContinue = true;
+//	    }
+//	  }
+//        }
+//        
+//        nPos++;
+//      } while(bContinue);
+//    }
     
     /* w00t? we don't want that silly keypress! */
     return false;
   }
+
+bool UIList::joystickAxisMotion(Uint8 i_joyNum, Uint8 i_joyAxis, Sint16 i_joyAxisValue) {
+  if(i_joyAxis % 2 == 0) { // horizontal
+    if(i_joyAxisValue < -(GUI_JOYSTICK_MINIMUM_DETECTION)) {
+      eventLeft();
+      return true;
+    } else if(i_joyAxisValue > GUI_JOYSTICK_MINIMUM_DETECTION) {
+      eventRight();
+      return true;
+    }
+  } else { // vertical
+    if(i_joyAxisValue < -(GUI_JOYSTICK_MINIMUM_DETECTION)) {
+      eventUp();
+      return true;
+    } else if(i_joyAxisValue > GUI_JOYSTICK_MINIMUM_DETECTION) {
+      eventDown();
+      return true;
+    }
+  }
+  return false;
+}
+
+bool UIList::joystickButtonDown(Uint8 i_joyNum, Uint8 i_joyButton) {
+  eventGo();
+  return true;
+}
   
 void UIList::adaptRealSelectedOnVisibleEntries() { // m_nRealSelected must be >= 0 and < size()
   bool v_found;
