@@ -1,5 +1,5 @@
 #ifdef HAVE_SDL_FRAMEWORK
-  #include <SDL_mutex.h>
+  #include <SDL_mixer.h>
 #else
   #define USE_RWOPS
   #include <SDL/SDL_mixer.h>
