@@ -23,7 +23,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../helpers/Log.h"
 #include "NetClient.h"
 #include "../XMSession.h"
+#include "../DBuffer.h"
+#include "extSDL_net.h"
 #include <sstream>
+#include "helpers/SwapEndian.h"
 
 char NetAction::m_buffer[NETACTION_MAX_PACKET_SIZE];
 unsigned int NetAction::m_biggestTCPPacket   = 0;
@@ -43,6 +46,16 @@ std::string NA_changeName::ActionKey    = "changeName";
 std::string NA_playingLevel::ActionKey  = "playingLevel";
 std::string NA_serverError::ActionKey   = "serverError";
 std::string NA_changeClients::ActionKey = "changeClients";
+// control : while it's sent a lot, reduce it at maximum
+std::string NA_playerControl::ActionKey = "c";
+std::string NA_clientMode::ActionKey  	= "clientMode";
+std::string NA_prepareToPlay::ActionKey = "prepareToPlay";
+std::string NA_killAlert::ActionKey     = "killAlert";
+std::string NA_prepareToGo::ActionKey   = "prepareToGo";
+// events are send regularly
+std::string NA_gameEvents::ActionKey    = "e";
+std::string NA_srvCmd::ActionKey        = "srvCmd";
+std::string NA_srvCmdAsw::ActionKey     = "srvCmdAsw";
 
 NetActionType NA_chatMessage::NAType   = TNA_chatMessage;
 NetActionType NA_frame::NAType         = TNA_frame;
@@ -53,6 +66,14 @@ NetActionType NA_changeName::NAType    = TNA_changeName;
 NetActionType NA_playingLevel::NAType  = TNA_playingLevel;
 NetActionType NA_serverError::NAType   = TNA_serverError;
 NetActionType NA_changeClients::NAType = TNA_changeClients;
+NetActionType NA_playerControl::NAType = TNA_playerControl;
+NetActionType NA_clientMode::NAType    = TNA_clientMode;
+NetActionType NA_prepareToPlay::NAType = TNA_prepareToPlay;
+NetActionType NA_killAlert::NAType     = TNA_killAlert;
+NetActionType NA_prepareToGo::NAType   = TNA_prepareToGo;
+NetActionType NA_gameEvents::NAType    = TNA_gameEvents;
+NetActionType NA_srvCmd::NAType        = TNA_srvCmd;
+NetActionType NA_srvCmdAsw::NAType     = TNA_srvCmdAsw;
 
 NetAction::NetAction() {
   m_source    = -2; // < -1 => undefined
@@ -62,13 +83,53 @@ NetAction::NetAction() {
 NetAction::~NetAction() {
 }
 
+std::string NetAction::getFancyBytes(unsigned int i_bytes) {
+  std::ostringstream v_s;
+  unsigned int v_n;
+
+  v_n = i_bytes;
+  if(v_n < 1024) {
+    v_s << v_n << " bytes";
+    return v_s.str();
+  }
+
+  v_n = v_n / 1024;
+  if(v_n < 1024) {
+    v_s << v_n << " kB";
+    return v_s.str();
+  }
+
+  v_n = v_n / 1024;
+  v_s << v_n << " mB";
+  return v_s.str();
+}
+
+/* std::string version */
+std::string NetAction::getStats() {
+  std::string v_stats;
+
+  std::ostringstream v_nbTCP, v_nbUDP;
+  v_nbTCP << NetAction::m_nbTCPPacketsSent;
+  v_nbUDP << NetAction::m_nbUDPPacketsSent;
+
+  v_stats += "number of TCP packets sent : " + v_nbTCP.str()                                  + "\n";
+  v_stats += "biggest TCP packet sent : "    + getFancyBytes(NetAction::m_biggestTCPPacket)   + "\n";
+  v_stats += "size of TCP packets sent : "   + getFancyBytes(NetAction::m_TCPPacketsSizeSent) + "\n";
+  v_stats += "number of UDP packets sent : " + v_nbUDP.str()                                  + "\n";
+  v_stats += "biggest UDP packet sent : "    + getFancyBytes(NetAction::m_biggestUDPPacket)   + "\n";
+  v_stats += "size of UDP packets sent : "   + getFancyBytes(NetAction::m_UDPPacketsSizeSent);
+
+  return v_stats;
+}
+
+/* log version */
 void NetAction::logStats() {
-  LogInfo("net: number of TCP packets sent : %u", NetAction::m_nbTCPPacketsSent);
-  LogInfo("net: biggest TCP packet sent : %u bytes", NetAction::m_biggestTCPPacket);
-  LogInfo("net: size of TCP packets sent : %u bytes", NetAction::m_TCPPacketsSizeSent);
-  LogInfo("net: number of UDP packets sent : %u", NetAction::m_nbUDPPacketsSent);
-  LogInfo("net: biggest UDP packet sent : %u bytes", NetAction::m_biggestUDPPacket);
-  LogInfo("net: size of UDP packets sent : %i bytes", NetAction::m_UDPPacketsSizeSent);
+  LogInfo("%-31s : %u", "net: number of TCP packets sent", NetAction::m_nbTCPPacketsSent);
+  LogInfo("%-31s : %s", "net: biggest TCP packet sent"   , getFancyBytes(NetAction::m_biggestTCPPacket).c_str());
+  LogInfo("%-31s : %s", "net: size of TCP packets sent"  , getFancyBytes(NetAction::m_TCPPacketsSizeSent).c_str());
+  LogInfo("%-31s : %u", "net: number of UDP packets sent", NetAction::m_nbUDPPacketsSent);
+  LogInfo("%-31s : %s", "net: biggest UDP packet sent"   , getFancyBytes(NetAction::m_biggestUDPPacket).c_str());
+  LogInfo("%-31s : %s", "net: size of UDP packets sent"  , getFancyBytes(NetAction::m_UDPPacketsSizeSent).c_str());
 }
 
 void NetAction::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP,
@@ -125,7 +186,7 @@ void NetAction::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPa
 
   } else if(i_tcpsd != NULL) {
     // don't send the \0
-    if( (nread = SDLNet_TCP_Send(*i_tcpsd, m_buffer, v_totalPacketSize)) != v_totalPacketSize) {
+    if( (nread = SDLNet_TCP_Send_noBlocking(*i_tcpsd, m_buffer, v_totalPacketSize)) != v_totalPacketSize) {
       throw Exception("TCP_Send failed");
     }
 
@@ -178,6 +239,10 @@ NetAction* NetAction::newNetAction(void* data, unsigned int len) {
     v_res = new NA_frame(((char*)data)+v_totalOffset, len-v_totalOffset);
   }
 
+  else if(v_cmd == NA_playerControl::ActionKey) {
+    v_res = new NA_playerControl(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
   else if(v_cmd == NA_clientInfos::ActionKey) {
     v_res = new NA_clientInfos(((char*)data)+v_totalOffset, len-v_totalOffset);
   }
@@ -206,6 +271,34 @@ NetAction* NetAction::newNetAction(void* data, unsigned int len) {
     v_res = new NA_changeClients(((char*)data)+v_totalOffset, len-v_totalOffset);
   }
 
+  else if(v_cmd == NA_clientMode::ActionKey) {
+    v_res = new NA_clientMode(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
+  else if(v_cmd == NA_prepareToPlay::ActionKey) {
+    v_res = new NA_prepareToPlay(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
+  else if(v_cmd == NA_killAlert::ActionKey) {
+    v_res = new NA_killAlert(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
+  else if(v_cmd == NA_prepareToGo::ActionKey) {
+    v_res = new NA_prepareToGo(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
+  else if(v_cmd == NA_gameEvents::ActionKey) {
+    v_res = new NA_gameEvents(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
+  else if(v_cmd == NA_srvCmd::ActionKey) {
+    v_res = new NA_srvCmd(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
+  else if(v_cmd == NA_srvCmdAsw::ActionKey) {
+    v_res = new NA_srvCmdAsw(((char*)data)+v_totalOffset, len-v_totalOffset);
+  }
+
   else {
     //((char*)data)[len-1] = '\0';
     //LogInfo("Invalid command : %s", (char*)data);
@@ -485,3 +578,232 @@ const std::vector<NetInfosClient>& NA_changeClients::getAddedInfosClients() cons
 const std::vector<NetInfosClient>& NA_changeClients::getRemovedInfosClients() const {
   return m_netRemovedInfosClients;
 }
+
+NA_playerControl::NA_playerControl(PlayerControl i_control, float i_value) {
+  m_control = i_control;
+  m_value = i_value;
+}
+
+NA_playerControl::NA_playerControl(PlayerControl i_control, bool i_value) {
+  m_control = i_control;
+  m_value = i_value ? 0.5 : -0.5; // negativ or positiv
+}
+
+NA_playerControl::NA_playerControl(void* data, unsigned int len) {
+  unsigned int v_localOffset = 0;
+
+  m_control = (PlayerControl) atoi(getLine(data, len, &v_localOffset).c_str());
+  if(PlayerControl_isValid(m_control) == false) {
+    throw Exception("Invalid player control");
+  }
+
+  if(len-v_localOffset-1 != 4) {
+    throw Exception("Invalid player control");
+  }
+  
+  m_value = SwapEndian::read4LFloat(((char*)data) + v_localOffset);
+
+  // don't allow value not between -1 and 1, but don't reject the client if not because float can be sometimes surprising
+  if(m_value < -1.0) m_value = -1.0;
+  if(m_value >  1.0) m_value =  1.0;
+}
+
+NA_playerControl::~NA_playerControl() {
+}
+
+void NA_playerControl::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  char buf[7];
+  snprintf(buf, 3, "%i\n", (int)(m_control));
+  SwapEndian::write4LFloat(buf+2, m_value);
+  NetAction::send(i_tcpsd, i_udpsd, i_sendPacket, i_udpRemoteIP, buf, 6); // don't send the \0
+}
+
+PlayerControl NA_playerControl::getType() {
+  return m_control;
+}
+
+float NA_playerControl::getFloatValue() {
+  return m_value;
+}
+
+bool NA_playerControl::getBoolValue() {
+  return m_value > 0.0;
+}
+
+NA_clientMode::NA_clientMode(NetClientMode i_mode) {
+  m_mode = i_mode;
+}
+
+NA_clientMode::NA_clientMode(void* data, unsigned int len) {
+  unsigned int v_localOffset = 0;
+  m_mode = (NetClientMode) (atoi(getLine(data, len, &v_localOffset).c_str()));
+}
+
+NA_clientMode::~NA_clientMode() {
+}
+
+void NA_clientMode::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  std::ostringstream v_send;
+  v_send << m_mode;
+
+  // force TCP
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
+}
+
+NetClientMode NA_clientMode::mode() const {
+  return m_mode;
+}
+
+NA_prepareToPlay::NA_prepareToPlay(const std::string& i_id_level, std::vector<int>& i_players) {
+  m_id_level = i_id_level;
+
+  // copy the vector
+  m_players = i_players;
+}
+
+NA_prepareToPlay::NA_prepareToPlay(void* data, unsigned int len) {
+  unsigned int v_localOffset = 0;
+  unsigned int v_nplayers;
+
+  m_id_level = getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
+  v_nplayers = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str());
+  for(unsigned int i=0; i<v_nplayers; i++) {
+    m_players.push_back(atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str()));
+  }
+}
+
+NA_prepareToPlay::~NA_prepareToPlay() {
+}
+
+void NA_prepareToPlay::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  std::ostringstream v_send;
+  v_send << m_id_level       << "\n";
+  v_send << m_players.size() << "\n";
+  for(unsigned int i=0; i<m_players.size(); i++) {
+    v_send << m_players[i]   << "\n";
+  }
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
+}
+
+std::string NA_prepareToPlay::idLevel() const {
+  return m_id_level;
+}
+
+const std::vector<int>& NA_prepareToPlay::players() {
+  return m_players;
+}
+
+NA_killAlert::NA_killAlert(int i_time) {
+  m_time = i_time;
+}
+
+NA_killAlert::NA_killAlert(void* data, unsigned int len) {
+  unsigned int v_localOffset = 0;
+  m_time = atoi(getLine(data, len, &v_localOffset).c_str());
+}
+
+NA_killAlert::~NA_killAlert() {
+}
+
+void NA_killAlert::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  std::ostringstream v_send;
+  v_send << m_time;
+
+  // force TCP
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
+}
+
+int NA_killAlert::time() const {
+  return m_time;
+}
+
+NA_prepareToGo::NA_prepareToGo(int i_time) {
+  m_time = i_time;
+}
+
+NA_prepareToGo::NA_prepareToGo(void* data, unsigned int len) {
+  unsigned int v_localOffset = 0;
+  m_time = atoi(getLine(data, len, &v_localOffset).c_str());
+}
+
+NA_prepareToGo::~NA_prepareToGo() {
+}
+
+void NA_prepareToGo::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  std::ostringstream v_send;
+  v_send << m_time;
+  
+  // force TCP
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
+}
+
+int NA_prepareToGo::time() const {
+  return m_time;
+}
+
+NA_gameEvents::NA_gameEvents(DBuffer* i_buffer) {
+  m_bufferLength = i_buffer->copyTo(m_buffer, XM_NET_MAX_EVENTS_SHOT_SIZE);
+}
+
+NA_gameEvents::NA_gameEvents(void* data, unsigned int len) {
+  m_bufferLength = len-1;
+  memcpy(m_buffer, data, len-1);
+}
+
+NA_gameEvents::~NA_gameEvents() {
+}
+
+void NA_gameEvents::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  // force TCP
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, m_buffer, m_bufferLength); // don't send the \0
+}
+
+char* NA_gameEvents::buffer() {
+  return m_buffer;
+}
+
+int NA_gameEvents::bufferSize() {
+  return m_bufferLength;
+}
+
+NA_srvCmd::NA_srvCmd(const std::string& i_cmd) {
+  m_cmd = i_cmd;
+}
+
+NA_srvCmd::NA_srvCmd(void* data, unsigned int len) {
+  ((char*)data)[len-1] = '\0';
+  m_cmd = std::string((char*)data);
+  ((char*)data)[len-1] = '\n';
+}
+
+NA_srvCmd::~NA_srvCmd() {
+}
+
+void NA_srvCmd::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, m_cmd.c_str(), m_cmd.size()); // don't send the \0
+}
+
+std::string NA_srvCmd::getCommand() {
+  return m_cmd;
+}
+
+NA_srvCmdAsw::NA_srvCmdAsw(const std::string& i_answer) {
+  m_answer = i_answer;
+}
+
+NA_srvCmdAsw::NA_srvCmdAsw(void* data, unsigned int len) {
+  ((char*)data)[len-1] = '\0';
+  m_answer = std::string((char*)data);
+  ((char*)data)[len-1] = '\n';
+}
+
+NA_srvCmdAsw::~NA_srvCmdAsw() {
+}
+
+void NA_srvCmdAsw::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, m_answer.c_str(), m_answer.size()); // don't send the \0
+}
+
+std::string NA_srvCmdAsw::getAnswer() {
+  return m_answer;
+}
