@@ -30,9 +30,11 @@ class NetServer : public Singleton<NetServer> {
   NetServer();
   ~NetServer();
 
-  void start();
+  void start(bool i_deamon);
   void stop();
   bool isStarted();
+  void wait();
+  bool acceptConnections();
 
   private:
   ServerThread* m_serverThread;
