@@ -26,8 +26,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../Universe.h"
 #include "../Renderer.h"
 
-StateCreditsMode::StateCreditsMode(Universe* i_universe, const std::string& i_replay, ReplayBiker* i_replayBiker):
-StateReplaying(i_universe, i_replay, i_replayBiker)
+StateCreditsMode::StateCreditsMode(const std::string& i_id, Universe* i_universe, const std::string& i_replay, ReplayBiker* i_replayBiker):
+StateReplaying(i_id, i_universe, i_replay, i_replayBiker)
 {
   m_credits = new Credits();
   m_name    = "StateCreditsMode";
@@ -78,5 +78,7 @@ void StateCreditsMode::abort() {
 }
 
 void StateCreditsMode::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
-  abort();
+  if(!i_xmkey.isDirectionnel()) {
+    abort();
+  }
 }
