@@ -25,16 +25,20 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 class StateDeadJust : public StateScene {
   public:
-  StateDeadJust(Universe* i_universe);
+  StateDeadJust(Universe* i_universe, const std::string& i_id);
   virtual ~StateDeadJust();
   
   virtual void enter();
+  virtual bool update();
   
   /* input */
   virtual void xmKey(InputEventType i_type, const XMKey& i_xmkey);
 
   virtual void restartLevel(bool i_reloadLevel = false);
   virtual void nextLevel(bool i_positifOrder = true);
+
+  private:
+  int m_enterTime;
 };
 
 #endif
