@@ -110,7 +110,8 @@ void StateLevelInfoViewer::checkEvents()
       if(pListEntry != NULL && !pListEntry->Text.empty()) {
 	/* Do it captain */
 	std::string playSpecificReplay = pListEntry->Text[0];
-	StateManager::instance()->pushState(new StatePreplayingReplay(playSpecificReplay, false));
+	StateManager::instance()->pushState(new StatePreplayingReplay(StateManager::instance()->getUniqueId(),
+								      playSpecificReplay, false));
       }
     }
   }
@@ -435,7 +436,7 @@ void StateLevelInfoViewer::updateLevelInfoViewerBestTimes() {
     if(pLV_BestTimes_All->getChecked()) {
       v_result = xmDatabase::instance("main")->readDB("SELECT finishTime, id_profile FROM profile_completedLevels "
 			      "WHERE id_level=\""   + xmDatabase::protectString(m_level)    + "\" "
-			      "ORDER BY finishTime LIMIT 10;",
+			      "ORDER BY finishTime+0 LIMIT 10;",
 			      nrow);
       for(unsigned int i=0; i<nrow; i++) {
 	v_finishTime  = atoi(xmDatabase::instance("main")->getResult(v_result, 2, i, 0));
@@ -449,7 +450,7 @@ void StateLevelInfoViewer::updateLevelInfoViewerBestTimes() {
       v_result = xmDatabase::instance("main")->readDB("SELECT finishTime FROM profile_completedLevels "
 			      "WHERE id_profile=\"" + xmDatabase::protectString(XMSession::instance()->profile())  + "\" "
 			      "AND   id_level=\""   + xmDatabase::protectString(m_level)    + "\" "
-			      "ORDER BY finishTime LIMIT 10;",
+			      "ORDER BY finishTime+0 LIMIT 10;",
 			      nrow);
       for(unsigned int i=0; i<nrow; i++) {
 	v_finishTime  = atoi(xmDatabase::instance("main")->getResult(v_result, 1, i, 0));
