@@ -25,6 +25,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../gui/specific/GUIXMoto.h"
 #include "../XMSession.h"
 #include "StatePreplayingGame.h"
+#include "StatePreplayingNet.h"
 #include "StatePreplayingReplay.h"
 #include "StateLevelInfoViewer.h"
 #include "StateMessageBox.h"
@@ -48,6 +49,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../thread/LevelsPacksCountUpdateThread.h"
 #include "../SysMessage.h"
 #include "../net/NetClient.h"
+#include "states/StateWaitServerInstructions.h"
 
 /* static members */
 UIRoot*  StateMainMenu::m_sGUI = NULL;
@@ -96,6 +98,7 @@ StateMainMenu::StateMainMenu(bool drawStateBehind,
 
   StateManager::instance()->registerAsObserver("REPLAYS_DELETE", this);
   StateManager::instance()->registerAsObserver("UPDATEPROFILE", this);
+  StateManager::instance()->registerAsObserver("UPDATEREFERENCEROOM", this);
   StateManager::instance()->registerAsObserver("NEW_LEVELS_TO_DOWNLOAD", this);
   StateManager::instance()->registerAsObserver("NO_NEW_LEVELS_TO_DOWNLOAD", this);
   StateManager::instance()->registerAsObserver("FAVORITES_UPDATED", this);
@@ -139,6 +142,7 @@ StateMainMenu::~StateMainMenu()
 
   StateManager::instance()->unregisterAsObserver("REPLAYS_DELETE", this);
   StateManager::instance()->unregisterAsObserver("UPDATEPROFILE", this);
+  StateManager::instance()->unregisterAsObserver("UPDATEREFERENCEROOM", this);
   StateManager::instance()->unregisterAsObserver("NEW_LEVELS_TO_DOWNLOAD", this);
   StateManager::instance()->unregisterAsObserver("NO_NEW_LEVELS_TO_DOWNLOAD", this);
   StateManager::instance()->unregisterAsObserver("FAVORITES_UPDATED", this);
@@ -183,7 +187,7 @@ void StateMainMenu::enter()
   if(XMSession::instance()->profile() == "" ||
      xmDatabase::instance("main")->stats_checkKeyExists_stats_profiles(XMSession::instance()->sitekey(),
 								       XMSession::instance()->profile()) == false) {
-    StateManager::instance()->pushState(new StateEditProfile(this));
+    StateManager::instance()->pushState(new StateEditProfile(StateManager::instance()->getUniqueId()));
     
     /* in case there is no profile, we show a message box */
     /* Should we show a notification box? (with important one-time info) */
@@ -214,6 +218,7 @@ void StateMainMenu::remakePacks() {
   LevelsManager::instance()->makePacks(XMSession::instance()->profile(),
 				       XMSession::instance()->idRoom(0),
 				       XMSession::instance()->debug(),
+				       XMSession::instance()->adminMode(),
 				       xmDatabase::instance("main"));
   updateLevelsPacksList();
 }
@@ -329,7 +334,8 @@ void StateMainMenu::checkEventsMainWindow() {
     } catch(Exception &e) {
       v_id_level = "tut1";
     }
-    StateManager::instance()->pushState(new StatePreplayingGame(v_id_level, false));
+    StateManager::instance()->pushState(new StatePreplayingGame(StateManager::instance()->getUniqueId(),
+								v_id_level, false));
   }
 
   // quit
@@ -382,7 +388,7 @@ void StateMainMenu::checkEventsMainWindow() {
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:CHANGEPLAYERBUTTON"));
   if(v_button->isClicked()) {
     v_button->setClicked(false);
-    StateManager::instance()->pushState(new StateEditProfile(this));
+    StateManager::instance()->pushState(new StateEditProfile(StateManager::instance()->getUniqueId()));
   }
 
   // new levels ?
@@ -406,7 +412,8 @@ void StateMainMenu::checkEventsMainWindow() {
     v_button->setClicked(false);
 
     GameApp::instance()->setCurrentPlayingList(getInfoFrameLevelsList());
-    StateManager::instance()->pushState(new StateDownloadGhost(getInfoFrameLevelId(), true));
+    StateManager::instance()->pushState(new StateDownloadGhost(StateManager::instance()->getUniqueId(),
+							       getInfoFrameLevelId(), true));
   }
 }
 
@@ -489,6 +496,18 @@ void StateMainMenu::checkEventsNetworkTab() {
     }
   }
 
+  // multi scenes
+  v_button = reinterpret_cast<UIButton*>(m_GUI->getChild("MAIN:FRAME_LEVELS:TABS:NET_TAB:SERVER_SIMPLE_GHOST_MODE"));
+  if(v_button->isClicked()) {
+    v_button->setClicked(false);
+  
+    XMSession::instance()->setClientGhostMode(v_button->getChecked());
+  
+    if(NetClient::instance()->isConnected()) {
+      SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_SERVERRECONNECT);
+    }
+  }
+
   // connect/disconnect
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:FRAME_LEVELS:TABS:NET_TAB:CONNECTDISCONNECT"));
   if(v_button->isClicked()) {
@@ -500,6 +519,13 @@ void StateMainMenu::checkEventsNetworkTab() {
       try {
 	NetClient::instance()->connect(XMSession::instance()->clientServerName(),
 				       XMSession::instance()->clientServerPort());
+	// don't send in ghost mode to be compatible with old servers
+	if(XMSession::instance()->clientGhostMode() == false) {
+	  NetClient::instance()->changeMode(XMSession::instance()->clientGhostMode() ? NETCLIENT_GHOST_MODE : NETCLIENT_SLAVE_MODE);
+	}
+	if(XMSession::instance()->clientGhostMode() == false) {
+	  StateManager::instance()->pushState(new StateWaitServerInstructions(StateManager::instance()->getUniqueId()));
+	}
       } catch(Exception &e) {
 	SysMessage::instance()->displayError(GAMETEXT_UNABLETOCONNECTONTHESERVER);
 	LogError("Unable to connect to the server");
@@ -542,7 +568,8 @@ void StateMainMenu::checkEventsLevelsFavoriteTab() {
 
     if(v_id_level != "") {
       GameApp::instance()->setCurrentPlayingList(v_list);
-      StateManager::instance()->pushState(new StatePreplayingGame(v_id_level, false));
+      StateManager::instance()->pushState(new StatePreplayingGame(StateManager::instance()->getUniqueId(),
+								  v_id_level, false));
     }
   }
 
@@ -589,7 +616,8 @@ void StateMainMenu::checkEventsLevelsNewTab() {
 
     if(v_id_level != "") {
       GameApp::instance()->setCurrentPlayingList(v_list);
-      StateManager::instance()->pushState(new StatePreplayingGame(v_id_level, false));
+      StateManager::instance()->pushState(new StatePreplayingGame(StateManager::instance()->getUniqueId(),
+								  v_id_level, false));
     }
   }
 
@@ -1241,6 +1269,15 @@ UIWindow* StateMainMenu::makeWindowLevels(UIWindow* i_parent) {
   v_edit->setID("PORT");
   v_edit->setContextHelp(CONTEXTHELP_SERVERPORT);
 
+  // mode
+  v_button = new UIButton(v_netOptionsTab, v_netOptionsTab->getPosition().nWidth-220, 60, 
+  			  GAMETEXT_CLIENTGHOSTMODE, 220, 25);
+  v_button->setType(UI_BUTTON_TYPE_CHECK);
+  v_button->setFont(drawlib->getFontSmall());
+  v_button->setID("SERVER_SIMPLE_GHOST_MODE");
+  v_button->setGroup(50058);
+  v_button->setContextHelp(CONTEXTHELP_CLIENTGHOSTMODE); 
+
   // client status
   v_someText = new UIStatic(v_netOptionsTab, 0, v_netOptionsTab->getPosition().nHeight-30-20-20, "...",
 			    v_netOptionsTab->getPosition().nWidth, 30);
@@ -1436,6 +1473,11 @@ void StateMainMenu::executeOneCommand(std::string cmd, std::string args)
     updateStats();
   }
 
+  else if(cmd == "UPDATEREFERENCEROOM") {
+    updateProfileStrings();
+    m_require_updateLevelsList = true;
+  }
+
   else if(cmd == "REPLAYS_DELETE") {
     UIList* v_list = reinterpret_cast<UIList *>(m_GUI->getChild("MAIN:FRAME_REPLAYS:REPLAYS_LIST"));
     if(v_list->getSelected() >= 0 && v_list->getSelected() < v_list->getEntries().size()) {
@@ -1642,13 +1684,18 @@ void StateMainMenu::updateReplaysList() {
   unsigned int nrow;
   bool v_listAll;
   UIList* v_list;
-  int v_selected;
+  std::string v_selected_replay;
 
   v_listAll = ((UIButton *) m_GUI->getChild("MAIN:FRAME_REPLAYS:REPLAYS_LIST_ALL"))->getChecked();
   v_list = (UIList *) m_GUI->getChild("MAIN:FRAME_REPLAYS:REPLAYS_LIST");
 
+
   /* Clear list */
-  v_selected = v_list->getSelected();
+  int v_selected = v_list->getSelected();
+  if(v_list->getSelected() >= 0 && v_list->getSelected() < v_list->getEntries().size()) {
+    v_selected_replay = v_list->getEntries()[v_list->getSelected()]->Text[0];
+  }
+
   v_list->clear();
     
   /* Enumerate replays */
@@ -1674,7 +1721,22 @@ void StateMainMenu::updateReplaysList() {
   }
   xmDatabase::instance("main")->read_DB_free(v_result); 
 
-  v_list->setRealSelected(v_selected);
+ /* reselect the previous replay */
+  if(v_selected_replay != "") {
+    int nReplay = -1;
+    for(unsigned int i=0; i<v_list->getEntries().size(); i++) {
+      if(v_list->getEntries()[i]->Text[0] == v_selected_replay) {
+	nReplay = i;
+	break;
+      }
+    }
+
+    if(nReplay == -1) { // replay not found, keep the same number in the list
+      v_list->setRealSelected(v_selected);
+    } else {
+      v_list->setRealSelected(nReplay);
+    }
+  }
 
   // apply the filter
   UIEdit*      v_edit;
@@ -1713,7 +1775,8 @@ void StateMainMenu::checkEventsReplays() {
     if(v_list->getSelected() >= 0 && v_list->getSelected() < v_list->getEntries().size()) {
       UIListEntry *pListEntry = v_list->getEntries()[v_list->getSelected()];
       if(pListEntry != NULL) {
-	StateManager::instance()->pushState(new StatePreplayingReplay(pListEntry->Text[0], false));
+	StateManager::instance()->pushState(new StatePreplayingReplay(StateManager::instance()->getUniqueId(),
+								      pListEntry->Text[0], false));
       }
     }
   }
@@ -1791,6 +1854,8 @@ void StateMainMenu::updateOptions() {
   // network
   v_edit = reinterpret_cast<UIEdit *>(m_GUI->getChild("MAIN:FRAME_LEVELS:TABS:NET_TAB:SERVER"));
   v_edit->setCaption(XMSession::instance()->clientServerName());
+  v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:FRAME_LEVELS:TABS:NET_TAB:SERVER_SIMPLE_GHOST_MODE"));
+  v_button->setChecked(XMSession::instance()->clientGhostMode());
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:FRAME_LEVELS:TABS:NET_TAB:DEFAULT_PORT"));
   v_button->setChecked(XMSession::instance()->clientServerPort() == DEFAULT_CLIENTSERVERPORT);
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:FRAME_LEVELS:TABS:NET_TAB:CUSTOM_PORT"));
@@ -1858,6 +1923,8 @@ void StateMainMenu::updateReplaysRights() {
   std::string v_replay;
   ReplayInfo* rplInfos;
 
+  // upload button
+  v_button->enableWindow(false);
   if(v_list->nbVisibleItems() > 0) {
     UIListEntry *pEntry = v_list->getEntries()[v_list->getSelected()];
     if(pEntry != NULL) {
@@ -1893,8 +1960,6 @@ void StateMainMenu::updateReplaysRights() {
 	delete rplInfos;
       }
     }
-  } else {
-    v_button->enableWindow(false);
   }
 
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:FRAME_REPLAYS:REPLAYS_SHOW_BUTTON"));
