@@ -32,6 +32,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "StateLevelPackViewer.h"
 #include "StateRequestKey.h"
 #include "StateOptions.h"
+#include "StateServerConsole.h"
 #include "StateVote.h"
 #include "../net/NetClient.h"
 
@@ -43,6 +44,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../SysMessage.h"
 #include "../xmscene/Camera.h"
 #include "../VideoRecorder.h"
+#include <sstream>
 
 StateManager::StateManager()
 {
@@ -74,6 +76,8 @@ StateManager::StateManager()
 					XMSession::instance()->videoRecordingDivision(),
 					XMSession::instance()->videoRecordingFramerate());
   }
+
+  m_currentUniqueId = 0;
 }
 
 StateManager::~StateManager()
@@ -91,6 +95,13 @@ StateManager::~StateManager()
   m_registeredStates.clear();
 }
 
+std::string StateManager::getUniqueId() {
+  std::ostringstream v_n;
+  v_n << m_currentUniqueId;
+  m_currentUniqueId++;
+  return v_n.str();
+}
+
 void StateManager::pushState(GameState* pNewState)
 {
   if(m_statesStack.size() != 0){
@@ -132,23 +143,21 @@ void StateManager::flush() {
   }
 }
 
-void StateManager::replaceState(GameState* pNewState)
+void StateManager::replaceState(GameState* pNewState, const std::string& i_parentId)
 {
-  GameState* pPreviousState = NULL;
-
-  if(m_statesStack.size() != 0){
-    (m_statesStack.back())->leave();
-    pPreviousState = m_statesStack.back();
-    m_statesStack.pop_back();
+  for(int i=m_statesStack.size()-1; i>=0; i--) {
+    if(m_statesStack[i]->getId() == i_parentId) {
+      m_statesStack[i]->leave();
+      m_toDeleteStates.push_back(m_statesStack[i]);
+      m_statesStack[i] = pNewState;
+      pNewState->enter();
+      calculateWhichStateIsRendered();
+      calculateFps();
+      return;
+    }
   }
-  
-  m_statesStack.push_back(pNewState);
-  (m_statesStack.back())->enter();
 
-  calculateWhichStateIsRendered();
-  calculateFps();
-
-  m_toDeleteStates.push_back(pPreviousState);
+  throw Exception("No state to replace");
 }
 
 bool StateManager::needUpdateOrRender() {
@@ -209,7 +218,7 @@ void StateManager::update()
   }
 
   /* update net */
-  NetClient::instance()->executeNetActions();
+  NetClient::instance()->executeNetActions(xmDatabase::instance("main"));
 
   /* update fps */
   if(m_lastFpsTime + 1000 < GameApp::getXMTimeInt()) {
@@ -245,6 +254,7 @@ void StateManager::renderOverAll() {
     
     for(unsigned int i=0; i<NetClient::instance()->otherClients().size(); i++) {
       v_fg = GameApp::instance()->getDrawLib()->getFontSmall()->getGlyph(NetClient::instance()->otherClients()[i]->name());
+
       v_fm->printString(v_fg,
 			GameApp::instance()->getDrawLib()->getDispWidth() - v_fg->realWidth() - vborder, vborder+v_voffset,
 			MAKE_COLOR(200,200,200,255), -1.0, true);     
@@ -323,8 +333,13 @@ VideoRecorder* StateManager::getVideoRecorder() {
 }
 
 void StateManager::drawFps() {
-  char cTemp[256];        
-  snprintf(cTemp, 256, "u(%i) d(%i)", getCurrentUpdateFPS(), getCurrentRenderFPS());
+  char cTemp[128];        
+
+  if(NetClient::instance()->isConnected()) {
+    snprintf(cTemp, 128, "u(%i) d(%i) n(%i)", getCurrentUpdateFPS(), getCurrentRenderFPS(), NetClient::instance()->getOwnFrameFPS());
+  } else {
+    snprintf(cTemp, 128, "u(%i) d(%i)", getCurrentUpdateFPS(), getCurrentRenderFPS());
+  }
 
   FontManager* v_fm = GameApp::instance()->getDrawLib()->getFontSmall();
   FontGlyph* v_fg = v_fm->getGlyph(cTemp);
@@ -362,7 +377,12 @@ void StateManager::drawStack() {
 
     drawLib->drawBox(Vector2f(xoff,     yoff - (i * h)), Vector2f(xoff + w/2, yoff - ((i+1) * h)), 1.0, bg_update);
     drawLib->drawBox(Vector2f(xoff+w/2, yoff - (i * h)), Vector2f(xoff + w,   yoff - ((i+1) * h)), 1.0, bg_render);
-    v_fg = v_fm->getGlyph(m_statesStack[i]->getName());
+
+    if(m_statesStack[i]->getId() == "") {
+      v_fg = v_fm->getGlyph(m_statesStack[i]->getName());
+    } else {
+      v_fg = v_fm->getGlyph(m_statesStack[i]->getName() + " (" + m_statesStack[i]->getId() + ")");
+    }
     v_fm->printString(v_fg, (w-v_fg->realWidth())/2 + xoff, yoff - ((i+1) * h - v_fg->realHeight()/2), font_color, 0.0, true);
 
     i++;
@@ -477,6 +497,7 @@ void StateManager::cleanStates() {
   StateRequestKey::clean();
   StateOptions::clean();
   StateVote::clean();
+  StateServerConsole::clean();
 }
 
 void StateManager::refreshStaticCaptions() {
@@ -680,3 +701,13 @@ bool StateManager::isThereASuchState(const std::string& i_name) {
 
   return false;
 }
+
+bool StateManager::isThereASuchStateId(const std::string& i_id) {
+  for(unsigned int i=0; i<m_statesStack.size(); i++) {
+    if(m_statesStack[i]->getId() == i_id) {
+      return true;
+    }
+  }
+
+  return false;
+}
