@@ -33,7 +33,7 @@ StateMessageBox::StateMessageBox(StateMessageBoxReceiver* i_receiver,
 				 bool updateStatesBehind,
 				 bool i_verticallyLarge):
   StateMenu(drawStateBehind,
-	    updateStatesBehind)
+	    updateStatesBehind, true, false)
 {
   m_receiver      = i_receiver;
   m_clickedButton = UI_MSGBOX_NOTHING;
@@ -54,6 +54,8 @@ void StateMessageBox::leave()
 {
   if(m_receiver != NULL) {
     m_receiver->sendFromMessageBox(getId(), m_clickedButton, m_msgbox->getTextInput());
+  } else {
+    sendFromMessageBox(getId(), m_clickedButton, m_msgbox->getTextInput());
   }
 }
 
