@@ -46,9 +46,9 @@ UIRoot*  StateOptions::m_sGUI = NULL;
 
 StateOptions::StateOptions(bool drawStateBehind, bool updateStatesBehind):
   StateMenu(drawStateBehind,
-	    updateStatesBehind) {
+	    updateStatesBehind, true, false) {
   m_name = "StateOptions";
-
+ 
   StateManager::instance()->registerAsObserver("UPDATEPROFILE", this);
   StateManager::instance()->registerAsObserver("THEMES_UPDATED", this);
   StateManager::instance()->registerAsObserver("ROOMS_UPDATED", this);
@@ -78,6 +78,11 @@ void StateOptions::enter()
   updateOptions();
   updateServerStrings();
   updateJoysticksStrings();
+  
+  if(XMSession::instance()->ugly()) {   // needed to show cursor on option menu while playing level
+    GameApp::instance()->displayCursor(true);
+  }
+
 }
 
 void StateOptions::clean() {
@@ -144,6 +149,12 @@ void StateOptions::checkEvents() {
     v_button->setClicked(false);
     XMSession::instance()->setEnableActiveZoom(v_button->getChecked()); 
   }
+  
+  v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:MAIN_TAB:CAMERATRAILCAM"));
+  if(v_button->isClicked()) {
+    v_button->setClicked(false);
+    XMSession::instance()->setEnableTrailCam(v_button->getChecked()); 
+  } 
 
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:MAIN_TAB:BEATINGMODE"));
   if(v_button->isClicked()) {
@@ -175,6 +186,8 @@ void StateOptions::checkEvents() {
 	GameApp::instance()->reloadTheme();
       }
       */
+
+      SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_RESTART);
     }
   }
 
@@ -185,9 +198,13 @@ void StateOptions::checkEvents() {
   }
 
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:THEME_TAB:GET_SELECTED"));
+  bool v_enabled = !(StateManager::instance()->isThereASuchState("StatePlayingLocal")
+		  || StateManager::instance()->isThereASuchState("StatePreplayingGame")
+		  || StateManager::instance()->isThereASuchState("StateDeadJust")
+		  || StateManager::instance()->isThereASuchState("StatePlayingNet"));
+  v_button->enableWindow(v_enabled);
   if(v_button->isClicked()) {
     v_button->setClicked(false);
-
     if(v_list->getSelected() >= 0 && v_list->getSelected() < v_list->getEntries().size()) {
       UIListEntry *pEntry = v_list->getEntries()[v_list->getSelected()];
       StateManager::instance()->pushState(new StateUpdateTheme(pEntry->Text[0]));
@@ -199,11 +216,14 @@ void StateOptions::checkEvents() {
   if(v_button->isClicked()) {
     v_button->setClicked(false);
     XMSession::instance()->setBpp(16); 
+    SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_RESTART);
   }
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:VIDEO_TAB:32BPP"));
+
   if(v_button->isClicked()) {
     v_button->setClicked(false);
-    XMSession::instance()->setBpp(32); 
+    XMSession::instance()->setBpp(32);
+    SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_RESTART);
   }
 
   v_list = reinterpret_cast<UIList *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:VIDEO_TAB:RESOLUTIONS_LIST"));
@@ -216,6 +236,8 @@ void StateOptions::checkEvents() {
       sscanf(pEntry->Text[0].c_str(),"%d X %d", &nW, &nH);
       XMSession::instance()->setResolutionWidth(nW);
       XMSession::instance()->setResolutionHeight(nH);
+
+      SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_RESTART);
     }
   }
 
@@ -223,6 +245,8 @@ void StateOptions::checkEvents() {
   if(v_button->isClicked()) {
     v_button->setClicked(false);
     XMSession::instance()->setWindowed(v_button->getChecked());
+
+    SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_RESTART);
   }
 
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:VIDEO_TAB:MENULOW"));
@@ -415,18 +439,33 @@ void StateOptions::checkEvents() {
     XMSession::instance()->setWwwPassword(v_edit->getCaption());
   }
 
+  std::string v_tabId;
   for(unsigned int i=0; i<XMSession::instance()->nbRoomsEnabled(); i++) {
       std::ostringstream v_strRoom;
       v_strRoom << i;
 
-      v_list = reinterpret_cast<UIList *>(m_GUI->getChild("MAIN:TABS:WWW_TAB:TABS:ROOMS_TAB_" + v_strRoom.str()
-							  + ":ROOMS_LIST"));
+      v_tabId = "MAIN:TABS:WWW_TAB:TABS:ROOMS_TAB_" + v_strRoom.str();
+      v_list = reinterpret_cast<UIList *>(m_GUI->getChild(v_tabId + ":ROOMS_LIST"));
+
+      /* check filter */
+      v_edit = reinterpret_cast<UIEdit *>(m_GUI->getChild(v_tabId + ":ROOMS_FILTER"));
+      if(v_edit->hasChanged()) {
+      	v_edit->setHasChanged(false);
+      	v_list->setFilter(v_edit->getCaption());
+      }
+
       if(v_list->isChanged()) {
 	v_list->setChanged(false);
 	if(v_list->getSelected() >= 0 && v_list->getSelected() < v_list->getEntries().size()) {
 	  v_list->getEntries()[v_list->getSelected()];
 	  XMSession::instance()->setIdRoom(i, *((std::string*)v_list->getEntries()[v_list->getSelected()]->pvUser));
 	  updateProfileStrings();
+
+	  // reference room was changed
+	  if(i==0) {
+	    // tell that to other states
+	    StateManager::instance()->sendAsynchronousMessage("UPDATEREFERENCEROOM");
+	  }
 	}
       }
 
@@ -505,7 +544,7 @@ void StateOptions::checkEvents() {
     if(NetServer::instance()->isStarted()) {
       NetServer::instance()->stop();
     } else {
-      NetServer::instance()->start();
+      NetServer::instance()->start(true);
     }
   }
 
@@ -594,6 +633,8 @@ void StateOptions::checkEvents() {
       //std::string v_locale = Locales::changeLocale(XMSession::instance()->language());
       //LogInfo("Locales changed to '%s'", v_locale.c_str());
       //StateManager::instance()->refreshStaticCaptions();
+
+      SysMessage::instance()->displayInformation(GAMETEXT_OPTION_NEED_TO_RESTART);
     }
   }
 
@@ -697,7 +738,7 @@ UIWindow* StateOptions::makeWindowOptions_general(UIWindow* i_parent) {
   v_button->setGroup(50023);
   v_button->setContextHelp(CONTEXTHELP_SHOWCONTEXTHELP);
  
-  v_button = new UIButton(v_window, 5, 123-10, GAMETEXT_AUTOSAVEREPLAYS, (v_window->getPosition().nWidth-40)/*/2*/, 28);
+  v_button = new UIButton(v_window, 5, 123-10, GAMETEXT_AUTOSAVEREPLAYS, (v_window->getPosition().nWidth-40)/2, 28);
   v_button->setType(UI_BUTTON_TYPE_CHECK);
   v_button->setID("AUTOSAVEREPLAYS");
   v_button->setFont(drawlib->getFontSmall());
@@ -729,8 +770,17 @@ UIWindow* StateOptions::makeWindowOptions_general(UIWindow* i_parent) {
   v_button->setGroup(50023);
   v_button->setContextHelp(CONTEXTHELP_CAMERAACTIVEZOOM);
 
+  /* Button to enable/disable trail cam */
+  v_button = new UIButton(v_window, 5+(v_window->getPosition().nWidth+40)/2, 123-10, GAMETEXT_CAMERATRAILCAM,
+			  (v_window->getPosition().nWidth-40)/2, 28);
+  v_button->setType(UI_BUTTON_TYPE_CHECK);
+  v_button->setID("CAMERATRAILCAM");
+  v_button->setFont(drawlib->getFontSmall());
+  v_button->setGroup(50023);
+  v_button->setContextHelp(CONTEXTHELP_CAMERATRAILCAM);
+
   /* Button to enable/disable beating mode */
-  v_button = new UIButton(v_window, 5+(v_window->getPosition().nWidth+40)/2, 123-10, GAMETEXT_BEATINGMODE,
+  v_button = new UIButton(v_window, 5+(v_window->getPosition().nWidth+40)/2, 153-10, GAMETEXT_BEATINGMODE,
 			  (v_window->getPosition().nWidth-40)/2, 28);
   v_button->setType(UI_BUTTON_TYPE_CHECK);
   v_button->setID("BEATINGMODE");
@@ -1257,11 +1307,17 @@ UIWindow* StateOptions::makeWindowOptions_language(UIWindow* i_parent) {
 
   unsigned int i=0;
   while(LANGUAGES[i][LANGUAGE_NAME] != NULL) {
-    pEntry = v_list->addEntry(LANGUAGES[i][LANGUAGE_NAME], NULL);
+    
+    if(std::string(_("FontGroup:GENERAL")) == std::string("FontGroup:ASIAN")) {
+      pEntry = v_list->addEntry(LANGUAGES[i][LANGUAGE_ASIAN_NAME], NULL);
+    } else {
+      pEntry = v_list->addEntry(LANGUAGES[i][LANGUAGE_NAME], NULL);
+    }
+
     pEntry->Text.push_back(LANGUAGES[i][LANGUAGE_CODE]);
     if(XMSession::instance()->language() == LANGUAGES[i][LANGUAGE_CODE])
       v_list->setRealSelected(i+1);
-
+  
     i++;
   }
 
@@ -1316,6 +1372,8 @@ UIWindow* StateOptions::makeRoomTab(UIWindow* i_parent, unsigned int i_number) {
   UIWindow* v_window;
   UIList*   v_list;
   UIButton*  v_button;
+  UIStatic* v_someText;
+  UIEdit*   v_edit;
   DrawLib* drawlib = GameApp::instance()->getDrawLib();
 
   std::string v_roomTitle;
@@ -1343,7 +1401,15 @@ UIWindow* StateOptions::makeRoomTab(UIWindow* i_parent, unsigned int i_number) {
     v_button->setContextHelp(CONTEXTHELP_ROOM_ENABLE);
   }
 
-  v_list = new UIList(v_window, 20, 25, "", v_window->getPosition().nWidth-215 - 20 - 20, v_window->getPosition().nHeight - 20 - 50);
+  v_someText = new UIStatic(v_window, 20, 25, std::string(GAMETEXT_FILTER) + ":", 90, 25);
+  v_someText->setFont(drawlib->getFontSmall());
+  v_someText->setHAlign(UI_ALIGN_RIGHT);
+  v_edit = new UIEdit(v_window, 120, 25, "", 200, 25);
+  v_edit->setFont(drawlib->getFontSmall());
+  v_edit->setID("ROOMS_FILTER");
+  v_edit->setContextHelp(CONTEXTHELP_ROOMS_FILTER);
+
+  v_list = new UIList(v_window, 20, 55, "", v_window->getPosition().nWidth-215 - 20 - 20, v_window->getPosition().nHeight - 40 - 50);
   v_list->setID("ROOMS_LIST");
   v_list->setFont(drawlib->getFontSmall());
   v_list->addColumn(GAMETEXT_ROOM, v_list->getPosition().nWidth);
@@ -1379,6 +1445,8 @@ void StateOptions::updateOptions() {
   v_button->setChecked(XMSession::instance()->enableDeadAnimation());
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:MAIN_TAB:CAMERAACTIVEZOOM"));
   v_button->setChecked(XMSession::instance()->enableActiveZoom());
+  v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:MAIN_TAB:CAMERATRAILCAM"));
+  v_button->setChecked(XMSession::instance()->enableTrailCam());
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:MAIN_TAB:ENABLECONTEXTHELP"));
   v_button->setChecked(XMSession::instance()->enableContextHelp());
   v_button = reinterpret_cast<UIButton *>(m_GUI->getChild("MAIN:TABS:GENERAL_TAB:TABS:MAIN_TAB:AUTOSAVEREPLAYS"));
@@ -1693,6 +1761,29 @@ void StateOptions::updateControlsList() {
     
   UIListEntry *p;
 
+
+  p = pList->addEntry(GAMETEXT_SWITCHFAVORITE);
+  p->Text.push_back(InputHandler::instance()->getSwitchFavorite().toFancyString());
+  p->Text.push_back(InputHandler::instance()->getSwitchFavorite().toString());
+
+  p = pList->addEntry(GAMETEXT_SWITCHBLACKLIST);
+  p->Text.push_back(InputHandler::instance()->getSwitchBlacklist().toFancyString());
+  p->Text.push_back(InputHandler::instance()->getSwitchBlacklist().toString());
+
+  p = pList->addEntry(GAMETEXT_SWITCHUGLYMODE);
+  p->Text.push_back(InputHandler::instance()->getSwitchUglyMode().toFancyString());
+  p->Text.push_back(InputHandler::instance()->getSwitchUglyMode().toString());
+
+  p = pList->addEntry(GAMETEXT_RESTARTLEVEL);
+  p->Text.push_back(InputHandler::instance()->getRestartLevel().toFancyString());
+  p->Text.push_back(InputHandler::instance()->getRestartLevel().toString());
+
+  p = pList->addEntry(GAMETEXT_SHOWCONSOLE);
+  p->Text.push_back(InputHandler::instance()->getShowConsole().toFancyString());
+  p->Text.push_back(InputHandler::instance()->getShowConsole().toString());
+
+  // player keys
+
   for(unsigned int i=0; i<INPUT_NB_PLAYERS; i++) {
     std::ostringstream v_n;
 
@@ -1730,18 +1821,6 @@ void StateOptions::updateControlsList() {
     } 
   }
 
-  p = pList->addEntry(GAMETEXT_SWITCHFAVORITE);
-  p->Text.push_back(InputHandler::instance()->getSwitchFavorite().toFancyString());
-  p->Text.push_back(InputHandler::instance()->getSwitchFavorite().toString());
-
-  p = pList->addEntry(GAMETEXT_SWITCHBLACKLIST);
-  p->Text.push_back(InputHandler::instance()->getSwitchBlacklist().toFancyString());
-  p->Text.push_back(InputHandler::instance()->getSwitchBlacklist().toString());
-
-  p = pList->addEntry(GAMETEXT_SWITCHUGLYMODE);
-  p->Text.push_back(InputHandler::instance()->getSwitchUglyMode().toFancyString());
-  p->Text.push_back(InputHandler::instance()->getSwitchUglyMode().toString());
-
 }
 
 void StateOptions::createThemesList(UIList *pList) {
@@ -1807,6 +1886,7 @@ void StateOptions::createThemesList(UIList *pList) {
 
 void StateOptions::updateRoomsList() {
   UIList* v_list;
+  std::string v_tabId;
   unsigned int j;
   bool v_found;
 
@@ -1814,8 +1894,8 @@ void StateOptions::updateRoomsList() {
       std::ostringstream v_strRoom;
       v_strRoom << i;
 
-      v_list = reinterpret_cast<UIList *>(m_GUI->getChild("MAIN:TABS:WWW_TAB:TABS:ROOMS_TAB_" + v_strRoom.str()
-							  + ":ROOMS_LIST"));
+      v_tabId = "MAIN:TABS:WWW_TAB:TABS:ROOMS_TAB_" + v_strRoom.str();
+      v_list = reinterpret_cast<UIList *>(m_GUI->getChild(v_tabId + ":ROOMS_LIST"));
       createRoomsList(v_list);
 
       std::string v_id_room = XMSession::instance()->idRoom(i);
@@ -1829,7 +1909,13 @@ void StateOptions::updateRoomsList() {
 	}
 	j++;
       }
+
+      // apply the filter
+      UIEdit*      v_edit;
+      v_edit = reinterpret_cast<UIEdit *>(m_GUI->getChild(v_tabId + ":ROOMS_FILTER"));
+      v_list->setFilter(v_edit->getCaption());
   }
+
 }
 
 void StateOptions::createRoomsList(UIList *pList) {
@@ -2033,4 +2119,12 @@ void StateOptions::setInputKey(const std::string& i_strKey, const std::string& i
   if(i_strKey == GAMETEXT_SWITCHUGLYMODE) {
     InputHandler::instance()->setSwitchUglyMode(XMKey(i_key));
   }
+
+  if(i_strKey == GAMETEXT_RESTARTLEVEL) {
+    InputHandler::instance()->setRestartLevel(XMKey(i_key));
+  }
+
+  if(i_strKey == GAMETEXT_SHOWCONSOLE) {
+    InputHandler::instance()->setShowConsole(XMKey(i_key));
+  }
 }
