@@ -26,38 +26,23 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 class StatePlaying : public StateScene {
   public:
-  StatePlaying(Universe* i_universe);
-  virtual ~StatePlaying();
-  
-  virtual void enter();
-  virtual void leave();
-  /* called when a new state is pushed or poped on top of the
-     current one*/
-  virtual void enterAfterPop();
-  
-  virtual bool update();
-  virtual void abortPlaying();
-  virtual void nextLevel(bool i_positifOrder = true);
-  virtual void restartLevel(bool i_reloadLevel = false);
+  StatePlaying(Universe* i_universe, const std::string& i_id);
+  virtual ~StatePlaying() =0;
 
-  /* input */
-  virtual void xmKey(InputEventType i_type, const XMKey& i_xmkey);
+  virtual void enter();
+  virtual void enterAfterPop();
+  virtual void executeOneCommand(std::string cmd, std::string args);
   virtual bool renderOverShadow();
 
   protected:
-  virtual void executeOneCommand(std::string cmd, std::string args);
+  void handleControllers(InputEventType Type, const XMKey& i_xmkey);
+  void handleScriptKeys(InputEventType Type, const XMKey& i_xmkey);
+  void dealWithActivedKeys(); // apply already pressed keys
+  void updateWithOptions();
+  
+  bool m_displayStats;
 
   private:
-  void onOneFinish();
-  void onAllDead();
-
-  void updateWithOptions();
-
-	void handleInput(Universe* i_universe, InputEventType Type, const XMKey& i_xmkey);
-  void dealWithActivedKeys(Universe* i_universe); // apply already pressed keys
-
-  bool m_gameIsFinished;
-  bool m_displayStats;
   bool m_changeDirKeyAlreadyPress[INPUT_NB_PLAYERS]; // to avoid key repetition
 };
 
