@@ -27,6 +27,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../xmscene/Camera.h"
 #include "../XMSession.h"
 #include "../xmscene/BikePlayer.h"
+#include "../xmscene/BikeGhost.h"
 #include "StateMessageBox.h"
 #include "StateDownloadGhost.h"
 #include "../drawlib/DrawLib.h"
@@ -38,8 +39,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #define PRESTART_ANIMATION_LEVEL_MSG_DURATION 100
 
-StatePreplaying::StatePreplaying(const std::string i_idlevel, bool i_sameLevel):
-  StateScene()
+StatePreplaying::StatePreplaying(const std::string& i_id, const std::string i_idlevel, bool i_sameLevel):
+  StateScene(i_id)
 {
   m_name  = "StatePreplaying";
   m_idlevel = i_idlevel;
@@ -88,7 +89,7 @@ void StatePreplaying::enter()
     initUniverse();
   } catch(Exception &e) {
     delete m_universe;
-    StateManager::instance()->replaceState(new StateMessageBox(NULL, "Ooops", UI_MSGBOX_OK));
+    onLoadingFailure("Ooops");
     return;
   }  
 
@@ -107,7 +108,7 @@ void StatePreplaying::enter()
     snprintf(cBuf, 256, GAMETEXT_LEVELCANNOTBELOADED, m_idlevel.c_str());
     delete m_universe;
     m_universe = NULL;
-    StateManager::instance()->replaceState(new StateMessageBox(NULL, cBuf, UI_MSGBOX_OK));
+    onLoadingFailure(cBuf);
     return;
   }
 
@@ -122,7 +123,7 @@ void StatePreplaying::enter()
       
       delete m_universe;
       m_universe = NULL;
-      StateManager::instance()->replaceState(new StateMessageBox(NULL, cBuf, UI_MSGBOX_OK));
+      onLoadingFailure(cBuf);
       return;
     }
   }
@@ -164,12 +165,13 @@ void StatePreplaying::enter()
     LogWarning(std::string("failed to initialize level\n" + e.getMsg()).c_str());
     delete m_universe;
     m_universe = NULL;
-    StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(e.getMsg(), 50), UI_MSGBOX_OK));
+    onLoadingFailure(e.getMsg());
     return;
   }
 
   if(needToDownloadGhost() == true){
-    StateManager::instance()->pushState(new StateDownloadGhost(m_idlevel));
+    StateManager::instance()->pushState(new StateDownloadGhost(StateManager::instance()->getUniqueId(),
+							       m_idlevel));
   } else {
     m_ghostDownloaded = true;
   }
@@ -180,11 +182,17 @@ void StatePreplaying::enter()
   } else {
     playLevelMusic();
   }
-
+ 
+//   m_universe->getScenes()[0]->getCamera()->getGhostTrail()->initGhostTrail(m_universe->getScenes()[0]->getFileGhost());
   /* prepare stats */
   makeStatsStr();
 }
 
+void StatePreplaying::onLoadingFailure(const std::string& i_msg) {
+  StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(i_msg, 50), UI_MSGBOX_OK),
+					 this->getId());
+}
+
 bool StatePreplaying::shouldBeAnimated() const {
   return m_playAnimation && XMSession::instance()->enableInitZoom() && XMSession::instance()->ugly() == false;
 }
@@ -263,7 +271,7 @@ bool StatePreplaying::render()
 void StatePreplaying::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
   StateScene::xmKey(i_type, i_xmkey);
 
-  if(i_type == INPUT_DOWN) {
+  if(i_type == INPUT_DOWN && !i_xmkey.isDirectionnel()) {
     // don't allow down key so that xmoto -l 1 works with the animation at startup : some pad give events at startup about their status
     m_playAnimation = false;
   }
@@ -287,10 +295,12 @@ void StatePreplaying::secondInitPhase()
       }
     }
 
+    GameRenderer::instance()->prepareForNewLevel(m_universe);
+
   } catch(Exception &e) {
     LogWarning(std::string("failed to initialize level\n" + e.getMsg()).c_str());
     closePlaying();
-    StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(e.getMsg(), 50), UI_MSGBOX_OK));
+    onLoadingFailure(e.getMsg());
     return;
   }
 
@@ -298,7 +308,6 @@ void StatePreplaying::secondInitPhase()
   if(NetClient::instance()->isConnected()) {
     NetClient::instance()->startPlay(m_universe);
   }
-  GameRenderer::instance()->prepareForNewLevel(m_universe);
 
   /* If "preplaying" / "initial-zoom" is enabled, this is where it's done */
   // animation
@@ -319,7 +328,7 @@ void StatePreplaying::secondInitPhase()
       for(unsigned int i=0; i<m_universe->getScenes().size(); i++) {
 	m_universe->getScenes()[i]->gameMessage(m_universe->getScenes()[i]->getLevelSrc()->Name(),
 						false,
-						PRESTART_ANIMATION_LEVEL_MSG_DURATION);
+						PRESTART_ANIMATION_LEVEL_MSG_DURATION, levelID);
       }
     }
   }
@@ -386,3 +395,4 @@ bool StatePreplaying::needToDownloadGhost()
 bool StatePreplaying::allowGhosts() {
   return true;
 }
+
