@@ -28,7 +28,7 @@ class FontGlyph;
 
 class StatePreplaying : public StateScene {
   public:
-  StatePreplaying(const std::string i_idlevel, bool i_sameLevel);
+  StatePreplaying(const std::string& i_id, const std::string i_idlevel, bool i_sameLevel);
   virtual ~StatePreplaying();
   
   virtual void enter();
@@ -55,6 +55,9 @@ class StatePreplaying : public StateScene {
   virtual bool needToDownloadGhost();
   virtual bool allowGhosts();
 
+  // which state to display on failure
+  virtual void onLoadingFailure(const std::string& i_msg);
+
   private:
   void executeOneCommand(std::string cmd, std::string args);
 
