@@ -25,7 +25,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 class StatePreplayingCredits : public StatePreplayingReplay {
   public:
-  StatePreplayingCredits(const std::string i_replay);
+  StatePreplayingCredits(const std::string& i_id, const std::string i_replay);
   virtual ~StatePreplayingCredits();
   
   protected:
