@@ -19,18 +19,19 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
 #include "StatePreplayingGame.h"
-#include "StatePlaying.h"
+#include "StatePlayingLocal.h"
 #include "StateManager.h"
 #include "../XMSession.h"
 #include "../Universe.h"
+#include "../Replay.h"
 #include "../helpers/Log.h"
 #include "../xmscene/Camera.h"
 #include "../xmscene/Level.h"
 #include "../Game.h"
 #include "../xmscene/BikePlayer.h"
 
-StatePreplayingGame::StatePreplayingGame(const std::string i_idlevel, bool i_sameLevel)
-: StatePreplaying(i_idlevel, i_sameLevel) {
+StatePreplayingGame::StatePreplayingGame(const std::string& i_id, const std::string i_idlevel, bool i_sameLevel)
+: StatePreplaying(i_id, i_idlevel, i_sameLevel) {
     m_name  = "StatePreplayingGame";
 }
 
@@ -65,7 +66,7 @@ void StatePreplayingGame::initPlayers() {
     
     for(unsigned int i=0; i<v_nbPlayer; i++) {
       v_world->setCurrentCamera(i);
-      v_world->getCamera()->setPlayerToFollow(v_world->addPlayerBiker(i, v_world->getLevelSrc()->PlayerStart(),
+      v_world->getCamera()->setPlayerToFollow(v_world->addPlayerLocalBiker(i, v_world->getLevelSrc()->PlayerStart(),
 								      DD_RIGHT,
 								      Theme::instance(), Theme::instance()->getPlayerTheme(),
 								      pGame->getColorFromPlayerNumber(i),
@@ -73,6 +74,7 @@ void StatePreplayingGame::initPlayers() {
 								      XMSession::instance()->enableEngineSound()));
       v_world->getCamera()->setScroll(false, v_world->getGravity());
     }
+        
   } else { // multiworlds
     Scene* v_world;
     
@@ -80,7 +82,7 @@ void StatePreplayingGame::initPlayers() {
       v_world = m_universe->getScenes()[i];
       v_world->setCurrentCamera(0);
       
-      v_world->getCamera()->setPlayerToFollow(v_world->addPlayerBiker(i, v_world->getLevelSrc()->PlayerStart(),
+      v_world->getCamera()->setPlayerToFollow(v_world->addPlayerLocalBiker(i, v_world->getLevelSrc()->PlayerStart(),
 								      DD_RIGHT,
 								      Theme::instance(), Theme::instance()->getPlayerTheme(),
 								      pGame->getColorFromPlayerNumber(i),
@@ -92,10 +94,11 @@ void StatePreplayingGame::initPlayers() {
   
   /* initreplay */
   m_universe->initReplay();
+  
 }
 
 void StatePreplayingGame::runPlaying() {
-  StateManager::instance()->replaceState(new StatePlaying(m_universe));
+  StateManager::instance()->replaceState(new StatePlayingLocal(m_universe, getId()), this->getId());
 }
 
 void StatePreplayingGame::nextLevel(bool i_positifOrder) {
