@@ -26,13 +26,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 class StateRequestKey : public StateMenu {
 public:
   StateRequestKey(const std::string& i_txt, 
-		  StateMenuContextReceiver* i_receiver = NULL,
 		  bool drawStateBehind    = true,
 		  bool updateStatesBehind = false);
   virtual ~StateRequestKey();
 
   virtual void enter();
-  virtual void keyDown(int nKey, SDLMod mod,int nChar);
+  virtual void xmKey(InputEventType i_type, const XMKey& i_xmkey);
 
   static void clean();
 
