@@ -35,9 +35,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../VideoRecorder.h"
 #include "../GameText.h"
 #include "../Game.h"
+#include "../Replay.h"
 #include "StateMainMenu.h"
 #include "../net/NetClient.h"
 #include "../net/NetActions.h"
+#include "../SysMessage.h"
+#include "states/StateVote.h"
 
 #define INPLAY_ANIMATION_TIME 1.0
 #define INPLAY_ANIMATION_SPEED 10
@@ -83,22 +86,26 @@ void StateScene::init() {
 
   // message registering
   initMessageRegistering();
+  
+  
 }
 
-StateScene::StateScene(bool i_doShade, bool i_doShadeAnim)
+StateScene::StateScene(const std::string& i_id, bool i_doShade, bool i_doShadeAnim)
 : GameState(false, false, i_doShade, i_doShadeAnim)
 {
+  setId(i_id);
   init();
 }
 
-StateScene::StateScene(Universe* i_universe, bool i_doShade, bool i_doShadeAnim)
+StateScene::StateScene(Universe* i_universe, const std::string& i_id, bool i_doShade, bool i_doShadeAnim)
   : GameState(false, false, i_doShade, i_doShadeAnim)
 {
+  setId(i_id);
   init();
   m_universe   = i_universe;
 
   if(m_universe != NULL) {
-    if(m_universe->getScenes().size() != 0) {
+    if(m_universe->getScenes().size() != 0) {    
       if(NetClient::instance()->isConnected()) {
 	NA_playingLevel na(m_universe->getScenes()[0]->getLevelSrc()->Id());
 	NetClient::instance()->send(&na, 0);
@@ -175,7 +182,8 @@ bool StateScene::update()
       while (( m_fLastPhysTime + (PHYS_STEP_SIZE)/100.0 <= GameApp::getXMTime()) && nPhysSteps < 10 && (XMSession::instance()->enableVideoRecording() == false || nPhysSteps == 0)) {
 	if(m_universe != NULL) {
 	  for(unsigned int i=0; i<m_universe->getScenes().size(); i++) {
-	    m_universe->getScenes()[i]->updateLevel(PHYS_STEP_SIZE, m_universe->getCurrentReplay());
+	    m_universe->getScenes()[i]->updateLevel(PHYS_STEP_SIZE,
+						    m_universe->getCurrentReplay(), m_universe->getCurrentReplay());
 	  }
 	}
 	m_fLastPhysTime += PHYS_STEP_SIZE/100.0;
@@ -197,7 +205,7 @@ bool StateScene::update()
       }
     }
   } catch(Exception &e) {
-    StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(e.getMsg(), 50), UI_MSGBOX_OK));  
+    StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(e.getMsg(), 50), UI_MSGBOX_OK), this->getId());
   }
 
   runAutoZoom();
@@ -212,7 +220,7 @@ bool StateScene::render()
   if (XMSession::instance()->ugly()) {
     pGame->getDrawLib()->clearGraphics();
   }
-
+  
   try {
     if(autoZoom() == false){
       if(m_universe != NULL) {
@@ -234,7 +242,7 @@ bool StateScene::render()
 
     ParticlesSource::setAllowParticleGeneration(GameRenderer::instance()->nbParticlesRendered() < NB_PARTICLES_TO_RENDER_LIMITATION);
   } catch(Exception &e) {
-    StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(e.getMsg(), 50), UI_MSGBOX_OK));
+    StateManager::instance()->replaceState(new StateMessageBox(NULL, splitText(e.getMsg(), 50), UI_MSGBOX_OK), this->getId());
   }
 
   GameState::render();
@@ -280,7 +288,7 @@ void StateScene::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
     }
   }
 
-  else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_RETURN, KMOD_NONE)) {
+  else if(i_type == INPUT_DOWN && i_xmkey == InputHandler::instance()->getRestartLevel()) {
     restartLevel();
   }
 
@@ -289,6 +297,20 @@ void StateScene::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
       m_universe->switchFollowCamera();
     }
   }
+  
+  else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_F4, KMOD_NONE)) {
+    if(m_universe != NULL) {
+      for(unsigned int j=0; j<m_universe->getScenes().size(); j++) {
+	for(unsigned int i=0; i<m_universe->getScenes()[j]->Cameras().size(); i++) {
+	  if(m_universe->getScenes()[j]->Cameras()[i]->getTrailAvailable()) {
+            m_universe->getScenes()[j]->Cameras()[i]->toggleTrackingShot(m_universe->getScenes()[j]);
+          } else {
+            SysMessage::instance()->displayText(SYS_MSG_TRAIL_NA);
+          }
+        }
+      }
+    }
+  }
 
   else if(i_type == INPUT_DOWN && i_xmkey == InputHandler::instance()->getSwitchFavorite()) {
     if(m_universe != NULL) {
@@ -315,7 +337,44 @@ void StateScene::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
   else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_PAGEDOWN, KMOD_NONE)) {
     nextLevel(false);
   }
+  
+  else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_t, KMOD_LCTRL)) {
+    if(m_universe != NULL) {
+      for(unsigned int j=0; j<m_universe->getScenes().size(); j++) {
+	for(unsigned int i=0; i<m_universe->getScenes()[j]->Cameras().size(); i++) {
+	  m_universe->getScenes()[j]->Cameras()[i]->toggleTrailCam();
+	  if(m_universe->getScenes()[j]->Cameras()[i]->getTrailAvailable() == false) {
+	    SysMessage::instance()->displayText(SYS_MSG_TRAILCAM_NA);
+	  }
+	  else if(XMSession::instance()->enableTrailCam()) {
+	    SysMessage::instance()->displayText(SYS_MSG_TRAILCAM_ACTIVATED);
+	  }
+	  else SysMessage::instance()->displayText(SYS_MSG_TRAILCAM_DEACTIVATED);
+        }
+      }
+    }
+  }
 
+  else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_g, KMOD_LCTRL)) {
+    if(m_universe != NULL) {
+      for(unsigned int j=0; j<m_universe->getScenes().size(); j++) {
+	for(unsigned int i=0; i<m_universe->getScenes()[j]->Cameras().size(); i++) {
+          if(m_universe->getScenes()[j]->getGhostTrail() != 0)
+            m_universe->getScenes()[j]->getGhostTrail()->toggleRenderGhostTrail();
+	  if(m_universe->getScenes()[j]->Cameras()[i]->getTrailAvailable() == false) {
+	    SysMessage::instance()->displayText(SYS_MSG_TRAIL_NA);
+	  }
+	  else if(m_universe->getScenes()[j]->getGhostTrail() != 0) {
+	    if(XMSession::instance()->renderGhostTrail()) 
+	        SysMessage::instance()->displayText(SYS_MSG_TRAIL_VISIBLE);
+	  
+	    else SysMessage::instance()->displayText(SYS_MSG_TRAIL_INVISIBLE);
+	  }
+        }
+      }
+    }
+  }
+  
 #if defined(ENABLE_DEV)
   else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_KP7, KMOD_NONE)) {
     /* Zoom in */
@@ -397,6 +456,17 @@ void StateScene::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
   }
 #endif
 
+  else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_v, KMOD_LCTRL)) {
+    if(XMSession::instance()->adminMode()) {
+      if(m_universe != NULL) {
+	if(m_universe->getScenes().size() == 1) {
+	  StateManager::instance()->pushState(new StateVote(StateManager::instance()->getUniqueId(),
+							    m_universe->getScenes()[0]->getLevelSrc()->Id()));
+	}
+      }
+    }
+  }
+
   else {
     GameState::xmKey(i_type, i_xmkey);
   }
@@ -427,7 +497,7 @@ void StateScene::setScoresTimes() {
   }
 
   /* get best result */
-  v_result = xmDatabase::instance("main")->readDB("SELECT MIN(finishTime) FROM profile_completedLevels WHERE "
+  v_result = xmDatabase::instance("main")->readDB("SELECT MIN(finishTime+0) FROM profile_completedLevels WHERE "
 						  "id_level=\"" + 
 						  xmDatabase::protectString(v_id_level) + "\";",
 						  nrow);
@@ -438,7 +508,7 @@ void StateScene::setScoresTimes() {
   xmDatabase::instance("main")->read_DB_free(v_result);
     
   /* get best player result */
-  v_result = xmDatabase::instance("main")->readDB("SELECT MIN(finishTime) FROM profile_completedLevels WHERE "
+  v_result = xmDatabase::instance("main")->readDB("SELECT MIN(finishTime+0) FROM profile_completedLevels WHERE "
 						  "id_level=\"" + 
 						  xmDatabase::protectString(v_id_level) + "\" " + 
 						  "AND id_profile=\"" + xmDatabase::protectString(XMSession::instance()->profile())  + "\";",
@@ -477,7 +547,7 @@ void StateScene::closePlaying() {
     NetClient::instance()->send(&na, 0);
   }
 
-  if(NetClient::instance()->isConnected()) {
+  if(NetClient::instance()->isPlayInitialized()) {
     NetClient::instance()->endPlay();
   }
 
@@ -551,7 +621,7 @@ void StateScene::executeOneCommand(std::string cmd, std::string args)
     // there is no other state before
     if(StateManager::instance()->numberOfStates() == 1) {
       // run the mainmenu state
-      StateManager::instance()->replaceState(new StateMainMenu());
+      StateManager::instance()->replaceState(new StateMainMenu(), this->getId());
     } else {
       m_requestForEnd = true;
     }
@@ -563,7 +633,7 @@ void StateScene::executeOneCommand(std::string cmd, std::string args)
     // there is no other state before
     if(StateManager::instance()->numberOfStates() == 1) {
       // run the mainmenu state
-      StateManager::instance()->replaceState(new StateMainMenu());
+      StateManager::instance()->replaceState(new StateMainMenu(), this->getId());
     } else {
       m_requestForEnd = true;
     }
@@ -587,7 +657,7 @@ void StateScene::executeOneCommand(std::string cmd, std::string args)
     // there is no other state before
     if(StateManager::instance()->numberOfStates() == 1) {
       // run the mainmenu state
-      StateManager::instance()->replaceState(new StateMainMenu());
+      StateManager::instance()->replaceState(new StateMainMenu(), this->getId());
     } else {
       m_requestForEnd = true;
     }
@@ -620,7 +690,7 @@ void StateScene::executeOneCommand(std::string cmd, std::string args)
 
 void StateScene::displayStats() {
   FontManager* v_fm = GameApp::instance()->getDrawLib()->getFontSmall();
-  FontGlyph* v_fg   = GameApp::instance()->getDrawLib()->getFontSmall()->getGlyph(m_statsStr);
+  FontGlyph* v_fg   = v_fm->getGlyph(m_statsStr);
   Vector2f A = Vector2f(GameApp::instance()->getDrawLib()->getDispWidth() - v_fg->realWidth(),
 			GameApp::instance()->getDrawLib()->getDispHeight() - v_fg->realHeight());
   Vector2f B= Vector2f(GameApp::instance()->getDrawLib()->getDispWidth(),
@@ -841,7 +911,8 @@ void StateScene::restartLevelToPlay(bool i_reloadLevel) {
     }
   }
 
-  StateManager::instance()->replaceState(new StatePreplayingGame(v_level, true));
+  StateManager::instance()->replaceState(new StatePreplayingGame(getId(), v_level, true),
+					 this->getId());
 
 }
 
@@ -865,7 +936,8 @@ void StateScene::nextLevelToPlay(bool i_positifOrder) {
 
   if(v_nextLevel != "") {
     closePlaying();
-    StateManager::instance()->replaceState(new StatePreplayingGame(v_nextLevel, v_currentLevel == v_nextLevel));
+    StateManager::instance()->replaceState(new StatePreplayingGame(getId(), v_nextLevel, v_currentLevel == v_nextLevel),
+					   this->getId());
   }
 }
 
