@@ -28,8 +28,8 @@ class Universe;
 
 class StateScene : public GameState {
 public:
- StateScene(bool i_doShade = false, bool i_doShadeAnim = false);
- StateScene(Universe* i_universe, bool i_doShade = false, bool i_doShadeAnim = false); // for state which doesn't create the universe
+  StateScene(const std::string& i_id, bool i_doShade = false, bool i_doShadeAnim = false);
+ StateScene(Universe* i_universe, const std::string& i_id, bool i_doShade = false, bool i_doShadeAnim = false); // for state which doesn't create the universe
  virtual ~StateScene();
  
  virtual void enter();
