@@ -18,9 +18,9 @@ along with XMOTO; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
-#include "Game.h"
+#include "../Game.h"
 #include "StateUpdateDb.h"
-#include "thread/UpdateDbThread.h"
+#include "../thread/UpdateDbThread.h"
 
 StateUpdateDb::StateUpdateDb(bool drawStateBehind,
 			     bool updateStatesBehind)
