@@ -96,6 +96,7 @@ int CheckWwwThread::realThreadFunction()
   std::string webRoomUrl;
   std::string webRoomName;
   std::string webLevelsUrl;
+  std::string v_stolen_msg;
   ProxySettings* pProxySettings;
 
   if(XMSession::instance()->www() == true){
@@ -120,6 +121,12 @@ int CheckWwwThread::realThreadFunction()
 	  setThreadProgress((100 * (i+1)) / XMSession::instance()->nbRoomsEnabled());
 	}
       }
+      m_pDb->updateMyHighscoresFromHighscores(XMSession::instance()->profile());
+
+      if(m_pDb->markMyHighscoresKnownStolen(XMSession::instance()->profile(), v_stolen_msg)) {
+	StateManager::instance()->sendAsynchronousMessage("MYHIGHSCORES_STOLEN", v_stolen_msg);
+      }
+
       if(m_realHighscoresUpdate) {
 	StateManager::instance()->sendAsynchronousMessage("HIGHSCORES_UPDATED");
       }
