@@ -22,15 +22,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __DOWNLOADGHOSTTHREAD_H__
 
 #include "XMThread.h"
-#include "WWWAppInterface.h"
+#include "../WWWAppInterface.h"
 
 class GameState;
 class WebRoom;
 
 class DownloadGhostThread : public XMThread, public WWWAppInterface {
 public:
-  DownloadGhostThread(GameState* pCallingState,
-		      std::string levelId,
+  DownloadGhostThread(std::string levelId,
 		      bool i_onlyMainRoomGhost);
   virtual ~DownloadGhostThread();
 
@@ -42,7 +41,6 @@ public:
 private:
 
   WebRoom*    m_pWebRoom;
-  GameState*  m_pCallingState;
   std::string m_msg;
   std::string m_levelId;
   bool m_onlyMainRoomGhost;
