@@ -22,8 +22,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __UPDATEDBTHREAD_H__
 
 #include "XMThread.h"
-#include "XMotoLoadLevelsInterface.h"
-#include "XMotoLoadReplaysInterface.h"
+#include "../XMotoLoadLevelsInterface.h"
+#include "../XMotoLoadReplaysInterface.h"
 
 class UpdateDbThread : public XMThread ,
 		       public XMotoLoadLevelsInterface,
