@@ -26,12 +26,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../states/StateUpgradeLevels.h"
 #include "../helpers/CmdArgumentParser.h"
 
-UpgradeLevelsThread::UpgradeLevelsThread(GameState* pCallingState, const std::string& i_id_theme)
+UpgradeLevelsThread::UpgradeLevelsThread(const std::string& i_id_theme, bool i_updateAutomaticallyLevels)
   : XMThread("ULT")
 {
   m_pWebLevels    = new WebLevels(this);
-  m_pCallingState = pCallingState;
-  m_updateAutomaticallyLevels = false;
+  m_updateAutomaticallyLevels = i_updateAutomaticallyLevels;
   m_msg = "";
   m_id_theme = i_id_theme;
 }
@@ -43,7 +42,6 @@ UpgradeLevelsThread::~UpgradeLevelsThread()
 
 void UpgradeLevelsThread::setBeingDownloadedInformation(const std::string &p_information, bool p_isNew)
 {
-  LogInfo(("setBeingDownloadedInformation" + p_information).c_str());
   setThreadCurrentMicroOperation(p_information);
 }
 
@@ -97,6 +95,7 @@ bool UpgradeLevelsThread::shouldLevelBeUpdated(const std::string &LevelID)
 int UpgradeLevelsThread::realThreadFunction()
 {
   int v_exit_code = 0;
+  bool v_shouldBeLoadedInBase = false;
 
   /* Check for extra levels */
   try {
@@ -124,7 +123,7 @@ int UpgradeLevelsThread::realThreadFunction()
 
     if(nULevels == 0) {
       m_msg = GAMETEXT_NONEWLEVELS;
-      return 1;
+      return 2 /* 2 for no new levels to update */;
     }
     else {
       StateManager::instance()->sendAsynchronousMessage("NEW_LEVELS_TO_DOWNLOAD");
@@ -139,8 +138,10 @@ int UpgradeLevelsThread::realThreadFunction()
 
   setThreadProgress(100);
 
-  // sleep while we don't have the user response
-  sleepThread();
+  if(m_updateAutomaticallyLevels == false) {
+    // sleep while we don't have the user response
+    sleepThread();
+  }
 
   if(m_askThreadToEnd == true){
     return 0;
@@ -169,6 +170,7 @@ int UpgradeLevelsThread::realThreadFunction()
     StateManager::instance()->sendAsynchronousMessage("THEMES_UPDATED");
 
     // don't safe kill here
+    v_shouldBeLoadedInBase = true;
     m_pWebLevels->upgrade(m_pDb);
   }
   catch(Exception& e) {
@@ -178,7 +180,7 @@ int UpgradeLevelsThread::realThreadFunction()
     v_exit_code = 1;
   }
 
-  if(v_exit_code == 0) {
+  if(v_exit_code == 0 || v_shouldBeLoadedInBase) {
     /* Got some new levels... load them! */
     LogInfo("Loading new and updated levels...");
 
