@@ -1,4 +1,4 @@
-/*=============================================================================
+/*===========================================================================
 XMOTO
 
 This file is part of XMOTO.
@@ -29,12 +29,18 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../chipmunk/chipmunk.h"
 #include "ChipmunkWorld.h"
 #include "PhysicsSettings.h"
+#include "../Theme.h"
+#include "../GameEvents.h"
 
 #define XM_DEFAULT_BLOCK_TEXTURE "default"
 #define XM_DEFAULT_PHYS_BLOCK_MASS 30.0
 #define XM_DEFAULT_PHYS_BLOCK_FRICTION 0.5
 #define XM_DEFAULT_PHYS_BLOCK_ELASTICITY 0.0
 
+#define PHYS_MOVE_POSITION_MINIMUM 0.3
+#define PHYS_MOVE_ROTATION_MINIMUM 0.1
+
+
 /* Vertex */
 ConvexBlockVertex::ConvexBlockVertex(const Vector2f& i_position, const Vector2f& i_texturePosition) {
   m_position         = i_position;
@@ -101,6 +107,14 @@ Block::Block(std::string i_id) {
   m_collisionElement = NULL;
   m_collisionMethod  = None;
   m_collisionRadius  = 0.0f;
+  m_blendColor.setRed(255);
+  m_blendColor.setGreen(255);
+  m_blendColor.setBlue(255);
+  m_blendColor.setAlpha(255);
+  m_edgeDefaultColor = DEFAULT_EDGE_BLENDCOLOR; // assign it or get random colors if no edge material is added
+
+  m_previousSavedPosition = DynamicPosition();
+  m_previousSavedRotation = DynamicRotation();
 }
 
 Block::~Block() {
@@ -123,6 +137,10 @@ Block::~Block() {
   m_collisionLines.clear();
 
   m_edgeGeoms.clear();
+  
+ // for(unsigned int i=0; i<edgeGeomBlendColor.size(); i++) delete edgeGeomBlendColor[i];
+  m_edgeMaterial.clear();
+  
 }
 
 void Block::setCenter(const Vector2f& i_center) {
@@ -259,29 +277,64 @@ void Block::translate(float x, float y)
   translateCollisionLines(x, y);
 }
 
-void Block::updatePhysics(int timeStep, CollisionSystem* io_collisionSystem) {
-  if(isPhysics()) {
-    // move block according to chipmunk, only if they have moved
-    bool moved = false;
+void Block::updatePhysics(int i_time, int timeStep, CollisionSystem* io_collisionSystem, DBuffer* i_recorder) {
+  Vector2f v_diffPosition;
 
-    Vector2f newPos = Vector2f(((mBody->p.x ) / CHIP_SCALE_RATIO) , (mBody->p.y ) / CHIP_SCALE_RATIO);
-    if(DynamicPosition() != newPos) {
-      setDynamicPosition(newPos);
-      moved = true;
-    }
+  if(isPhysics() == false) {
+    return;
+  }
 
-    if(DynamicRotation() != mBody->a) {
-      setDynamicRotation(mBody->a);
-      moved = true;
-    }
+  // move block according to chipmunk, only if they have moved
+  bool moved = false;
 
-    if(moved == true){
-      // inform collision system that there has been a change
-      io_collisionSystem->moveDynBlock(this);
+  Vector2f newPos = Vector2f(((mBody->p.x ) / CHIP_SCALE_RATIO) , (mBody->p.y ) / CHIP_SCALE_RATIO);
+  if(DynamicPosition() != newPos) {
+    setDynamicPosition(newPos);
+    moved = true;
+  }
+  
+  if(DynamicRotation() != mBody->a) {
+    setDynamicRotation(mBody->a);
+    moved = true;
+  }
+  
+  if(moved == true){
+    // inform collision system that there has been a change
+    io_collisionSystem->moveDynBlock(this);
+  }
+  
+  cpBodyResetForces(mBody);
+
+  /* record */
+  /* don't save any physic event for the moment
+  float v_diffRotation;
+
+  if(i_recorder != NULL) {
+    v_diffPosition = m_previousSavedPosition-DynamicPosition();
+    v_diffRotation = m_previousSavedRotation-DynamicRotation();
+    
+    // save position only if the block moved
+    if(v_diffPosition.length() > PHYS_MOVE_POSITION_MINIMUM) {
+      SceneEvent *pEvent = new MGE_SetBlockPos(i_time,
+					       Id(),
+					       DynamicPosition().x,
+					       DynamicPosition().y);
+      pEvent->serialize(*i_recorder);
+      delete pEvent;
+      m_previousSavedPosition = DynamicPosition();
     }
     
-    cpBodyResetForces(mBody);
+    // save rotation only if the block moved
+    if(fabs(v_diffRotation) > PHYS_MOVE_ROTATION_MINIMUM) {
+      SceneEvent *pEvent = new MGE_SetBlockRotation(i_time,
+						    Id(),
+						    DynamicRotation());
+      pEvent->serialize(*i_recorder);
+      delete pEvent;
+      m_previousSavedRotation = DynamicRotation();
+    }
   }
+  */
 }
 
 int Block::loadToPlay(CollisionSystem* io_collisionSystem, ChipmunkWorld* i_chipmunkWorld, PhysicsSettings* i_physicsSettings) {
@@ -340,7 +393,7 @@ int Block::loadToPlay(CollisionSystem* io_collisionSystem, ChipmunkWorld* i_chip
     }
 
     /* add dynamic lines */
-    if(isLayer() == false && isDynamic()) {
+    if(isDynamic() && m_layer == -1) {
       /* Define collision lines */
       Line *v_line = new Line;
       v_line->x1 = v_line->y1 = v_line->x2 = v_line->y2 = 0.0f;
@@ -383,7 +436,7 @@ int Block::loadToPlay(CollisionSystem* io_collisionSystem, ChipmunkWorld* i_chip
   }
 
   /* define dynamic block in the collision system */
-  if(isLayer() == false && isDynamic()) {
+  if(isDynamic() && m_layer == -1) {
     updateCollisionLines(true, true);
     m_collisionElement = io_collisionSystem->addDynBlock(this);
   }
@@ -482,13 +535,30 @@ int Block::loadToPlay(CollisionSystem* io_collisionSystem, ChipmunkWorld* i_chip
 }
 
 void Block::addPoly(BSPPoly* i_poly, CollisionSystem* io_collisionSystem) {
-  ConvexBlock *v_block = new ConvexBlock(this);
-  float scale = TextureScale();
+  ConvexBlock* v_block = new ConvexBlock(this);
+  float scale = TextureScale() * 0.25;
+  Sprite* pSprite = Theme::instance()->getSprite(SPRITE_TYPE_TEXTURE,
+						 this->getTexture());
+  
+  if(pSprite != NULL) 
+  {
+    try{
+      Texture* v_texture = pSprite->getTexture();
+      if(v_texture != NULL) {
+	int v_textureSize = v_texture->nWidth;
+	if(v_textureSize < 256 && v_textureSize != 0)
+	  // divide by texturesize to prevent upscaling of textures < 256x256
+	  scale *= (256/v_textureSize);
+      }
+    } catch(Exception& e) {
+      ;
+    }
+  }
 
-  for(unsigned int i=0; i<i_poly->Vertices().size(); i++) {
+  for(unsigned int i=0; i<i_poly->Vertices().size(); i++) {	
     v_block->addVertex(i_poly->Vertices()[i],
-		       Vector2f((InitialPosition().x + i_poly->Vertices()[i].x) * 0.25 * scale,
-                                (InitialPosition().y + i_poly->Vertices()[i].y) * 0.25 * scale));
+		       Vector2f((InitialPosition().x + i_poly->Vertices()[i].x) * scale,
+                                (InitialPosition().y + i_poly->Vertices()[i].y) * scale));
   }
   m_convexBlocks.push_back(v_block);
 }
@@ -503,6 +573,7 @@ void Block::unloadToPlay() {
     delete m_collisionLines[i];
   }
   m_collisionLines.clear();
+  
 }
 
 bool Block::isPhysics() const {
@@ -647,6 +718,7 @@ void BlockVertex::setColor(const TColor &i_color) {
   m_color = i_color;
 }
 
+
 bool Block::isPhysics_readFromXml(XMLDocument* i_xmlSource, TiXmlElement *pElem) {
   TiXmlElement* pPositionElem   = XML::findElement(*i_xmlSource, pElem, std::string("position"));
 
@@ -673,6 +745,20 @@ Block* Block::readFromXml(XMLDocument* i_xmlSource, TiXmlElement *pElem) {
   if(pUseTextureElem != NULL) {
     pBlock->setTexture(XML::getOption(pUseTextureElem,"id", "default"));
     pBlock->setTextureScale(atof(XML::getOption(pUseTextureElem,"scale","1").c_str()));
+    
+    
+    /* Color blending for blocks */
+    int blendColor_r = 255, blendColor_g = 255, blendColor_b = 255, blendColor_a = 255;
+    std::string v_blendColor = XML::getOption(pUseTextureElem,"color_r");
+    if(v_blendColor != "") blendColor_r = atoi(v_blendColor.c_str());
+    v_blendColor = XML::getOption(pUseTextureElem,"color_g");
+    if(v_blendColor != "") blendColor_g = atoi(v_blendColor.c_str());
+    v_blendColor = XML::getOption(pUseTextureElem,"color_b");
+    if(v_blendColor != "") blendColor_b = atoi(v_blendColor.c_str());
+    v_blendColor = XML::getOption(pUseTextureElem,"color_a");
+    if(v_blendColor != "") blendColor_a = atoi(v_blendColor.c_str());
+    pBlock->setBlendColor(TColor(blendColor_r,blendColor_g,blendColor_b,blendColor_a));
+    
   }
 
   if(pPositionElem != NULL) {
@@ -687,7 +773,7 @@ Block* Block::readFromXml(XMLDocument* i_xmlSource, TiXmlElement *pElem) {
     pBlock->setPhysics(XML::getOption(pPositionElem,"physics","false") == "true");
     pBlock->setIsLayer(XML::getOption(pPositionElem,"islayer","false") == "true");
     pBlock->setLayer(atoi(XML::getOption(pPositionElem,"layerid","-1").c_str()));
- }
+  }
 
   if(pPhysicsElem != NULL) {
     char str[16];
@@ -722,6 +808,24 @@ Block* Block::readFromXml(XMLDocument* i_xmlSource, TiXmlElement *pElem) {
     pBlock->setEdgeDrawMethod(pBlock->stringToEdge(methodStr));
     // 270 is the default one for the 'angle' edge draw method, not used for the others
     pBlock->setEdgeAngle(atof(XML::getOption(pEdgeElem, "angle", "270.0").c_str()));
+    
+    //check for geoms assignments: blendColor, depth and scale
+    for(TiXmlElement *pedge = pEdgeElem->FirstChildElement(); pedge!=NULL; pedge=pedge->NextSiblingElement()) {
+      if( !strcmp(pedge->Value(), "material") ) {  //strcmp returns 0 in case of match, thats why the NOT means actually TRUE here
+        std::string v_materialName = XML::getOption(pedge, "name", "not_used").c_str();
+        std::string v_materialTexture = XML::getOption(pedge, "edge", "").c_str();
+        int blendColor_r, blendColor_g, blendColor_b, blendColor_a;
+        std::string v_blendColor = XML::getOption(pedge, "color_r", "255"); blendColor_r = atoi(v_blendColor.c_str());
+        v_blendColor = XML::getOption(pedge, "color_g", "255"); blendColor_g = atoi(v_blendColor.c_str());
+        v_blendColor = XML::getOption(pedge, "color_b", "255"); blendColor_b = atoi(v_blendColor.c_str());
+        v_blendColor = XML::getOption(pedge, "color_a", "255"); blendColor_a = atoi(v_blendColor.c_str());
+        
+        float v_scale = atof(XML::getOption(pedge, "scale", "-1.0f").c_str()); //set scale default alias -1
+        float v_depth = atof(XML::getOption(pedge, "depth", "-1.0f").c_str()); //det depth default alias -1
+        pBlock->addEdgeMaterial(v_materialName, v_materialTexture, TColor(blendColor_r, blendColor_g, blendColor_b, blendColor_a), v_scale, v_depth);
+      }
+    }
+    
   } else {
     pBlock->setEdgeDrawMethod(angle);
     pBlock->setEdgeAngle(DEFAULT_EDGE_ANGLE);
@@ -736,6 +840,7 @@ Block* Block::readFromXml(XMLDocument* i_xmlSource, TiXmlElement *pElem) {
   float lastX = 0.0;
   float lastY = 0.0;
   bool  firstVertex = true;
+  
   /* Get vertices */
   for(TiXmlElement *pj = pElem->FirstChildElement(); pj!=NULL; pj=pj->NextSiblingElement()) {
     if(!strcmp(pj->Value(),"vertex")) {
@@ -772,8 +877,14 @@ void Block::saveBinary(FileHandle *i_pfh) {
       FS::writeBool(i_pfh,     isPhysics());
       FS::writeBool(i_pfh,     isLayer());
       FS::writeInt_LE(i_pfh,   getLayer());
-      FS::writeString(i_pfh,   Texture());
+      FS::writeString(i_pfh,   getTexture());
       FS::writeFloat_LE(i_pfh, TextureScale());
+      
+      FS::writeInt_LE(i_pfh, m_blendColor.Red());
+      FS::writeInt_LE(i_pfh, m_blendColor.Green());
+      FS::writeInt_LE(i_pfh, m_blendColor.Blue());
+      FS::writeInt_LE(i_pfh, m_blendColor.Alpha());
+      
       FS::writeFloat_LE(i_pfh, InitialPosition().x);
       FS::writeFloat_LE(i_pfh, InitialPosition().y);
       FS::writeFloat_LE(i_pfh, GripPer20());
@@ -782,6 +893,19 @@ void Block::saveBinary(FileHandle *i_pfh) {
       FS::writeFloat_LE(i_pfh, Elasticity());
       FS::writeInt_LE(i_pfh,   getEdgeDrawMethod());
       FS::writeFloat_LE(i_pfh, edgeAngle());
+      
+      FS::writeInt_LE(i_pfh, m_edgeMaterial.size());
+      for(unsigned int i=0; i<m_edgeMaterial.size(); i++) {
+        FS::writeString(i_pfh, m_edgeMaterial[i].name);
+        FS::writeString(i_pfh, m_edgeMaterial[i].texture);
+        FS::writeInt_LE(i_pfh, m_edgeMaterial[i].color.Red());
+        FS::writeInt_LE(i_pfh, m_edgeMaterial[i].color.Green());
+        FS::writeInt_LE(i_pfh, m_edgeMaterial[i].color.Blue());
+        FS::writeInt_LE(i_pfh, m_edgeMaterial[i].color.Alpha());
+        FS::writeFloat_LE(i_pfh, m_edgeMaterial[i].scale);
+        FS::writeFloat_LE(i_pfh, m_edgeMaterial[i].depth);
+      }
+      
       FS::writeInt_LE(i_pfh,   getCollisionMethod());
       FS::writeFloat_LE(i_pfh, getCollisionRadius());
 
@@ -805,6 +929,13 @@ Block* Block::readFromBinary(FileHandle *i_pfh) {
   pBlock->setTexture(FS::readString(i_pfh));
   pBlock->setTextureScale(FS::readFloat_LE(i_pfh));
 
+  TColor v_blendColor = TColor(255,255,255,255);
+  v_blendColor.setRed(FS::readInt_LE(i_pfh));
+  v_blendColor.setGreen(FS::readInt_LE(i_pfh));
+  v_blendColor.setBlue(FS::readInt_LE(i_pfh));
+  v_blendColor.setAlpha(FS::readInt_LE(i_pfh));
+  pBlock->setBlendColor(v_blendColor);
+
   Vector2f v_Position;
   v_Position.x = FS::readFloat_LE(i_pfh);
   v_Position.y = FS::readFloat_LE(i_pfh);
@@ -815,6 +946,24 @@ Block* Block::readFromBinary(FileHandle *i_pfh) {
   pBlock->setElasticity(FS::readFloat_LE(i_pfh));
   pBlock->setEdgeDrawMethod((EdgeDrawMethod)FS::readInt_LE(i_pfh));
   pBlock->setEdgeAngle(FS::readFloat_LE(i_pfh));
+  
+  int geomSize = FS::readInt_LE(i_pfh);  //get size of geoms and read out as many times
+  for( int i=0; i<geomSize; i++) {
+    EdgeMaterial v_geomMat;
+    v_geomMat.name = FS::readString(i_pfh);
+    v_geomMat.texture = FS::readString(i_pfh);
+    TColor v_edgeMatColor = TColor(255,255,255,255);
+    v_edgeMatColor.setRed(FS::readInt_LE(i_pfh));
+    v_edgeMatColor.setGreen(FS::readInt_LE(i_pfh));
+    v_edgeMatColor.setBlue(FS::readInt_LE(i_pfh));
+    v_edgeMatColor.setAlpha(FS::readInt_LE(i_pfh));
+    v_geomMat.color = v_edgeMatColor;
+    v_geomMat.scale = FS::readFloat_LE(i_pfh);
+    v_geomMat.depth = FS::readFloat_LE(i_pfh);
+    pBlock->m_edgeMaterial.push_back(v_geomMat);
+  }
+      
+  
   pBlock->setCollisionMethod((CollisionMethod)FS::readInt_LE(i_pfh));
   pBlock->setCollisionRadius(FS::readFloat_LE(i_pfh));
   
@@ -831,9 +980,9 @@ Block* Block::readFromBinary(FileHandle *i_pfh) {
   return pBlock;
 }
 
-void Block::addEdgeGeom(int geom)
+void Block::addEdgeGeom(int geomIndex)
 {
-  m_edgeGeoms.push_back(geom);
+  m_edgeGeoms.push_back(geomIndex);
 }
 
 std::vector<int>& Block::getEdgeGeoms()
@@ -1030,3 +1179,65 @@ Block::CollisionMethod Block::stringToColMethod(std::string method)
   else
     return None;
 }
+
+void Block::setBlendColor(const TColor& i_blendColor)
+{
+  m_blendColor = i_blendColor;
+}
+
+const TColor& Block::getBlendColor() const
+{
+  return m_blendColor;
+}
+
+void Block::addEdgeMaterial( std::string i_name, std::string i_texture, const TColor& i_blendColor, float i_scale, float i_depth )
+{
+  if((i_texture != "" ) && (i_name != "not_used")) {
+    EdgeMaterial geomMat;
+    geomMat.name = i_name;
+    geomMat.color = i_blendColor;
+    geomMat.texture = i_texture;
+    geomMat.scale = i_scale;
+    geomMat.depth = i_depth;
+    m_edgeMaterial.push_back(geomMat);
+  };
+}
+
+std::string Block::getEdgeMaterialTexture(std::string i_materialName) {
+  for(unsigned int i=0; i<m_edgeMaterial.size(); i++) {
+     if(m_edgeMaterial[i].name == i_materialName) {
+       return m_edgeMaterial[i].texture;
+     }
+   }
+   return std::string("");
+}
+
+TColor& Block::getEdgeMaterialColor(std::string i_materialName) 
+{   
+   for(unsigned int i=0; i<m_edgeMaterial.size(); i++) {
+     if(m_edgeMaterial[i].name == i_materialName) {
+       return m_edgeMaterial[i].color;
+     }
+   }
+   return m_edgeDefaultColor;
+}
+
+float Block::getEdgeMaterialDepth(std::string i_materialName)
+{
+  for(unsigned int i=0; i<m_edgeMaterial.size(); i++) {
+     if(m_edgeMaterial[i].name == i_materialName) {
+       return m_edgeMaterial[i].depth;
+     }
+   }
+   return DEFAULT_EDGE_DEPTH;
+}
+
+float Block::getEdgeMaterialScale(std::string i_materialName)
+{
+  for(unsigned int i=0; i<m_edgeMaterial.size(); i++) {
+     if(m_edgeMaterial[i].name == i_materialName) {
+       return m_edgeMaterial[i].scale;
+     }
+   }
+   return DEFAULT_EDGE_SCALE;
+}
