@@ -42,8 +42,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "PhysicsSettings.h"
 #include "../Theme.h"
 
-#define CACHE_LEVEL_FORMAT_VERSION 25
-
 Level::Level() {
   m_xmotoTooOld = false;
   m_leftLimit   = 0.0;
@@ -163,7 +161,8 @@ bool Level::isPhysics() const {
   return m_isPhysics;
 }
 
-void Level::updatePhysics(int timeStep, CollisionSystem* p_CollisionSystem, ChipmunkWorld* i_chipmunkWorld) {
+void Level::updatePhysics(int i_time, int timeStep, CollisionSystem* p_CollisionSystem, ChipmunkWorld* i_chipmunkWorld, DBuffer* i_recorder) {
+
   if(i_chipmunkWorld == NULL) {
     return;
   }
@@ -172,7 +171,7 @@ void Level::updatePhysics(int timeStep, CollisionSystem* p_CollisionSystem, Chip
 
   // loop through all blocks, looking for chipmunky ones
   for(unsigned int i=0; i<m_blocks.size(); i++) {
-    m_blocks[i]->updatePhysics(timeStep, p_CollisionSystem);
+    m_blocks[i]->updatePhysics(i_time, timeStep, p_CollisionSystem, i_recorder);
   }
 }
 
@@ -419,7 +418,11 @@ void Level::loadXML() {
       
       /* Sky */
       Tmp = XML::getElementText(*m_xmlSource, pInfoElem,"sky");
-      if(Tmp != "") m_sky->setTexture(Tmp);
+      if(Tmp != "") {
+        m_sky->setTexture(Tmp);
+        m_sky->setBlendTexture(Tmp);
+      }
+      
 
       /* advanced sky parameters ? */
       bool v_useAdvancedOptions = false;
@@ -480,6 +483,14 @@ void Level::loadXML() {
 	    m_sky->setDriftTextureColor(TColor(v_r, v_g, v_b, v_a)); 
 	  }
 	}
+	
+	/* Sky Blend texture */
+        v_skyValue = XML::getOption(pSkyElem, "BlendTexture");
+	if(v_skyValue != "") {
+	  m_sky->setBlendTexture(v_skyValue.c_str());
+	  v_useAdvancedOptions = true;
+	}
+	
       }
       if(v_useAdvancedOptions == false) {
 	/* set old values in case no option is used */
@@ -722,7 +733,9 @@ void Level::exportBinary(const std::string &FileName, const std::string& pSum) {
     FS::writeInt_LE(pfh,   m_sky->DriftTextureColor().Green());
     FS::writeInt_LE(pfh,   m_sky->DriftTextureColor().Blue());
     FS::writeInt_LE(pfh,   m_sky->DriftTextureColor().Alpha());
-
+    
+    FS::writeString(pfh,   m_sky->BlendTexture());
+    
     FS::writeString(pfh,m_borderTexture);
     FS::writeString(pfh,m_scriptFileName);
 
@@ -936,7 +949,7 @@ bool Level::importBinary(const std::string &FileName, const std::string& pSum) {
         m_sky->setTexture(FS::readString(pfh));
 	m_sky->setZoom(FS::readFloat_LE(pfh));
 	m_sky->setOffset(FS::readFloat_LE(pfh));
-
+        
 	int v_r, v_g, v_b, v_a;
 	v_r = FS::readInt_LE(pfh);
 	v_g = FS::readInt_LE(pfh);
@@ -953,7 +966,7 @@ bool Level::importBinary(const std::string &FileName, const std::string& pSum) {
 	v_a = FS::readInt_LE(pfh);
 	m_sky->setDriftTextureColor(TColor(v_r, v_g, v_b, v_a));
 	/* *** */
-
+        m_sky->setBlendTexture(FS::readString(pfh));
         m_borderTexture = FS::readString(pfh);
 
         m_scriptFileName = FS::readString(pfh);
@@ -1343,3 +1356,128 @@ void Level::loadRemplacementSprites()
   m_flowerSprite     = Theme::instance()->getSprite(SPRITE_TYPE_ANIMATION, SpriteForFlower());
   m_starSprite       = Theme::instance()->getSprite(SPRITE_TYPE_ANIMATION, SpriteForStar());
 }
+
+float Level::averagePhysicBlocksSize() const {
+  int v_nb;
+  float v_total;
+  float xmin = 0.0, 
+        xmax = 0.0, 
+        ymin = 0.0, 
+        ymax = 0.0;
+
+  if(m_isPhysics == false) {
+    return 0;
+  }  
+
+  v_nb    = 0;
+  v_total = 0.0;
+
+  for(unsigned int i=0; i<m_blocks.size(); i++) {
+    if(m_blocks[i]->isPhysics()) {
+      v_nb ++;
+
+      for(unsigned int j=0; j<m_blocks[i]->Vertices().size(); j++) {
+	if(j == 0) {
+	  xmin = m_blocks[i]->Vertices()[j]->Position().x;
+	  xmax = m_blocks[i]->Vertices()[j]->Position().x;
+	  ymin = m_blocks[i]->Vertices()[j]->Position().y;
+	  ymax = m_blocks[i]->Vertices()[j]->Position().y;
+	} else {
+	  if(xmin > m_blocks[i]->Vertices()[j]->Position().x) {
+	    xmin = m_blocks[i]->Vertices()[j]->Position().x;
+	  }
+	  if(xmax < m_blocks[i]->Vertices()[j]->Position().x) {
+	    xmax = m_blocks[i]->Vertices()[j]->Position().x;
+	  }
+	  if(ymin > m_blocks[i]->Vertices()[j]->Position().y) {
+	    ymin = m_blocks[i]->Vertices()[j]->Position().y;
+	  }
+	  if(ymax < m_blocks[i]->Vertices()[j]->Position().y) {
+	    ymax = m_blocks[i]->Vertices()[j]->Position().y;
+	  }
+	}
+      }
+
+      if(xmax - xmin > ymax - ymin) {
+	v_total += xmax - xmin;
+      } else {
+	v_total += ymax - ymin;
+      }
+    }
+  }
+
+  if(v_nb == 0) {
+    return 0;
+  }
+
+  return v_total/v_nb;
+}
+
+float Level::maxPhysicBlocksSize() const {
+  float v_max;
+  float xmin = 0.0,
+        xmax = 0.0,
+        ymin = 0.0, 
+        ymax = 0.0;
+
+  if(m_isPhysics == false) {
+    return 0;
+  }  
+
+  v_max = 0.0;
+
+  for(unsigned int i=0; i<m_blocks.size(); i++) {
+    if(m_blocks[i]->isPhysics()) {
+      for(unsigned int j=0; j<m_blocks[i]->Vertices().size(); j++) {
+	if(j == 0) {
+	  xmin = m_blocks[i]->Vertices()[j]->Position().x;
+	  xmax = m_blocks[i]->Vertices()[j]->Position().x;
+	  ymin = m_blocks[i]->Vertices()[j]->Position().y;
+	  ymax = m_blocks[i]->Vertices()[j]->Position().y;
+	} else {
+	  if(xmin > m_blocks[i]->Vertices()[j]->Position().x) {
+	    xmin = m_blocks[i]->Vertices()[j]->Position().x;
+	  }
+	  if(xmax < m_blocks[i]->Vertices()[j]->Position().x) {
+	    xmax = m_blocks[i]->Vertices()[j]->Position().x;
+	  }
+	  if(ymin > m_blocks[i]->Vertices()[j]->Position().y) {
+	    ymin = m_blocks[i]->Vertices()[j]->Position().y;
+	  }
+	  if(ymax < m_blocks[i]->Vertices()[j]->Position().y) {
+	    ymax = m_blocks[i]->Vertices()[j]->Position().y;
+	  }
+	}
+      }
+
+      if(xmax - xmin > ymax - ymin) {
+	if(v_max < xmax - xmin) {
+	  v_max += xmax - xmin;
+	}
+      } else {
+	if(v_max < ymax - ymin) {
+	  v_max += ymax - ymin;
+	}
+      }
+    }
+  }
+
+  return v_max;
+}
+
+int Level::nbPhysicBlocks() const {
+  int v_nb;
+
+  if(m_isPhysics == false) {
+    return 0;
+  }  
+
+  v_nb = 0;
+  for(unsigned int i=0; i<m_blocks.size(); i++) {
+    if(m_blocks[i]->isPhysics()) {
+      v_nb++;
+    }
+  }
+
+  return v_nb;
+}
