@@ -21,6 +21,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __LEVELSRC_H__
 #define __LEVELSRC_H__
 
+#define CACHE_LEVEL_FORMAT_VERSION 30
+
 #include <string>
 #include <vector>
 #include "BasicSceneStructs.h"
@@ -39,6 +41,7 @@ class XMLDocument;
 class ChipmunkWorld;
 class Sprite;
 class PhysicsSettings;
+class DBuffer;
 
 /*===========================================================================
   Level source object - holds all stored information about a level
@@ -97,7 +100,10 @@ class Level {
   bool isScripted() const;
   bool isPhysics() const;
 
-  void updatePhysics(int timeStep, CollisionSystem* p_CollisionSystem, ChipmunkWorld* i_chipmunkWorld);
+  void updatePhysics(int i_time, int timeStep, CollisionSystem* p_CollisionSystem, ChipmunkWorld* i_chipmunkWorld, DBuffer* i_recorder);
+  float averagePhysicBlocksSize() const;
+  float maxPhysicBlocksSize() const;
+  int   nbPhysicBlocks() const;
 
   Block*  getBlockById(const std::string& i_id);
   Entity* getEntityById(const std::string& i_id);
