@@ -18,9 +18,6 @@ along with XMOTO; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
-/* 
- *  Game object. Handles all of the gamestate management und so weiter.
- */
 #include "../GameText.h"
 #include "../Game.h"
 #include "Scene.h"
@@ -30,8 +27,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../PhysSettings.h"
 #include "../GameEvents.h"
 #include "Entity.h"
-#include "BikeGhost.h"
+#include "GhostTrail.h"
 #include "BikePlayer.h"
+#include "BikeController.h"
 #include "BikeParameters.h"
 #include "../helpers/Log.h"
 #include "Camera.h"
@@ -45,7 +43,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "PhysicsSettings.h"
 #include "../net/NetClient.h"
 #include "../net/NetActions.h"
+#include "ScriptTimer.h"
+#include "../drawlib/DrawLib.h"
 
+#define GAMEMESSAGES_PACKTIME 40
+
+/* 
+ *  Game object. Handles all of the gamestate management und so weiter.
+ */
   Scene::Scene() {
     m_bDeathAnimEnabled=true;
     m_lastCallToEveryHundreath = 0;
@@ -72,11 +77,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     m_halfUpdate = true;
 
     m_physicsSettings = NULL;
+    
+    m_ghostTrail = NULL;
   }
   
   Scene::~Scene() {
     cleanPlayers();
     cleanGhosts();
+    cleanScriptTimers();
+    if(m_ghostTrail != 0) delete m_ghostTrail;		
   }
 
   void Scene::loadLevel(xmDatabase *i_db, const std::string& i_id_level) {
@@ -96,7 +105,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
       i_db->read_DB_free(v_result);
 
       m_pLevelSrc->loadReducedFromFile();
-
+      
     } catch(Exception &e) {
       delete m_pLevelSrc;
       m_pLevelSrc = NULL;
@@ -109,6 +118,7 @@ void Scene::cleanGhosts() {
     delete m_ghosts[i];
   }
   m_ghosts.clear();
+//  if(m_fileGhost != 0) delete m_fileGhost;
 }
 
 void Scene::cleanPlayers() {
@@ -148,7 +158,32 @@ void Scene::cleanPlayers() {
   /*===========================================================================
     Add game message
     ===========================================================================*/
-  void Scene::gameMessage(std::string Text, bool bOnce, int duration) {
+  void Scene::gameMessage(std::string Text, bool bOnce, int duration, MessageType i_msgType) {
+
+    if(Text == "" ) return;  // eliminate empty messages
+
+    /* If text is longer than screen width, put \n into it to split lines */   
+    DrawLib* pDrawLib = GameApp::instance()->getDrawLib();
+    FontManager* pFM = pDrawLib->getFontMedium();
+    FontGlyph* pFG = pFM->getGlyph(Text);
+    if(pFG->realWidth() > pDrawLib->getDispWidth() ) {
+      unsigned int v_newline = 0;
+      std::string v_subtext = ("");
+      for( unsigned int i = 0; i<Text.length(); i++) {
+        pFG = pFM->getGlyph(Text.substr(v_newline,i-v_subtext.length()));  //substr isnt a problem for utf8, because its got a rule which prevents characters beeing in 2-byte chars
+        if(pFG->realWidth() >= pDrawLib->getDispWidth()-15) {  // our sub string length is now equal disp Width
+          for(unsigned int j=i; j>v_newline; j--) { //look for " "
+            if(!Text.compare(j,1," ")) {
+               Text.insert(j,"\n");
+               v_newline = j+1;
+               v_subtext = Text.substr(i-v_subtext.length(),j);
+               continue;  // leave this loop, to continue with rest of the string
+            }
+          }
+        }
+      }
+    }
+    
     /* "unique"? */
     GameMessage *pMsg = NULL;
     
@@ -170,19 +205,21 @@ void Scene::cleanPlayers() {
 	pMsg->nAlpha = 255;
 	pMsg->bOnce = bOnce;
 	pMsg->Text = Text;
+	pMsg->msgType = i_msgType;
 	m_GameMessages.push_back(pMsg);	
       } else {
-	/* split the message if \n is encoutered */
+	/* split the message if \n is encountered */
 	std::string v_txtRest = Text;
 	int n = v_txtRest.find_first_of("\n");
 
-	while(n >= 0 && (unsigned int)n < v_txtRest.length()) {
+	while(n >= 0 && (unsigned int)n < v_txtRest.length()) {  
 	  pMsg = new GameMessage;
 	  pMsg->removeTime = getTime() + duration;
 	  pMsg->bNew = true;
 	  pMsg->nAlpha = 255;
 	  pMsg->bOnce = bOnce;
 	  pMsg->Text = v_txtRest.substr(0, n);
+	  pMsg->msgType = i_msgType;
 	  m_GameMessages.push_back(pMsg);
 	  v_txtRest = v_txtRest.substr(n+1, v_txtRest.length()-1);
 	  n = v_txtRest.find_first_of("\n");
@@ -194,6 +231,7 @@ void Scene::cleanPlayers() {
 	pMsg->nAlpha = 255;
 	pMsg->bOnce = bOnce;
 	pMsg->Text = v_txtRest;
+	pMsg->msgType = i_msgType;
 	m_GameMessages.push_back(pMsg);
       }
     } else {
@@ -201,12 +239,33 @@ void Scene::cleanPlayers() {
       pMsg->Text = Text;
       pMsg->removeTime = getTime() + duration;
       pMsg->nAlpha = 255;
+      pMsg->msgType = i_msgType;
     }
-
+    packGameMessages();
     updateGameMessages();
   }
+  
+void Scene::packGameMessages() {   //put multiple GameMessages into one, if they appear shortly one after another
 
-  void Scene::clearGameMessages(void) {
+  for( int i = m_GameMessages.size()-1 ; i > 0 ; i-- ) {
+    
+    if( (m_GameMessages[i]->removeTime - m_GameMessages[i-1]->removeTime < GAMEMESSAGES_PACKTIME) && 
+        (m_GameMessages[i]->removeTime != 0) &&
+        (m_GameMessages[i]->msgType == m_GameMessages[i-1]->msgType) &&
+        (m_GameMessages[i]->bOnce == m_GameMessages[i-1]->bOnce) &&
+        (m_GameMessages[i]->nAlpha == m_GameMessages[i-1]->nAlpha)) {                   //of same Type?
+    
+      m_GameMessages[i-1]->Text += "\n" + m_GameMessages[i]->Text;
+      m_GameMessages[i-1]->removeTime = m_GameMessages[i]->removeTime;              //set removeTime of latest Message   
+      //remove last one
+      delete m_GameMessages[i];
+      m_GameMessages.erase(m_GameMessages.begin() +i);
+    
+    }
+  }
+}
+
+void Scene::clearGameMessages(void) {
     for(unsigned int i=0 ;i<m_GameMessages.size() ;i++)
       m_GameMessages[i]->removeTime=0;
   }
@@ -214,7 +273,7 @@ void Scene::cleanPlayers() {
   /*===========================================================================
     Update game
     ===========================================================================*/
-  void Scene::updateLevel(int timeStep, Replay *i_recordedReplay) {
+void Scene::updateLevel(int timeStep, Replay* i_frameRecorder, DBuffer* i_eventRecorder, bool i_fast) {
     float v_diff;
     int v_previousTime;
     bool v_recordReplay;
@@ -257,10 +316,29 @@ void Scene::cleanPlayers() {
 
     /* Update misc stuff (only when not playing a replay) */
     if(m_playEvents) {
-      getLevelSrc()->updatePhysics(timeStep, &m_Collision, m_chipmunkWorld);
+      getLevelSrc()->updatePhysics(m_time, timeStep, &m_Collision, m_chipmunkWorld, i_eventRecorder);
       _UpdateZones();
       _UpdateEntities();
     }
+	
+
+	/* update ScriptTimers */
+    try {
+			unsigned int i=0;
+			while(i<m_ScriptTimers.size()){
+				m_ScriptTimers[i]->UpdateTimer(getTime());
+				if(m_ScriptTimers[i]->isFinished()==true){
+					delete m_ScriptTimers[i];
+					m_ScriptTimers.erase(m_ScriptTimers.begin() + i);
+				}else{ //only grow index if we don't delete anything
+					i++;
+				}
+			}
+		} catch(Exception &e) {
+			LogWarning(std::string("Script Timer Update Failed!!\n" + e.getMsg()).c_str());
+			throw e;
+		}
+	
 
     /* Invoke Tick() script function */
     /* and play script dynamic objects */
@@ -301,17 +379,18 @@ void Scene::cleanPlayers() {
       m_chipmunkWorld->updateWheelsPosition(m_players);
     }
 
-    executeEvents(i_recordedReplay);
+    executeEvents(i_eventRecorder);
 
     // record the replay only if
     v_recordReplay = 
-      i_recordedReplay != NULL                                                            &&
-      getTime() - m_lastStateSerializationTime >= 100.0f/i_recordedReplay->getFrameRate() && // limit the framerate
+      i_frameRecorder != NULL                                                            &&
+      getTime() - m_lastStateSerializationTime >= 100.0f/i_frameRecorder->getFrameRate() && // limit the framerate
       Players().size() == 1;                                                                 // supported in one player mode only
 
     // upload the frame only if
     v_uploadFrame =
       NetClient::instance()->isConnected() &&
+      NetClient::instance()->mode() == NETCLIENT_GHOST_MODE &&
       getTime() - m_lastStateUploadTime >= 100.0f/XMSession::instance()->clientFramerateUpload();
 
     if(v_recordReplay) {
@@ -323,7 +402,7 @@ void Scene::cleanPlayers() {
     }
 
     /* save the replay */
-    if(v_recordReplay || v_uploadFrame) {
+    if((v_recordReplay || v_uploadFrame) && i_fast == false) {
       for(unsigned int i=0; i<Players().size(); i++) {
 
 	// in both case, don't get when player is dead (in the frame, you don't get the 'died' information, thus via the network, you're not able to draw the player correctly)
@@ -344,8 +423,8 @@ void Scene::cleanPlayers() {
 	  }
 	  
 	  if(v_recordReplay && i == 0) {
-	    i_recordedReplay->storeState(BikeState);
-	    i_recordedReplay->storeBlocks(m_pLevelSrc->Blocks());
+	    i_frameRecorder->storeState(BikeState);
+	    i_frameRecorder->storeBlocks(m_pLevelSrc->Blocks());
 	  }
 	}
       }
@@ -358,13 +437,13 @@ void Scene::cleanPlayers() {
     m_DelSchedule.clear();
   }
 
-  void Scene::executeEvents(Replay *p_replay) {
+  void Scene::executeEvents(DBuffer *i_recorder) {
     /* Handle events generated this update */
     while(getNumPendingGameEvents() > 0) {
       SceneEvent *pEvent = getNextGameEvent();
-      if(p_replay != NULL) {
+      if(i_recorder != NULL) {
 	/* Encode event */
-	_SerializeGameEventQueue(p_replay, pEvent);
+	pEvent->serialize(*i_recorder);
       }
       
       /* What event? */
@@ -409,8 +488,8 @@ void Scene::cleanPlayers() {
   /*===========================================================================
     Prepare the specified level for playing through this game object
     ===========================================================================*/
-  void Scene::prePlayLevel(Replay *recordingReplay,
-			      bool i_playEvents) {
+  void Scene::prePlayLevel(DBuffer *i_recorder,
+			   bool i_playEvents) {
     m_playEvents = i_playEvents;
     /* load the level if not */
     if(m_pLevelSrc->isFullyLoaded() == false) {
@@ -499,9 +578,10 @@ void Scene::cleanPlayers() {
     }
 
     // load chimunk
-    if(m_pLevelSrc->isPhysics()) {
-      LogInfo("Running a physics level");
-      m_chipmunkWorld = new ChipmunkWorld(m_physicsSettings);
+    if(m_playEvents) {
+      if(m_pLevelSrc->isPhysics()) {
+	m_chipmunkWorld = new ChipmunkWorld(m_physicsSettings, m_pLevelSrc);
+      }
     }
 
     /* Generate extended level data to be used by the game */
@@ -525,7 +605,7 @@ void Scene::cleanPlayers() {
     m_lastStateUploadTime        = -100;
 
     if(m_playEvents) {
-      executeEvents(recordingReplay);
+      executeEvents(i_recorder);
     }
   }
 
@@ -557,6 +637,9 @@ void Scene::cleanPlayers() {
     v_ghost->setReference(i_isReference);
     v_ghost->initLastToTakeEntities(m_pLevelSrc);
     m_ghosts.push_back(v_ghost);
+    if(i_info == "WR") {  // then we ve got our ghost trail, because WR is always optimal path through level!
+      m_ghostTrail = new GhostTrail(v_ghost);
+    }
     return v_ghost;
   }
 
@@ -596,13 +679,17 @@ void Scene::cleanPlayers() {
       }
       /* if no OnLoad(), assume success */
       /* Success? */
-      if(!bOnLoadSuccess) {
+      if(bOnLoadSuccess == false) {
 	LogError("OnLoad script function failed !");
 	throw Exception("OnLoad script function failed !");
       }
     }
   }
-
+  
+/*  void Scene::setFileGhost(FileGhost* i_fileGhost) {
+    m_fileGhost = i_fileGhost;
+  }
+*/
   /*===========================================================================
     Free this game object
     ===========================================================================*/
@@ -634,6 +721,7 @@ void Scene::cleanPlayers() {
 
     cleanPlayers();
     cleanGhosts();
+    cleanScriptTimers();
 
     removeCameras();
 
@@ -815,13 +903,13 @@ void Scene::cleanPlayers() {
 	     pZone->doesCircleTouch(v_player->getState()->RearWheelP,  v_player->getState()->Parameters()->WheelRadius()) ||
 	     pZone->doesCircleTouch(v_player->getState()->HeadP, v_player->getState()->Parameters()->HeadSize())) {       
 	    /* In the zone -- did he just enter it? */
-	    if(v_player->setTouching(pZone, true) == PlayerBiker::added){
+	    if(v_player->setTouching(pZone, true) == PlayerLocalBiker::added){
 	      createGameEvent(new MGE_PlayerEntersZone(getTime(), pZone, j));
 	    }
 	  } else {
 	    /* Not in the zone... but was he during last update? - i.e. has 
 	       he just left it? */      
-	    if(v_player->setTouching(pZone, false) == PlayerBiker::removed){
+	    if(v_player->setTouching(pZone, false) == PlayerLocalBiker::removed){
 	      createGameEvent(new MGE_PlayerLeavesZone(getTime(), pZone, j));
 	    }
 	  }
@@ -870,7 +958,7 @@ void Scene::cleanPlayers() {
 				   entities[i]->Size(),
 				   HeadPos,
 				   v_player->getState()->Parameters()->HeadSize())) {
-	      if(v_player->setTouching(entities[i], true) == PlayerBiker::added){
+	      if(v_player->setTouching(entities[i], true) == PlayerLocalBiker::added){
 		createGameEvent(new MGE_PlayerTouchesEntity(getTime(),
 							    entities[i]->Id(),
 							    true, j));
@@ -885,7 +973,7 @@ void Scene::cleanPlayers() {
 					  entities[i]->Size(),
 					  v_player->getState()->RearWheelP,
 					  v_player->getState()->Parameters()->WheelRadius())) {
-	      if(v_player->setTouching(entities[i], true) == PlayerBiker::added){
+	      if(v_player->setTouching(entities[i], true) == PlayerLocalBiker::added){
 		createGameEvent(new MGE_PlayerTouchesEntity(getTime(),
 							    entities[i]->Id(),
 							    false, j));
@@ -893,7 +981,7 @@ void Scene::cleanPlayers() {
 	      
 	      /* body then ?*/
 	    } else if(touchEntityBodyExceptHead(*(v_player->getState()), *(entities[i]))) {
-	      if(v_player->setTouching(entities[i], true) == PlayerBiker::added){
+	      if(v_player->setTouching(entities[i], true) == PlayerLocalBiker::added){
 		createGameEvent(new MGE_PlayerTouchesEntity(getTime(),
 							    entities[i]->Id(),
 							    false, j));
@@ -1037,31 +1125,32 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
   }
   
   void Scene::MoveBlock(Block* pBlock, float pX, float pY) {
-    pBlock->translate(pX, pY);
-    m_Collision.moveDynBlock(pBlock);
+    if(pBlock->isDynamic() == true) {
+      pBlock->translate(pX, pY);
+      m_Collision.moveDynBlock(pBlock);
+    }
   }
-  
+
   void Scene::SetBlockPos(std::string pBlockID, float pX, float pY) {
     Block* v_block = m_pLevelSrc->getBlockById(pBlockID);
-    v_block->setDynamicPositionAccordingToCenter(Vector2f(pX, pY));
-    m_Collision.moveDynBlock(v_block);
-  }
-  
-  void Scene::SetPhysicsBlockPos(std::string pBlockID, float pX, float pY) {
-    Block* v_block = m_pLevelSrc->getBlockById(pBlockID);
-    v_block->setDynamicPositionAccordingToCenter(Vector2f(pX, pY));
-    if (v_block->isPhysics()) {
-      v_block->setPhysicsPosition(pX, pY);
-    } else {
-      // report error?
+    if(v_block->isDynamic() == true) {
+      v_block->setDynamicPositionAccordingToCenter(Vector2f(pX, pY));
+
+      if(m_chipmunkWorld != NULL) {
+	if(v_block->isPhysics()) {
+	  v_block->setPhysicsPosition(pX, pY);
+	}
+      }
+      m_Collision.moveDynBlock(v_block);
     }
-    m_Collision.moveDynBlock(v_block);
   }
   
   void Scene::SetBlockCenter(std::string pBlockID, float pX, float pY) {
     Block* v_block = m_pLevelSrc->getBlockById(pBlockID);
-    v_block->setCenter(Vector2f(pX, pY));
-    m_Collision.moveDynBlock(v_block);
+    if(v_block->isDynamic() == true) {
+      v_block->setCenter(Vector2f(pX, pY));
+      m_Collision.moveDynBlock(v_block);
+    }
   }
   
   void Scene::SetBlockRotation(std::string pBlockID, float pAngle) {
@@ -1070,8 +1159,10 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
   }     
   
   void Scene::SetBlockRotation(Block* pBlock, float pAngle) {
-    if(pBlock->setDynamicRotation(pAngle) == true)
-      m_Collision.moveDynBlock(pBlock);
+    if(pBlock->isDynamic() == true) {
+      if(pBlock->setDynamicRotation(pAngle) == true)
+	m_Collision.moveDynBlock(pBlock);
+    }
   }     
   
   void Scene::SetEntityDrawAngle(std::string pEntityID, float pAngle) {
@@ -1144,9 +1235,16 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
    
   void Scene::CameraMove(float p_x, float p_y) {
     getCamera()->desactiveActionZoom();
+    getCamera()->setUseTrailCam(false);
     getCamera()->moveCamera(p_x, p_y);
   }
 
+  void Scene::CameraSetPos(float p_x, float p_y) {
+    getCamera()->desactiveActionZoom();
+    getCamera()->setUseTrailCam(false);
+    getCamera()->setCameraPosition(p_x, p_y);
+  }
+
   void Scene::CameraRotate(float i_angle) {
     getCamera()->setDesiredRotationAngle(i_angle);
   }
@@ -1162,7 +1260,7 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
       if(m_bDeathAnimEnabled) {
 	m_players[i_player]->setBodyDetach(true);
       }
-      m_players[i_player]->getControler()->stopContols();
+      m_players[i_player]->getControler()->stopControls();
 
       // inform camera that the player dies (for the following point)
       for(unsigned int i=0; i<m_cameras.size(); i++){
@@ -1195,7 +1293,7 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
     touchEntity(i_player, getLevelSrc()->getEntityById(p_entityID), p_bTouchedWithHead);
   }
 
-  void Scene::entityDestroyed(const std::string& i_entityId) {
+  void Scene::entityDestroyed(const std::string& i_entityId, int i_time) {
     Entity *v_entity;
     v_entity = getLevelSrc()->getEntityById(i_entityId);
 
@@ -1214,7 +1312,7 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
       }
 
       /* update timediff */
-      m_myLastStrawberries.push_back(getTime());
+      m_myLastStrawberries.push_back(i_time);
       
       for(unsigned int i=0; i<m_ghosts.size(); i++) {
 	m_ghosts[i]->updateDiffToPlayer(m_myLastStrawberries);
@@ -1280,25 +1378,37 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
   }
 
 
-  PlayerBiker* Scene::addPlayerBiker(int i_localNetId, Vector2f i_position, DriveDir i_direction,
-					Theme *i_theme, BikerTheme* i_bikerTheme,
-					const TColor& i_filterColor,
-					const TColor& i_filterUglyColor,
-					bool i_enableEngineSound) {
-    PlayerBiker* v_playerBiker = new PlayerBiker(m_physicsSettings, i_position, i_direction, m_PhysGravity,
-						 i_theme, i_bikerTheme,
-						 i_filterColor, i_filterUglyColor);
-    v_playerBiker->setOnBikerHooks(new SceneOnBikerHooks(this, m_players.size()));
-    v_playerBiker->setPlaySound(i_enableEngineSound);
-    v_playerBiker->setLocalNetId(i_localNetId);
-    m_players.push_back(v_playerBiker);
-
-    if(m_chipmunkWorld != NULL) {
-      m_chipmunkWorld->addPlayer(v_playerBiker);
-    }
-
-    return v_playerBiker;
+PlayerLocalBiker* Scene::addPlayerLocalBiker(int i_localNetId, Vector2f i_position, DriveDir i_direction,
+				   Theme *i_theme, BikerTheme* i_bikerTheme,
+				   const TColor& i_filterColor,
+				   const TColor& i_filterUglyColor,
+				   bool i_enableEngineSound) {
+  PlayerLocalBiker* v_playerBiker = new PlayerLocalBiker(m_physicsSettings, i_position, i_direction, m_PhysGravity,
+					       i_theme, i_bikerTheme,
+					       i_filterColor, i_filterUglyColor);
+  v_playerBiker->setOnBikerHooks(new SceneOnBikerHooks(this, m_players.size()));
+  v_playerBiker->setPlaySound(i_enableEngineSound);
+  v_playerBiker->setLocalNetId(i_localNetId);
+  m_players.push_back(v_playerBiker);
+  
+  if(m_chipmunkWorld != NULL) {
+    m_chipmunkWorld->addPlayer(v_playerBiker);
   }
+  
+  return v_playerBiker;
+}
+
+PlayerNetClient* Scene::addPlayerNetClient(Vector2f i_position, DriveDir i_direction,
+					   Theme *i_theme, BikerTheme* i_bikerTheme,
+					   const TColor& i_filterColor,
+					   const TColor& i_filterUglyColor) {
+  PlayerNetClient* v_playerNetClient = new PlayerNetClient(m_physicsSettings,
+							   i_position, i_direction, m_PhysGravity,
+							   i_theme, i_bikerTheme, i_filterColor, i_filterUglyColor);
+  m_players.push_back(v_playerNetClient);
+  
+  return v_playerNetClient;
+}
 
   void Scene::setGravity(float x,float y) {
     m_PhysGravity.x=x;
@@ -1366,20 +1476,14 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
 
   void Scene::onRewinding() {
     bool v_continue = true;
-    unsigned int i = m_myLastStrawberries.size()-1;
+    int i = m_myLastStrawberries.size()-1;
 
     // remove strawberries untaken
-    while(v_continue) {
+    while(v_continue && i>=0) { // must be at least one strawberry
       // > because updateToTime is done after m_time increase
       if(m_myLastStrawberries[i] > m_time) { 
 	m_myLastStrawberries.erase(m_myLastStrawberries.begin() + i);
-
-	if(i == 0) {
-	  v_continue = false;
-	} else {
-	  i--;
-	}
-	
+	i--;
       } else {
 	v_continue = false;
       }
@@ -1415,7 +1519,10 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
   }
   unsigned int Scene::getNumberCameras(){
     // the last camera is the autozoom one
-    return m_cameras.size()==1?1:m_cameras.size()-1;
+    if(m_cameras.size() <= 1) {
+      return m_cameras.size();
+    }
+    return m_cameras.size()-1;
   }
   void Scene::setCurrentCamera(unsigned int currentCamera){
     m_currentCamera = currentCamera;
@@ -1423,9 +1530,10 @@ void Scene::translateEntity(Entity* pEntity, float x, float y)
   unsigned int Scene::getCurrentCamera(){
     return m_currentCamera;
   }
-  void Scene::addCamera(Vector2i upperleft, Vector2i downright, bool i_useActiveZoom){
+  void Scene::addCamera(Vector2i upperleft, Vector2i downright, bool i_useActiveZoom, bool i_useTrailCam){
     Camera* i_cam = new Camera(upperleft, downright);
     i_cam->allowActiveZoom(i_useActiveZoom);
+    i_cam->allowTrailCam(i_useTrailCam);
     m_cameras.push_back(i_cam);
     m_cameras.back()->initCamera();
   }
@@ -1503,3 +1611,27 @@ void SceneOnBikerHooks::onHeadTouches() {
   m_motoGame->createGameEvent(new MGE_PlayerDies(m_motoGame->getTime(), false, m_playerNumber));
 }
 
+
+/*===========================================================================*/
+/* ScriptTimer methods (public)                                              */
+/*===========================================================================*/
+  ScriptTimer* Scene::getScriptTimerByName(std::string TimerName){
+		for(unsigned int i=0; i<m_ScriptTimers.size(); i++) {
+		    if(m_ScriptTimers[i]->GetName()==TimerName){
+			return m_ScriptTimers[i];
+			}
+		}
+    return NULL;
+  }
+
+	void Scene::createScriptTimer(std::string TimerName, float delay, int loops){
+		m_ScriptTimers.push_back(new ScriptTimer(TimerName, delay, loops, m_luaGame, getTime()));
+	}
+
+	void Scene::cleanScriptTimers(){
+		for(unsigned int i=0; i<m_ScriptTimers.size(); i++) {
+    	delete m_ScriptTimers[i];
+		}
+		m_ScriptTimers.clear();
+	}
+
